<?xml version="1.0" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:temp=".">

	<msxsl:script language="JScript" implements-prefix="temp">
	function FileTime(tsNodeList)
	{
		var filetime = Date.parse(tsNodeList.nextNode().text) * 10000 + 116444736000000000;
		return filetime.toString(16);
	}
	</msxsl:script>

	<xsl:output version="1.0" method="xml" encoding="UTF-8" />

	<xsl:variable name="targetCount" select="count(/Report/Analysis/Targets/Target)" />
	
	<xsl:template match="/">
		<securityAnalysisData version="1" xmlns="urn:redteam:SecurityAnalysisData">
			<collection tool="CATNet" version="1.0">
				<xsl:attribute name="time"><xsl:value-of select="temp:FileTime(/Report/Analysis/StopTimeStamp)" /></xsl:attribute>
				<platform idx="0" majorVersion="0" minorVersion="0" buildNumber="0" csdVersion="0" servicePackMajor="0" servicePackMinor="0" suiteMask="0" productType="0" />
				<xsl:apply-templates select="Report/Analysis/Targets/Target" />
				<xsl:apply-templates select="Report/Rules" />
			</collection>
		</securityAnalysisData>
	</xsl:template>
	
	<xsl:template match="Report/Analysis/Targets/Target">
		<file>
			<xsl:attribute name="idx"><xsl:value-of select="position()" /></xsl:attribute>
			<xsl:attribute name="path"><xsl:value-of select="."/></xsl:attribute>
		</file>
	</xsl:template>

	<xsl:template match="Report/Rules">
		<xsl:for-each select="./Rule/Results/Result">		
		<check>
			<xsl:attribute name="idx"><xsl:value-of select="position() + $targetCount" /></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="ancestor::Rule/Identifier"/></xsl:attribute>
			<xsl:attribute name="result">
				<xsl:choose>
				<xsl:when test="Suppressed = 'true'">Pass</xsl:when>
				<xsl:when test="ConfidenceLevel = 'Low'">Warning</xsl:when>
				<xsl:otherwise>Fail</xsl:otherwise>
			</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="stack">
				<xsl:for-each select="./Transformations/*">
					<xsl:if test="position() != 1">|</xsl:if>
					<xsl:value-of select="Statement" /> [<xsl:value-of select="@file" /> @ <xsl:value-of select="@line" />]
				</xsl:for-each>
			</xsl:attribute>
		</check>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>
