<?xml version="1.0" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:js="urn:custom-javascript"
	exclude-result-prefixes="msxsl js">

	<msxsl:script language="JScript" implements-prefix="js">
		<![CDATA[
			var count = 1;

			function inc()
			{
				return count++;
			}
		]]>
	</msxsl:script>

	<xsl:output method="html"/>

	<xsl:template name="filename-from-path">
		<xsl:param name="name"/>
		<xsl:choose>
			<xsl:when test="contains($name, '\')">
				<xsl:call-template name="filename-from-path">
					<xsl:with-param name="name" select="substring-after($name, '\')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$name"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="row-color">
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$index mod 2 != 0">background: #f8e6cb</xsl:when>
			<xsl:otherwise>background: #cbe6f8 </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="/">

		<HTML>
			<TITLE>
				Code Analysis Report
			</TITLE>
			<BODY>
				<STYLE type="text/css">
					table
					{
						background: #cccccc;
						color: #444444;
						border-spacing: 1px;
						font: 10px 'Verdana', Arial, Helvetica, sans-serif;
					}
					td, th 
					{
						padding: 2px;
					}
					th
					{
						font-weight: bold;
						text-align: left;
						background: #F5F5F5;
						color: #666666;
						border: 1px;
						font-size: 12px
					}
					tbody tr td
					{
						background: #c9e4e9;
						text-align: left;
					}

					body
					{
						font-family: arial, helvetica, sans-serif;
					}

					.tdp
					{
						font-weight: bold;
					}
				</STYLE>
				<xsl:apply-templates select="Report/Analysis"/>
				<br/>
				<xsl:apply-templates select="Report/Rules"/>
			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="Analysis">
		<table width="100%">
			<th colspan="2" style="background: #59bba5; height: 30px">Analysis Information</th>
			<tbody>
        <tr><td class="tdp"><nobr>Analysis Engine Version</nobr></td><td><xsl:value-of select="AnalysisEngineVersion"/></td></tr>
				<tr><td class="tdp"><nobr>Created by</nobr></td><td><xsl:value-of select="User"/></td></tr>
				<tr><td class="tdp"><nobr>Start time</nobr></td><td><xsl:value-of select="StartTimeStamp"/></td></tr>
				<tr><td class="tdp"><nobr>Stop time</nobr></td><td><xsl:value-of select="StopTimeStamp"/></td></tr>
				<tr><td class="tdp"><nobr>Elapsed time</nobr></td><td><xsl:value-of select="ElapsedTime"/></td></tr>
				<tr><td class="tdp"><nobr>Data flow graph</nobr></td><td>
						<xsl:value-of select="DataFlowSuperGraph/Nodes"/> nodes, 
						<xsl:value-of select="DataFlowSuperGraph/Edges"/> edges
					</td>
				</tr>
				<tr><td class="tdp">Targets</td><td width='100%'>
						<xsl:for-each select="Targets/Target">
							<xsl:value-of select="."/><br/>
						</xsl:for-each>
				</td></tr>
			</tbody>
		</table>
	</xsl:template>

	<xsl:template match="Rules">
		<table>
		<xsl:for-each select="Rule">
			<xsl:if test="TotalResults &gt; 0">
				<th style="background: #59bba5; height: 30px" colspan="2"><xsl:value-of select="Name"/> (<xsl:value-of select="Identifier"/>)</th>
				<tr><td><b><xsl:value-of select="TotalResults"/> results</b></td></tr>
				<tr><td style="background: #ffffff; padding: 4px">
					<table width='100%'>
						<xsl:for-each select="Results/Result">
				
							<tr>
								<th colspan="4" style="background: #fcd998; height: 30px; text-align: left">
									<nobr>Result #<xsl:value-of select="js:inc()"/></nobr>
								</th>
							</tr>
							<tr>
								<th colspan="4">Summary</th>
							</tr>
							<tr>
								<td><b>Problem</b></td>
								<td colspan="3"><xsl:value-of select="ProblemDescription"/></td>
							</tr>
							<tr>
								<td><b>Resolution</b></td>
								<td colspan="3"><xsl:value-of select="Resolution"/></td>
							</tr>
							<tr>
								<td><b>Entry Variable</b></td>
								<td colspan="3"><xsl:value-of select="EntryVariable"/></td>
							</tr>
							<tr>
								<td><b>Confidence</b></td>
								<td colspan="3">
									<xsl:value-of select="ConfidenceLevel"/>
									<xsl:if test="string-length(ConfidenceReason) != 0">
										 (<xsl:value-of select="ConfidenceReason"/>)
									</xsl:if>
								</td>
							</tr>
							<xsl:if test="Suppressed != 'false'">
								<tr>
									<td><b>Suppressed</b></td>
									<td colspan="3">Yes</td>
								</tr>
								<tr>
									<td><b><nobr>Suppression Type</nobr></b></td>
									<td colspan="3"><xsl:value-of select="SuppressionType"/></td>
								</tr>
								<xsl:if test="string-length(SuppressionCategory) != 0">
									<tr>
										<td><b><nobr>Suppression Category</nobr></b></td>
										<td colspan="3"><xsl:value-of select="SuppressionCategory"/></td>
									</tr>
								</xsl:if>
								<xsl:if test="string-length(SuppressionJustification) != 0">
									<tr>
										<td><b><nobr>Suppression Justification</nobr></b></td>
										<td colspan="3"><xsl:value-of select="SuppressionJustification"/></td>
									</tr>
								</xsl:if>
							</xsl:if>
							<tr>
								<th>Source Context</th>
								<th>Line</th>
								<th><nobr>Input Variable</nobr></th>
								<th>Statement</th>
							</tr>
							<tbody>
								<xsl:for-each select="Transformations/*">
									<tr>
										<td>
											<xsl:attribute name="style">
												<xsl:call-template name="row-color"><xsl:with-param name="index" select="position()"/></xsl:call-template>
											</xsl:attribute>
											<xsl:choose>
												<xsl:when test="@line != 0">
													<xsl:call-template name="filename-from-path">
														<xsl:with-param name="name" select="@file"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>
													In <xsl:value-of select="StatementMethod"/>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:attribute name="style">
												<xsl:call-template name="row-color"><xsl:with-param name="index" select="position()"/></xsl:call-template>
											</xsl:attribute>
											<xsl:if test="@line != 0">
												<xsl:value-of select="@line"/>
											</xsl:if>
										</td>
										<td>
											<xsl:attribute name="style">
												<xsl:call-template name="row-color"><xsl:with-param name="index" select="position()"/></xsl:call-template>
											</xsl:attribute>
											<nobr><xsl:value-of select="ActualInputVariable"/></nobr>
										</td>
										<td>
											<xsl:attribute name="style">
												<xsl:call-template name="row-color"><xsl:with-param name="index" select="position()"/></xsl:call-template>
											</xsl:attribute>
											<xsl:value-of select="Statement"/>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
							<tr><td colspan="4" style="background: #ffffff; height: 10px; border-width: 0 0 0 0"></td></tr>
					</xsl:for-each>
					</table>
				</td></tr>
			</xsl:if>
		</xsl:for-each>
		</table>
	</xsl:template>
</xsl:stylesheet>
