$CURRENT_DIR = (Split-Path -Path $MyInvocation.MyCommand.Definition -Parent);
$DLL_DIR = ( Join-Path -Path $CURRENT_DIR -ChildPath "..\..\MVCSiteTemplate\bin\" );
$OUTPUT_DIR = ( Join-Path -Path $CURRENT_DIR -ChildPath "Output\" );

Write-Host "Running CAT.NET...";

$args = @("/file:`"$($DLL_DIR)CommerceServerContrib.Web.dll`"",
		  "/file:`"$($DLL_DIR)CommerceServerContrib.CrossTier.dll`"",
		  "/file:`"$($DLL_DIR)CommerceServerContrib.MVCSiteTemplate.dll`"", 
		  "/report:`"$($OUTPUT_DIR)report.xml`"",
		  "/config:`"$($CURRENT_DIR)\Config`"", 
		  "/rule:`"$($CURRENT_DIR)\Rules`"", 
		  "/verbose:Debug",
		  "/reportxsl:`"$($CURRENT_DIR)\config\report.xsl`"",
		  "/reportxsloutput:`"$($OUTPUT_DIR)report.html`"");
		  
Get-Variable | out-default;		  

if ((Test-Path -path $OUTPUT_DIR))
{
	Write-Host "Deleting output directory...";
	Remove-Item -path $OUTPUT_DIR -recurse -Force -Confirm:$false;
}

Write-Host "Creating new output directory...";
New-Item $OUTPUT_DIR -type directory

$returnValue = Start-Process -FilePath  (Join-Path -Path $CURRENT_DIR -ChildPath "CATNetCmd64.exe") -ArgumentList $args -NoNewWindow -Wait -PassThru;

if( $returnValue.ExitCode -ne 0 )
{
	Write-Error "Program Exit Code was $($returnValue.ExitCode), aborting.`r$($returnValue.StandardError)";
}

Write-Host "Checking for issues...";
$reportXml = [xml]( Get-Content -Path ( Join-Path -Path $OUTPUT_DIR -ChildPath "report.xml" ) );

[int]$issueCount = 0;
foreach($result in $reportXml.Report.Rules.Rule){
	$issueCount += [int]$($result.TotalResults)
}

Write-Host "Found $($issueCount) issues.";

if($issueCount -gt 0)
{
	Write-Host "Exiting with code 1";
	exit 1;
}
else{
	Write-Host "Exiting with code 0";
	exit 0;
}