﻿//-----------------------------------------------------------------------
// <copyright file="BaseController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.MVCSiteTemplate.Controllers
{
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.Web;
    using System;
    using System.Collections.Generic;
    using System.Configuration;
    using System.Globalization;
    using System.Linq;
    using System.Web;
    using System.Web.Mvc;

    /// <summary>
    /// Base controller for all controllers
    /// </summary>
    public class BaseController : Controller
    {
        /// <summary>
        /// The value to tell the app tier to recalculate the basket
        /// </summary>
        public const string DoRefreshBasket = "true";

        private ICommerceContext _context;
        private string _userId = string.Empty;        

        /// <summary>
        /// Initializes a new instance of the <see cref="BaseController" /> class.
        /// </summary>
        public BaseController()
        {
            this._context = PresentationServiceLocator.Current.SiteContext;
            this._userId = string.IsNullOrWhiteSpace(this._context.User.Id) ? this._context.User.AnonymousId : this._context.User.Id;
        }

        /// <summary>
        /// Gets the default catalog for the site
        /// </summary>
        public string DefaultCatalog
        {
            get
            {
                return ConfigurationManager.AppSettings["DefaultCommerceCatalog"];
            }
        }

        /// <summary>
        /// Gets a value indicating whether if the site is in large basket mode.
        /// </summary>
        /// <value>
        ///   <c>true</c> if the site is in large basket mode; otherwise, <c>false</c>.
        /// </value>
        public bool LargeBasketMode
        {
            get
            {
                bool returnValue = false;
                var basketModeAppSetting = ConfigurationManager.AppSettings["LargeBasketMode"];
                if (string.IsNullOrEmpty(basketModeAppSetting) && bool.TryParse(basketModeAppSetting, out returnValue))
                {
                    return returnValue;
                }

                return returnValue;
            }
        }

        /// <summary>
        /// Gets the current context for the site
        /// </summary>
        public ICommerceContext Context
        {
            get
            {
                return this._context;
            }
        }

        /// <summary>
        /// Gets the current user id
        /// </summary>
        public string UserId
        {
            get
            {
                return this._userId;
            }
        }

        /// <summary>
        /// Gets the id of a cart basket type
        /// </summary>
        public string CartBasketType
        {
            get
            {
                return this.Context.DefaultBasketType.ToString(CultureInfo.InvariantCulture);
            }
        }

        /// <summary>
        /// Gets the type of the order basket.
        /// </summary>
        /// <value>
        /// The type of the order basket.
        /// </value>
        public string OrderBasketType
        {
            get
            {
                return "1";
            }
        }
    }
}