﻿//-----------------------------------------------------------------------
// <copyright file="CategoryController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.MVCSiteTemplate.Controllers
{
    using CommerceServerContrib.MVCSiteTemplate;
    using CommerceServerContrib.MVCSiteTemplate.Models.Generated;
    using System;
    using System.Globalization;
    using System.Web.Mvc;
    using RT = CommerceServerContrib.MVCSiteTemplate.RequestTemplates;

    /// <summary>
    /// handles all calls to the category
    /// </summary>
    public class CategoryController : BaseController
    {
        /// <summary>
        /// Handles displaying a category
        /// </summary>
        /// <param name="categoryId">Category ID</param>
        /// <param name="page">The page to take.</param>
        /// <returns>ActionResult to render a Category View.</returns>
        public ActionResult Index(string categoryId, string page)
        {
            if (!string.IsNullOrWhiteSpace(categoryId))
            {
                var skip = Helpers.ItemsToSkip(page, 10);
                var categories = RT.Catalog.GetCategoryWithChildProducts(
                    categoryId,
                    this.DefaultCatalog,
                    string.IsNullOrWhiteSpace(page) ? "0" : skip.ToString(CultureInfo.InvariantCulture),
                    "10",
                    "true",
                    null,
                    null,
                    null,
                    null,
                    null);

                if (categories != null)
                {
                    var category = (Category)categories[0];
                    ViewBag.CurrentPage = Helpers.CalculateCurrentPage(category.ChildProductsFirstItemIndex);
                    ViewBag.TotalPages = Helpers.CalculateTotalPages(category.ChildProductsTotalItemCount);
                    
                    return View(category);
                }
            }

            return View(new Category());
        }
    }
}
