﻿//-----------------------------------------------------------------------
// <copyright file="ProductController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.MVCSiteTemplate.Controllers
{
    using CommerceServerContrib.MVCSiteTemplate.Models;
    using CommerceServerContrib.MVCSiteTemplate.Models.Generated;
    using System.Linq;
    using System.Web.Mvc;
    using RT = CommerceServerContrib.MVCSiteTemplate.RequestTemplates;

    /// <summary>
    /// Handles all product calls
    /// </summary>
    public class ProductController : BaseController
    {
        /// <summary>
        /// Queries and returns the product for the Product Index page.
        /// </summary>
        /// <param name="productId">Commerce Server Product ID</param>
        /// <returns>ActionResult to render View.</returns>
        public ActionResult Index(string productId)
        {
            if (string.IsNullOrWhiteSpace(productId))
            {
                return View(new ProductViewModel());
            }

            var entity = RT.Catalog.GetProductSummary(productId, this.DefaultCatalog);

            if (entity != null)
            {
                var product = (Product)(entity.First());

                var productViewModel = new ProductViewModel
                {
                    ProductId = product.Id,
                    DisplayName = product.DisplayName,
                    ListPrice = product.ListPrice,
                    Description = product.Description,
                    ImageFilename = product.ImageFilename,
                    Quantity = 1
                };

                if (product.Variants != null && product.Variants.Count > 0)
                {
                    productViewModel.Variants.AddRange(
                        from v in product.Variants
                        select new VariantViewModel
                        {
                            Id = v.Id,
                            VariantCode = v.VariantCode,
                            Size = v.Size,
                            ProductColor = v.ProductColor
                        });
                }

                return View(productViewModel);
            }

            return View(new ProductViewModel());
        }
    }
}
