﻿//-----------------------------------------------------------------------
// <copyright file="SupportingDataController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.MVCSiteTemplate.Controllers
{
    using CommerceServerContrib.MVCSiteTemplate.Models.Generated;
    using CommerceServerContrib.MVCSiteTemplate.RequestTemplates;
    using System.Collections.Generic;
    using System.Linq;
    using System.Web.Http;

    /// <summary>
    /// WebAPI controller for accessing 
    /// </summary>
    public class SupportingDataController : ApiController
    {
        /// <summary>
        /// Gets the region with its states or provinces.
        /// </summary>
        /// <returns>A List of Region object with their State or Provinces.</returns>
        [ActionName("GetRegions")]
        public List<Region> GetRegions()
        {
            var regionsWithStates = Profile.GetRegions();
            return new List<Region>(regionsWithStates.Select(c => (Region)c));
        }

        /// <summary>
        /// Gets the state for region.
        /// </summary>
        /// <param name="regionId">The region id.</param>
        /// <returns>States for a given region.</returns>
        [ActionName("GetStateForRegion")]
        public List<StateProvince> GetStateForRegion(string regionId)
        {
            var regionWithStates = Profile.GetRegionWithState(regionId);
            if (regionWithStates != null && regionWithStates.Count > 0)
            {
                var region = (Region)regionWithStates[0];
                return region.StatesProvinces;
            }

            return null;
        }
    }
}
