﻿//-----------------------------------------------------------------------
// <copyright file="AddressOrders.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.MVCSiteTemplate.Models.Generated
{
    /// <summary>
    /// Partial class for working with Order system addresses in Commerce Server.
    /// </summary>
    public partial class AddressOrders
    {
        /// <summary>
        /// Determines whether the specified <see cref="System.Object" /> is equal to this instance.
        /// </summary>
        /// <param name="obj">The <see cref="System.Object" /> to compare with this instance.</param>
        /// <returns>
        ///   <c>true</c> if the specified <see cref="System.Object" /> is equal to this instance; otherwise, <c>false</c>.
        /// </returns>
        public override bool Equals(object obj)
        {
            var secondAddress = obj as AddressOrders;
            if (secondAddress != null && secondAddress.Properties.Count == this.Properties.Count)
            {
                bool same = true;
                foreach (var key in this.Properties.Keys)
                {
                    if (!key.Equals(PropertyName.Id) && !key.Equals(PropertyName.AddressName))
                    {
                        if (!secondAddress.Properties.Contains(key) ||
                            !this.PropertiesEqualAsString(this.Properties[key], secondAddress.Properties[key]))
                        {
                            same = false;
                            break;
                        }
                    }
                }

                return same;
            }

            return false;
        }

        /// <summary>
        /// Returns a hash code for this instance.
        /// </summary>
        /// <returns>
        /// A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table. 
        /// </returns>
        public override int GetHashCode()
        {
            int hashCode = 0;
            foreach (var key in this.Properties.Keys)
            {
                if (!key.Equals(PropertyName.Id) && !key.Equals(PropertyName.AddressName))
                {
                    hashCode ^= this.GetPropertyHashCode(this.Properties[key]);
                }
            }

            return hashCode;
        }

        private int GetPropertyHashCode(object property)
        {
            if (property != null)
            {
                string objectasString = property.ToString();
                return objectasString.GetHashCode();
            }

            return 0;
        }

        private bool PropertiesEqualAsString(object firstProperty, object secondProperty)
        {
            string firstAsString = string.Empty;
            string secondAsString = string.Empty;
            if (firstProperty != null)
            {
                firstAsString = firstProperty.ToString();
            }

            if (secondProperty != null)
            {
                secondAsString = secondProperty.ToString();
            }

            if (firstAsString.Equals(secondAsString))
            {
                return true;
            }

            return false;
        }
    }
}