﻿//-----------------------------------------------------------------------
// <copyright file="LineItemViewModel.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.MVCSiteTemplate.Models
{
    using System.ComponentModel.DataAnnotations;

    /// <summary>
    /// View model for a Basket LineItem.
    /// </summary>
    public class LineItemViewModel : IImageEntity
    {
        /// <summary>
        /// Gets or sets the LineItem Id.
        /// </summary>
        public string Id { get; set; }

        /// <summary>
        /// Gets or sets the unique identifier of the Basket.  
        /// </summary>
        public string BasketId { get; set; }

        /// <summary>
        /// Gets or sets the parent BasketViewModel.
        /// </summary>
        public BasketViewModel BasketViewModel { get; set; }

        /// <summary>
        /// Gets or sets the Product Id of the current LineItem.
        /// </summary>
        public string ProductId { get; set; }

        /// <summary>
        /// Gets or sets the VariantId of the current LineItem.
        /// </summary>
        public string VariantId { get; set; }

        /// <summary>
        /// Gets or sets the associated ProductViewModel.
        /// </summary>
        public ProductViewModel ProductViewModel { get; set; }

        /// <summary>
        /// Gets or sets the Product and/or Variant Description.
        /// </summary>
        public string Description { get; set; }

        /// <summary>
        /// Gets or sets the Quantity of the current LineItem.
        /// </summary>
        public decimal? Quantity { get; set; }

        /// <summary>
        /// Gets or sets the ListPrice of the Product and/or Variant.
        /// </summary>
        [UIHint("Currency")]
        public decimal? ListPrice { get; set; }

        /// <summary>
        /// Gets or sets the ListPrice times the Quantity.
        /// </summary>
        [UIHint("Currency")]
        public decimal Subtotal { get; set; }

        /// <summary>
        /// Gets or sets the Total cost of the line item.
        /// </summary>
        [UIHint("Currency")]
        public decimal Total { get; set; }

        /// <summary>
        /// Gets or sets the image path, in ; separated format, i.e. "/images/1;/images/2"
        /// </summary>
        public string ProductImagePath { get; set; }

        /// <summary>
        /// Gets or sets the Status.
        /// </summary>
        public string Status { get; set; }

        /// <summary>
        /// Gets or sets the DisplayName.
        /// </summary>
        public string DisplayName { get; set; }

        /// <summary>
        /// Gets or sets the ImageFileName
        /// </summary>
        public string ImageFilename
        {
            get
            {
                return this.ProductImagePath;
            }

            set
            {
                this.ProductImagePath = value;
            }
        }
    }
}
