﻿//-----------------------------------------------------------------------
// <copyright file="ProductViewModel.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.MVCSiteTemplate.Models
{
    using System.Collections.Generic;

    /// <summary>
    /// A view model for a Product.
    /// </summary>
    public class ProductViewModel : IImageEntity
    {
        private List<VariantViewModel> variants = new List<VariantViewModel>();

        /// <summary>
        /// Gets or sets the Product Id.
        /// </summary>
        public string ProductId { get; set; }

        /// <summary>
        /// Gets or sets the Product Description.
        /// </summary>
        public string Description { get; set; }

        /// <summary>
        /// Gets or sets the Product DisplayName.
        /// </summary>
        public string DisplayName { get; set; }        

        /// <summary>
        /// Gets or sets the Product ListPrice.
        /// </summary>
        public decimal? ListPrice { get; set; }

        /// <summary>
        /// Gets or sets the Product ImageFileName.
        /// </summary>
        public string ImageFilename { get; set; }

        /// <summary>
        /// Gets or sets the default Quantity to be used when creating a new LineItem.
        /// </summary>
        public decimal? Quantity { get; set; }

        /// <summary>
        /// Gets or sets the list of VariantViewModels, representing the related Product Variants.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly", Justification = "It is readonly, but this allows object initializers to initialize the child collection, by using Clear and Add instead of just replacing the reference.")]
        public List<VariantViewModel> Variants 
        {
            get
            {
                return this.variants;
            }
            
            set
            {
                this.variants.Clear();
                this.variants.AddRange(value);
            }
        }
    }
}
