﻿//-----------------------------------------------------------------------
// <copyright file="CheckoutControllerPage.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A page to act as a controller for the Checkout functionality.  </summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.SharePoint.Support
{
    using System;
    using System.Collections.Generic;
    using System.Globalization;
    using System.Web;
    using System.Web.Services;
    using CommerceServer.Foundation;
    using CommerceServer.Foundation.RequestTemplates;
    using CommerceServerContrib.SharePoint.Support.Entities;
    using CommerceServerContrib.SharePoint.Support.Pages;
    using CommerceServerContrib.SharePoint.Support.RequestTemplates;
    using CommerceServerContrib.SharePoint.Support.ViewModels;
    using CommerceServerContrib.Web;
    using RT = CommerceServerContrib.SharePoint.Support.RequestTemplates;

    /// <summary>
    /// A page to act as a controller for the Checkout functionality.  
    /// </summary>
    public class CheckoutControllerPage : CommercePage
    {
        private const string ReadyForCheckout = "ReadyForCheckout";
        private const string DoRefreshBasket = "true";
        private const string OrderBasketType = "1";

        /// <summary>
        /// Recalculates basket totals, etc.
        /// </summary>
        /// <param name="billingFirstName">First name of the billing.</param>
        /// <param name="billingLastName">Last name of the billing.</param>
        /// <param name="billingLine1">The billing line1.</param>
        /// <param name="billingLine2">The billing line2.</param>
        /// <param name="billingCity">The billing city.</param>
        /// <param name="billingCountryRegionName">Name of the billing country region.</param>
        /// <param name="billingStateProvinceName">Name of the billing state province.</param>
        /// <param name="billingTelephone">The billing telephone.</param>
        /// <param name="shipToBillingAddress">The ship to billing address.</param>
        /// <param name="shippingFirstName">First name of the shipping.</param>
        /// <param name="shippingLastName">Last name of the shipping.</param>
        /// <param name="shippingLine1">The shipping line1.</param>
        /// <param name="shippingLine2">The shipping line2.</param>
        /// <param name="shippingCity">The shipping city.</param>
        /// <param name="shippingCountryRegionName">Name of the shipping country region.</param>
        /// <param name="shippingStateProvinceName">Name of the shipping state province.</param>
        /// <param name="shippingTelephone">The shipping_telephone.</param>
        /// <param name="shippingMethod">The shipping method.</param>
        /// <param name="paymentMethod">The payment method.</param>
        /// <param name="creditCardFirstName">First name of the credit card.</param>
        /// <param name="creditCardLastName">Last name of the credit card.</param>
        /// <param name="creditCardNumber">The credit card number.</param>
        /// <param name="creditCardMonth">The credit card month.</param>
        /// <param name="creditCardYear">The cc_year.</param>
        /// <param name="creditCardVerification">The cc_credit card verification.</param>
        /// <param name="cleanBasket">The clean basket.</param>
        /// <returns>
        /// Simplified WebMethodResponse.
        /// </returns>
        [WebMethod]
        public static WebMethodResponse Recalculate(
            string billingFirstName,
            string billingLastName,
            string billingLine1,
            string billingLine2,
            string billingCity,
            string billingCountryRegionName,
            string billingStateProvinceName,
            string billingTelephone,
            string shipToBillingAddress,
            string shippingFirstName,
            string shippingLastName,
            string shippingLine1,
            string shippingLine2,
            string shippingCity,
            string shippingCountryRegionName,
            string shippingStateProvinceName,
            string shippingTelephone,
            string shippingMethod,
            string paymentMethod,
            string creditCardFirstName,
            string creditCardLastName,
            string creditCardNumber,
            string creditCardMonth,
            string creditCardYear,
            string creditCardVerification,
            string cleanBasket)
        {
            var basketViewModel = BuildBasketViewModel(
                HttpUtility.UrlDecode(billingFirstName),
                HttpUtility.UrlDecode(billingLastName),
                HttpUtility.UrlDecode(billingLine1),
                HttpUtility.UrlDecode(billingLine2),
                HttpUtility.UrlDecode(billingCity),
                HttpUtility.UrlDecode(billingCountryRegionName),
                HttpUtility.UrlDecode(billingStateProvinceName),
                HttpUtility.UrlDecode(billingTelephone),
                HttpUtility.UrlDecode(shippingFirstName),
                HttpUtility.UrlDecode(shippingLastName),
                HttpUtility.UrlDecode(shippingLine1),
                HttpUtility.UrlDecode(shippingLine2),
                HttpUtility.UrlDecode(shippingCity),
                HttpUtility.UrlDecode(shippingCountryRegionName),
                HttpUtility.UrlDecode(shippingStateProvinceName),
                HttpUtility.UrlDecode(shippingTelephone),
                HttpUtility.UrlDecode(shippingMethod),
                HttpUtility.UrlDecode(paymentMethod),
                HttpUtility.UrlDecode(creditCardFirstName),
                HttpUtility.UrlDecode(creditCardLastName),
                HttpUtility.UrlDecode(creditCardNumber),
                HttpUtility.UrlDecode(creditCardMonth),
                HttpUtility.UrlDecode(creditCardYear),
                HttpUtility.UrlDecode(creditCardVerification),
                HttpUtility.UrlDecode(shipToBillingAddress));

            var returnValue = new WebMethodResponse();

            var response = UpdateBasketAndGetOtherDataInReturn(
                basketViewModel, 
                PresentationServiceLocator.Current.SiteContext.DefaultBasketType.ToString(CultureInfo.InvariantCulture), 
                ReadyForCheckout,
                cleanBasket);

            if (response != null && response.Count > 0)
            {
                // state handling
                var serviceAdapterResponse = response[0] as ServiceAdapterResponse<object>;
                var responseList = serviceAdapterResponse.Value as List<object>;
                var basketList = responseList[0] as List<CommerceEntity>;
                var newBasket = new Basket(basketList[0]);

                newBasket.PaymentMethod = basketViewModel.CreditCardPayment;
                newBasket.UserBillingAsShipping = basketViewModel.UseBillingAddressForShippingAddress;

                basketList[0] = newBasket.ToCommerceEntity();

                returnValue.HtmlPayload = RenderControl("/_layouts/CommerceServerContrib.Farm/Checkout/Checkout.ascx", response);
                returnValue.Success = true;
                return returnValue;
            }

            returnValue.Success = false;
            return returnValue;
        }

        /// <summary>
        /// Does a basket checkout.
        /// </summary>
        /// <param name="billingFirstName">First name of the billing.</param>
        /// <param name="billingLastName">Last name of the billing.</param>
        /// <param name="billingLine1">The billing line1.</param>
        /// <param name="billingLine2">The billing line2.</param>
        /// <param name="billingCity">The billing city.</param>
        /// <param name="billingCountryRegionName">Name of the billing country region.</param>
        /// <param name="billingStateProvinceName">Name of the billing state province.</param>
        /// <param name="billingTelephone">The billing telephone.</param>
        /// <param name="shipToBillingAddress">The ship to billing address.</param>
        /// <param name="shippingFirstName">First name of the shipping.</param>
        /// <param name="shippingLastName">Last name of the shipping.</param>
        /// <param name="shippingLine1">The shipping line1.</param>
        /// <param name="shippingLine2">The shipping line2.</param>
        /// <param name="shippingCity">The shipping city.</param>
        /// <param name="shippingCountryRegionName">Name of the shipping country region.</param>
        /// <param name="shippingStateProvinceName">Name of the shipping state province.</param>
        /// <param name="shippingTelephone">The shipping telephone.</param>
        /// <param name="shippingMethod">The shipping method.</param>
        /// <param name="paymentMethod">The payment method.</param>
        /// <param name="creditCardFirstName">First name of the credit card.</param>
        /// <param name="creditCardLastName">Last name of the credit card.</param>
        /// <param name="creditCardNumber">The credit card number.</param>
        /// <param name="creditCardMonth">The credit card month.</param>
        /// <param name="creditCardYear">The credit card year.</param>
        /// <param name="creditCardVerification">The credit card verification.</param>
        /// <param name="cleanBasket">The clean basket.</param>
        /// <returns>
        /// Simplified WebMethodResponse.
        /// </returns>
        [WebMethod]
        public static WebMethodResponse Checkout(
            string billingFirstName,
            string billingLastName,
            string billingLine1,
            string billingLine2,
            string billingCity,
            string billingCountryRegionName,
            string billingStateProvinceName,
            string billingTelephone,
            string shipToBillingAddress,
            string shippingFirstName,
            string shippingLastName,
            string shippingLine1,
            string shippingLine2,
            string shippingCity,
            string shippingCountryRegionName,
            string shippingStateProvinceName,
            string shippingTelephone,
            string shippingMethod,
            string paymentMethod,
            string creditCardFirstName,
            string creditCardLastName,
            string creditCardNumber,
            string creditCardMonth,
            string creditCardYear,
            string creditCardVerification,
            string cleanBasket)
        {
            var basketViewModel = BuildBasketViewModel(
                HttpUtility.UrlDecode(billingFirstName),
                HttpUtility.UrlDecode(billingLastName),
                HttpUtility.UrlDecode(billingLine1),
                HttpUtility.UrlDecode(billingLine2),
                HttpUtility.UrlDecode(billingCity),
                HttpUtility.UrlDecode(billingCountryRegionName),
                HttpUtility.UrlDecode(billingStateProvinceName),
                HttpUtility.UrlDecode(billingTelephone),
                HttpUtility.UrlDecode(shippingFirstName),
                HttpUtility.UrlDecode(shippingLastName),
                HttpUtility.UrlDecode(shippingLine1),
                HttpUtility.UrlDecode(shippingLine2),
                HttpUtility.UrlDecode(shippingCity),
                HttpUtility.UrlDecode(shippingCountryRegionName),
                HttpUtility.UrlDecode(shippingStateProvinceName),
                HttpUtility.UrlDecode(shippingTelephone),
                HttpUtility.UrlDecode(shippingMethod),
                HttpUtility.UrlDecode(paymentMethod),
                HttpUtility.UrlDecode(creditCardFirstName),
                HttpUtility.UrlDecode(creditCardLastName),
                HttpUtility.UrlDecode(creditCardNumber),
                HttpUtility.UrlDecode(creditCardMonth),
                HttpUtility.UrlDecode(creditCardYear),
                HttpUtility.UrlDecode(creditCardVerification),
                HttpUtility.UrlDecode(shipToBillingAddress));

            var response = UpdateBasket(basketViewModel, OrderBasketType, ReadyForCheckout, cleanBasket);
            var returnValue = new WebMethodResponse();

            if (response != null && response.Count > 0)
            {
                var basket = new Basket(response[0]);
                returnValue.Success = true;
                returnValue.RedirectUrl = "/pages/submitted.aspx?orderId=" + basket.OrderNumber;
            }
            else
            {
                returnValue.Success = false;
            }

            return returnValue;
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA1806:DoNotIgnoreMethodResults", MessageId = "System.Boolean.TryParse(System.String,System.Boolean@)", Justification = "Default is fine.")]
        private static BasketViewModel BuildBasketViewModel(
            string billing_firstName, 
            string billing_lastName, 
            string billing_line1, 
            string billing_line2, 
            string billing_city, 
            string billing_countryRegionName, 
            string billing_stateProvinceName, 
            string billing_telephone, 
            string shipping_firstName, 
            string shipping_lastName, 
            string shipping_line1, 
            string shipping_line2, 
            string shipping_city, 
            string shipping_countryRegionName, 
            string shipping_stateProvinceName, 
            string shipping_telephone, 
            string shippingMethod, 
            string paymentMethod, 
            string cc_firstName, 
            string cc_lastName, 
            string cc_creditCardNumber, 
            string cc_month, 
            string cc_year, 
            string cc_creditCardVerification,
            string shipToBillingAddress)
        {
            var basketViewModel = new BasketViewModel();
            var billingAddress = new AddressOrders();
            billingAddress.AddressName = "Billing";
            billingAddress.FirstName = billing_firstName;
            billingAddress.LastName = billing_lastName;
            billingAddress.Line1 = billing_line1;
            billingAddress.Line2 = billing_line2;
            billingAddress.City = billing_city;
            billingAddress.CountryRegionName = billing_countryRegionName;
            billingAddress.StateProvinceName = billing_stateProvinceName;
            billingAddress.Telephone = billing_telephone;

            var shippingAddress = new AddressOrders();
            shippingAddress.AddressName = "Shipping";
            shippingAddress.FirstName = shipping_firstName;
            shippingAddress.LastName = shipping_lastName;
            shippingAddress.Line1 = shipping_line1;
            shippingAddress.Line2 = shipping_line2;
            shippingAddress.City = shipping_city;
            shippingAddress.CountryRegionName = shipping_countryRegionName;
            shippingAddress.StateProvinceName = shipping_stateProvinceName;
            shippingAddress.Telephone = shipping_telephone;

            basketViewModel.BillingAddress = billingAddress;
            basketViewModel.ShippingAddress = shippingAddress;

            basketViewModel.CreditCardPayment.FirstName = cc_firstName;
            basketViewModel.CreditCardPayment.LastName = cc_lastName;
            basketViewModel.CreditCardPayment.CreditCardNumber = cc_creditCardNumber;
            basketViewModel.CreditCardPayment.CreditCardVerification = cc_creditCardVerification;
            basketViewModel.CreditCardPayment.Month = cc_month;
            basketViewModel.CreditCardPayment.Year = cc_year;

            basketViewModel.PaymentId = paymentMethod;
            basketViewModel.ShippingMethodId = shippingMethod;
            
            bool usebillingForShipping = false;
            bool.TryParse(shipToBillingAddress, out usebillingForShipping);

            basketViewModel.UseBillingAddressForShippingAddress = usebillingForShipping;

            return basketViewModel;
        }

        private static void CopyBillingAddressIntoShippingAddress(BasketViewModel basket)
        {
            var newShippingAddress = new AddressOrders();
            foreach (var property in basket.BillingAddress.Properties)
            {
                newShippingAddress.Properties[property.Key] = property.Value;
            }

            basket.ShippingAddress = newShippingAddress;
        }

        private static List<object> UpdateBasketAndGetOtherDataInReturn(BasketViewModel basketViewModel, string basketType, string basketStatus, string cleanBasket)
        {
            var shippingAddressId = Guid.NewGuid().ToString();
            var billingAddressId = Guid.NewGuid().ToString();

            CleanBasketIfRequired(cleanBasket);

            if (basketViewModel.UseBillingAddressForShippingAddress)
            {
                CopyBillingAddressIntoShippingAddress(basketViewModel);
            }

            var parameters = new RequestTemplateParameterCollection();

            parameters.Add(new RequestTemplateParameter("Name", PresentationServiceLocator.Current.SiteContext.DefaultBasketName, RequestTemplateParameterType.Search));
            parameters.Add(new RequestTemplateParameter("UserId", PresentationServiceLocator.Current.SiteContext.UserId, RequestTemplateParameterType.Search));
            parameters.Add(new RequestTemplateParameter("BasketType", PresentationServiceLocator.Current.SiteContext.DefaultBasketType.ToString(CultureInfo.InvariantCulture), RequestTemplateParameterType.Search));
            parameters.Add(new RequestTemplateParameter("BasketType", basketType, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("Status", basketStatus, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("RefreshBasket", DoRefreshBasket, RequestTemplateParameterType.Option));
            parameters.Add(new RequestTemplateParameter("ShippingAddressId", shippingAddressId, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingAddressName", basketViewModel.ShippingAddress.AddressName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingFirstName", basketViewModel.ShippingAddress.FirstName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingLastName", basketViewModel.ShippingAddress.LastName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingLine1", basketViewModel.ShippingAddress.Line1, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingLine2", basketViewModel.ShippingAddress.Line2, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingCity", basketViewModel.ShippingAddress.City, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingStateProvinceCode", basketViewModel.ShippingAddress.StateProvinceCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingStateProvinceName", basketViewModel.ShippingAddress.StateProvinceName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingZipPostalCode", basketViewModel.ShippingAddress.ZipPostalCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingCountryRegionCode", basketViewModel.ShippingAddress.CountryRegionCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingCountryRegionName", basketViewModel.ShippingAddress.CountryRegionName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingTelephone", basketViewModel.ShippingAddress.Telephone, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingAddressId", billingAddressId, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingAddressName", basketViewModel.BillingAddress.AddressName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingFirstName", basketViewModel.BillingAddress.FirstName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingLastName", basketViewModel.BillingAddress.LastName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingLine1", basketViewModel.BillingAddress.Line1, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingLine2", basketViewModel.BillingAddress.Line2, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingCity", basketViewModel.BillingAddress.City, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingStateProvinceCode", basketViewModel.BillingAddress.StateProvinceCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingStateProvinceName", basketViewModel.BillingAddress.StateProvinceName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingZipPostalCode", basketViewModel.BillingAddress.ZipPostalCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingCountryRegionCode", basketViewModel.BillingAddress.CountryRegionCode, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingCountryRegionName", basketViewModel.BillingAddress.CountryRegionName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("BillingTelephone", basketViewModel.BillingAddress.Telephone, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ShippingMethodId", basketViewModel.ShippingMethodId, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ExpirationMonth", basketViewModel.CreditCardPayment.Month, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ExpirationYear", basketViewModel.CreditCardPayment.Year, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("CustomerName", basketViewModel.CreditCardPayment.FirstName + " " + basketViewModel.CreditCardPayment.LastName, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("CreditCardNumber", basketViewModel.CreditCardPayment.CreditCardNumber, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("ValidationCode", basketViewModel.CreditCardPayment.CreditCardVerification, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("CreditCardBillingAddressId", billingAddressId, RequestTemplateParameterType.PropertiesToSet));
            parameters.Add(new RequestTemplateParameter("PaymentMethodId", basketViewModel.PaymentId, RequestTemplateParameterType.Search));
            var controller = ControllerFactory.GetController("Orders");
            var serviceAdapterResponse = controller.ProcessRequest("UpdateBasketWithPaymentAndShippingMethods", parameters, "POCO");

            if (serviceAdapterResponse.Succeeded)
            {
                var returnList = new List<object>();
                returnList.Add(serviceAdapterResponse);
                return returnList;
            }

            return null;
        }

        private static List<CommerceEntity> UpdateBasket(BasketViewModel basketViewModel, string basketType, string basketStatus, string cleanBasket)
        {
            var shippingAddressId = Guid.NewGuid().ToString();
            var billingAddressId = Guid.NewGuid().ToString();
            
            CleanBasketIfRequired(cleanBasket);

            if (basketViewModel.UseBillingAddressForShippingAddress)
            {
                CopyBillingAddressIntoShippingAddress(basketViewModel);
            }

            #region Update Basket
            var result = RT.Orders.UpdateBasket(
                PresentationServiceLocator.Current.SiteContext.DefaultBasketName,
                PresentationServiceLocator.Current.SiteContext.UserId,
                PresentationServiceLocator.Current.SiteContext.DefaultBasketType.ToString(CultureInfo.InvariantCulture),
                basketType,
                basketStatus,
                DoRefreshBasket,
                shippingAddressId,
                basketViewModel.ShippingAddress.AddressName,
                basketViewModel.ShippingAddress.FirstName,
                basketViewModel.ShippingAddress.LastName,
                basketViewModel.ShippingAddress.Line1,
                basketViewModel.ShippingAddress.Line2,
                basketViewModel.ShippingAddress.City,
                basketViewModel.ShippingAddress.StateProvinceCode,
                basketViewModel.ShippingAddress.StateProvinceName,
                basketViewModel.ShippingAddress.ZipPostalCode,
                basketViewModel.ShippingAddress.CountryRegionCode,
                basketViewModel.ShippingAddress.CountryRegionName,
                basketViewModel.ShippingAddress.Telephone,
                billingAddressId,
                basketViewModel.BillingAddress.AddressName,
                basketViewModel.BillingAddress.FirstName,
                basketViewModel.BillingAddress.LastName,
                basketViewModel.BillingAddress.Line1,
                basketViewModel.BillingAddress.Line2,
                basketViewModel.BillingAddress.City,
                basketViewModel.BillingAddress.StateProvinceCode,
                basketViewModel.BillingAddress.StateProvinceName,
                basketViewModel.BillingAddress.ZipPostalCode,
                basketViewModel.BillingAddress.CountryRegionCode,
                basketViewModel.BillingAddress.CountryRegionName,
                basketViewModel.BillingAddress.Telephone,
                basketViewModel.ShippingMethodId,
                basketViewModel.CreditCardPayment.Month,
                basketViewModel.CreditCardPayment.Year,
                basketViewModel.CreditCardPayment.FirstName + " " + basketViewModel.CreditCardPayment.LastName,
                basketViewModel.CreditCardPayment.CreditCardNumber,
                basketViewModel.CreditCardPayment.CreditCardVerification,
                billingAddressId,
                basketViewModel.PaymentId);
            #endregion

            return result;
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA1806:DoNotIgnoreMethodResults", MessageId = "System.Boolean.TryParse(System.String,System.Boolean@)", Justification = "The default value is fine.")]
        private static void CleanBasketIfRequired(string cleanBasket)
        {
            bool clean = false;
            bool.TryParse(cleanBasket, out clean);

            if (clean)
            {
                RT.Orders.CleanBasket(
                    PresentationServiceLocator.Current.SiteContext.DefaultBasketName,
                    PresentationServiceLocator.Current.SiteContext.UserId,
                    PresentationServiceLocator.Current.SiteContext.DefaultBasketType.ToString(CultureInfo.InvariantCulture));
            }
        }
    }
}
