﻿//-----------------------------------------------------------------------
// <copyright file="CommercePage.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A base page for Commerce Server SharePoint application pages.</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.SharePoint.Support
{
    using System.Collections.Generic;
    using System.Globalization;
    using System.IO;
    using System.Web;
    using System.Web.UI;
    using CommerceServer.Foundation;
    using CommerceServer.Foundation.RequestTemplates;
    using CommerceServerContrib.CrossTier.Interfaces;
    using Microsoft.SharePoint.WebControls;

    /// <summary>
    /// A base page for Commerce Server SharePoint application pages.
    /// </summary>
    public class CommercePage : LayoutsPageBase
    {
        /// <summary>
        /// Renders the control.
        /// </summary>
        /// <param name="path">The path.</param>
        /// <param name="responseData">The response data.</param>
        /// <returns>String HTML.</returns>
        protected static string RenderControl(string path, List<object> responseData)
        {
            using (var page = new Page())
            {
                var userControl = (UserControl)page.LoadControl(path);

                using (var writer = new StringWriter(CultureInfo.InvariantCulture))
                {
                    page.Controls.Add(userControl);

                    if (responseData != null)
                    {
                        ((IBaseControl)userControl).ResponseData = responseData;
                    }

                    HttpContext.Current.Server.Execute(page, writer, false);
                    return writer.ToString();
                }
            }
        }

        /// <summary>
        /// Converts a basket list to ServiceResponse data in a list so it can be rendered by the web part.
        /// </summary>
        /// <param name="basketList">The basket list.</param>
        /// <returns>A list of ServerAdapterResponses. </returns>
        protected static List<object> BasketListToResponseData(List<CommerceEntity> basketList)
        {
            var responseData = new List<object>();
            ServiceAdapterResponse<object> adapterResponse = new ServiceAdapterResponse<object>();

            adapterResponse.Value = basketList;
            responseData.Add(adapterResponse);
            return responseData;
        }
    }
}
