﻿//-----------------------------------------------------------------------
// <copyright file="ControllerFactory.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A simple factory for returning the Commerce Server Request Template Factory based on Area.</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.SharePoint.Support.RequestTemplates
{
    using CommerceServerContrib.CrossTier.Interfaces.Controllers;
    using CommerceServerContrib.Web.Controllers;

    /// <summary>
    /// A simple factory for returning the Commerce Server Request Template Factory based on Area.
    /// </summary>
    public static class ControllerFactory
    {
        /// <summary>
        /// Method which returns the right controller for the area. 
        /// </summary>
        /// <param name="area">Area (Catalog, Profiles, etc.) required.</param>
        /// <returns>Commerce Server Contrib Controller instance.</returns>
        public static BaseController<IRequestTemplateController> GetController(string area)
        {
            switch (area)
            {
                case "Catalog":
                    return new CatalogController();
                case "Orders":
                    return new OrdersController();
                case "Marketing":
                    return new MarketingController();
                default:
                    return new CatalogController();
            }
        }
    }
}
