﻿//-----------------------------------------------------------------------
// <copyright file="PaymentMethodViewModel.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A ViewModel for displaying Payments.</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.SharePoint.Support.ViewModels
{
    using CommerceServer.Foundation;

    /// <summary>
    /// A ViewModel for displaying Payments.
    /// </summary>
    public class PaymentMethodViewModel
    {
        #region CommerceEntity Keys
        private const string FirstNameKey = "FirstName";
        private const string LastNameKey = "LastName";
        private const string CreditCardNumberKey = "CreditCardNumber";
        private const string MonthKey = "Month";
        private const string YearKey = "Year";
        private const string CreditCardVerificationKey = "CreditCardVerification";
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="PaymentMethodViewModel" /> class.
        /// </summary>
        public PaymentMethodViewModel()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PaymentMethodViewModel" /> class.
        /// </summary>
        /// <param name="commerceEntity">A Commerce Entity that has properties which are copied into the View Model.</param>
        public PaymentMethodViewModel(CommerceEntity commerceEntity)
        {
            this.FirstName = commerceEntity.Properties[FirstNameKey] as string;
            this.LastName = commerceEntity.Properties[LastNameKey] as string;
            this.CreditCardNumber = commerceEntity.Properties[CreditCardNumberKey] as string;
            this.Month = commerceEntity.Properties[MonthKey] as string;
            this.Year = commerceEntity.Properties[YearKey] as string;
            this.CreditCardVerification = commerceEntity.Properties[CreditCardVerificationKey] as string;
        }

        /// <summary>
        /// Gets or sets the first name.
        /// </summary>
        /// <value>
        /// The first name.
        /// </value>
        public string FirstName { get; set; }

        /// <summary>
        /// Gets or sets the last name.
        /// </summary>
        /// <value>
        /// The last name.
        /// </value>
        public string LastName { get; set; }

        /// <summary>
        /// Gets or sets the credit card number.
        /// </summary>
        /// <value>
        /// The credit card number.
        /// </value>
        public string CreditCardNumber { get; set; }

        /// <summary>
        /// Gets or sets the month.
        /// </summary>
        /// <value>
        /// The month.
        /// </value>
        public string Month { get; set; }

        /// <summary>
        /// Gets or sets the year.
        /// </summary>
        /// <value>
        /// The year.
        /// </value>
        public string Year { get; set; }

        /// <summary>
        /// Gets or sets the credit card verification number.
        /// </summary>
        /// <value>
        /// The credit card verification number.
        /// </value>
        public string CreditCardVerification { get; set; }

        /// <summary>
        /// Converts the payment method view model to a Commerce Entity;
        /// </summary>
        /// <returns>CommerceEntity based on the PaymentMethodViewModel.</returns>
        public CommerceEntity ToCommerceEntity()
        {
            var ce = new CommerceEntity();
            ce.Properties = new CommercePropertyCollection();
            ce.Properties.Add(FirstNameKey, this.FirstName);
            ce.Properties.Add(LastNameKey, this.LastName);
            ce.Properties.Add(CreditCardNumberKey, this.CreditCardNumber);
            ce.Properties.Add(MonthKey, this.Month);
            ce.Properties.Add(YearKey, this.Year);
            ce.Properties.Add(CreditCardVerificationKey, this.CreditCardVerification);

            return ce;
        }
    }
}
