﻿//-----------------------------------------------------------------------
// <copyright file="AnonymousUser.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the AnonymousUser class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the anonymousUser configuration element.
    /// </summary>
    public class AnonymousUser
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AnonymousUser"/> class.
        /// </summary>
        /// <param name="element">The <see cref="AnonymousUserElement"/> this class is mapped to.</param>
        public AnonymousUser(AnonymousUserElement element)
        {
            if (element != null)
            {
                this.CookieName = element.CookieName;
                this.SlidingExpiration = element.SlidingExpiration;
                this.Timeout = element.Timeout;
            }
            else
            {
                this.CookieName = AnonymousUserElement.CookieNameDefaultValue;
                this.SlidingExpiration = AnonymousUserElement.SlidingExpirationDefaultValue;
                this.Timeout = AnonymousUserElement.TimeoutDefaultValue;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="AnonymousUser"/> class.
        /// </summary>
        public AnonymousUser()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the cookie name.
        /// </summary>
        public string CookieName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets a value indicating whether a sliding expiration algorighm will be used for cookie expiration.
        /// </summary>
        public bool SlidingExpiration
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the anonymous user cookie timeout.
        /// </summary>
        public TimeSpan Timeout
        {
            get;
            private set;
        }
    }
}
