﻿//-----------------------------------------------------------------------
// <copyright file="Argument.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the Argument class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the argument configuration element.
    /// </summary>
    public class Argument
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Argument"/> class.
        /// </summary>
        /// <param name="element">The <see cref="ArgumentElement"/> this class is mapped to.</param>
        public Argument(ArgumentElement element)
        {
            if (element != null)
            {
                this.Key = element.Key;
                this.Value = element.Value;
            }
            else
            {
                this.Key = null;
                this.Value = null;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Argument"/> class.
        /// </summary>
        public Argument()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the unique key name of this argument.
        /// </summary>
        public string Key
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the value of this argument.
        /// </summary>
        public string Value
        {
            get;
            private set;
        }
    }
}
