﻿//-----------------------------------------------------------------------
// <copyright file="ArgumentDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the ArgumentDictionary class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the arguments configuration element collection.
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2237:MarkISerializableTypesWithSerializable", Justification = "This class is not intended to be serialized.")]
    public class ArgumentDictionary : ConfigurationMappedDictionary<Argument>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ArgumentDictionary"/> class.
        /// </summary>
        /// <param name="element">The <see cref="ArgumentElementCollection"/> this class is mapped to.</param>
        public ArgumentDictionary(ArgumentElementCollection element)
            : base(element)
        {
            if (element != null)
            {
                foreach (ArgumentElement childElement in element)
                {
                    this[childElement.Key] = new Argument(childElement);
                }
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ArgumentDictionary"/> class.
        /// </summary>
        public ArgumentDictionary()
            : this((ArgumentElementCollection)null)
        {
        }
    }
}
