﻿//-----------------------------------------------------------------------
// <copyright file="ConfigurationMappedDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the ConfigurationMappedDictionary class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Configuration;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents a collection that is mapped to a configuration element collection.
    /// </summary>
    /// <typeparam name="T">The type of the items in the collection.</typeparam>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2237:MarkISerializableTypesWithSerializable", Justification = "This class is not intended to be serialized.")]
    public class ConfigurationMappedDictionary<T> : Dictionary<string, T>, IConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurationMappedDictionary&lt;T&gt;"/> class.
        /// </summary>
        /// <param name="element">The configuration element this class is mapped to.</param>
        protected ConfigurationMappedDictionary(ConfigurationElement element)
            : base(StringComparer.OrdinalIgnoreCase)
        {
            this.IsMappedToConfiguration = (element != null);

            BasePresentationElementCollection presentationElement = element as BasePresentationElementCollection;
            if (presentationElement != null)
            {
                this.IsMappedToConfiguration = this.IsMappedToConfiguration && presentationElement.IsMappedToXml;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurationMappedDictionary&lt;T&gt;"/> class with serialized data.
        /// </summary>
        /// <param name="info">A SerializationInfo object containing the information required to serialize this class.</param>
        /// <param name="context">A StreamingContext structure containing the source and destination of the serialized stream associated with this class.</param>
        protected ConfigurationMappedDictionary(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context)
            : base(info, context)
        {
            this.IsMappedToConfiguration = info.GetBoolean("IsMappedToConfiguration");
        }

        /// <summary>
        /// Gets a value indicating whether this collection was mapped to a configuration element.
        /// </summary>
        public bool IsMappedToConfiguration
        {
            get;
            private set;
        }
    }
}
