﻿//-----------------------------------------------------------------------
// <copyright file="ConfigurationMappedItem.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the ConfigurationMappedItem class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Configuration;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents an item that is mapped to a configuration element.
    /// </summary>
    public abstract class ConfigurationMappedItem : IConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurationMappedItem"/> class.
        /// </summary>
        /// <param name="element">The configuration element this class is mapped to.</param>
        protected ConfigurationMappedItem(ConfigurationElement element)
        {
            this.IsMappedToConfiguration = (element != null);

            BasePresentationElement presentationElement = element as BasePresentationElement;
            if (presentationElement != null)
            {
                this.IsMappedToConfiguration = this.IsMappedToConfiguration && presentationElement.IsMappedToXml;
            }
        }

        /// <summary>
        /// Gets a value indicating whether this item was mapped to a configuration element.
        /// </summary>
        public bool IsMappedToConfiguration
        {
            get;
            private set;
        }
    }
}
