﻿//-----------------------------------------------------------------------
// <copyright file="EncryptionKey.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the EncryptionKey class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the key configuration element
    /// </summary>
    public class EncryptionKey : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionKey"/> class.
        /// </summary>
        /// <param name="element">The <see cref="EncryptionKeyElement"/> this class is mapped t.</param>
        public EncryptionKey(EncryptionKeyElement element)
            : base(element)
        {
            if (element != null)
            {
                this.Name = element.Name;
                this.Value = element.Value;
            }
            else
            {
                this.Name = null;
                this.Value = null;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionKey"/> class.
        /// </summary>
        public EncryptionKey()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the name of the encryption key.
        /// </summary>
        public string Name
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the value of the encryption key.
        /// </summary>
        public string Value
        {
            get;
            private set;
        }
    }
}
