﻿//-----------------------------------------------------------------------
// <copyright file="EncryptionKeyDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the EncryptionKeyDictionary class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the a collection of <see cref="EncryptionKey"/> items.
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2237:MarkISerializableTypesWithSerializable", Justification = "This class is not intended to be serialized.")]
    public class EncryptionKeyDictionary : ConfigurationMappedDictionary<EncryptionKey>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionKeyDictionary"/> class.
        /// </summary>
        /// <param name="element">The <see cref="EncryptionKeyElementCollection"/> this class is mapped to.</param>
        public EncryptionKeyDictionary(EncryptionKeyElementCollection element)
            : base(element)
        {
            if (element != null)
            {
                foreach (EncryptionKeyElement childElement in element)
                {
                    this[childElement.Name] = new EncryptionKey(childElement);
                }
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionKeyDictionary"/> class.
        /// </summary>
        public EncryptionKeyDictionary()
            : this(null)
        {
        }
    }
}
