﻿//-----------------------------------------------------------------------
// <copyright file="EncryptionProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the EncryptionProvider class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the encryptionKey configuration element.
    /// </summary>
    public class EncryptionProvider : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionProvider"/> class.
        /// </summary>
        /// <param name="element">The <see cref="EncryptionKeyElementCollection"/> this class is mapped to.</param>
        public EncryptionProvider(EncryptionKeyElementCollection element)
            : base(element)
        {
            if (element != null)
            {
                this.Name = element.Name;
                this.EncryptionProviderType = element.EncryptionProviderType;
                this.EncryptionKeys = new EncryptionKeyDictionary(element);
            }
            else
            {
                this.Name = null;
                this.EncryptionProviderType = null;
                this.EncryptionKeys = new EncryptionKeyDictionary();
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionProvider"/> class.
        /// </summary>
        public EncryptionProvider()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the friendly name of the encryption key provider.
        /// </summary>
        public string Name
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the encryption provider type name.
        /// </summary>
        public string EncryptionProviderType
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the encryption keys configured for this provider.
        /// </summary>
        public EncryptionKeyDictionary EncryptionKeys
        {
            get;
            private set;
        }
    }
}
