﻿//-----------------------------------------------------------------------
// <copyright file="EncryptionProviderDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the EncryptionProviderDictionary class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the encryptionKeys confiuration element
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2237:MarkISerializableTypesWithSerializable", Justification = "This class is not intended to be serialized.")]
    public class EncryptionProviderDictionary : ConfigurationMappedDictionary<EncryptionProvider>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionProviderDictionary"/> class.
        /// </summary>
        /// <param name="element">The <see cref="EncryptionKeysElementCollection"/> this class is mapped to.</param>
        public EncryptionProviderDictionary(EncryptionKeysElementCollection element)
            : base(element)
        {
            if (element != null)
            {
                foreach (EncryptionKeyElementCollection childElement in element)
                {
                    this[childElement.Name] = new EncryptionProvider(childElement);
                }
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionProviderDictionary"/> class.
        /// </summary>
        public EncryptionProviderDictionary()
            : this(null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="EncryptionProviderDictionary"/> class with serialized data.
        /// </summary>
        /// <param name="info">A SerializationInfo object containing the information required to serialize this class.</param>
        /// <param name="context">A StreamingContext structure containing the source and destination of the serialized stream associated with this class.</param>
        protected EncryptionProviderDictionary(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context)
            : base(info, context)
        {
        }
    }
}
