﻿//-----------------------------------------------------------------------
// <copyright file="ExceptionHandling.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the ExceptionHandling class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the exceptionHandling configuration element
    /// </summary>
    public class ExceptionHandling : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ExceptionHandling"/> class.
        /// </summary>
        /// <param name="element">The <see cref="ExceptionHandlingElement"/> that is mapped to this class.</param>
        public ExceptionHandling(ExceptionHandlingElement element)
            : base(element)
        {
            if (element != null)
            {
                this.DefaultExceptionPolicy = element.DefaultExceptionPolicy;
            }
            else
            {
                this.DefaultExceptionPolicy = null;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ExceptionHandling"/> class.
        /// </summary>
        public ExceptionHandling()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the name of the default exception policy for this brand.
        /// </summary>
        public string DefaultExceptionPolicy
        {
            get;
            private set;
        }
    }
}
