﻿//-----------------------------------------------------------------------
// <copyright file="RegisteredUser.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the RegisteredUser class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the registeredUser configuration element.
    /// </summary>
    public class RegisteredUser : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RegisteredUser"/> class.
        /// </summary>
        /// <param name="element">The <see cref="RegisteredUserElement"/> that is mapped to this class.</param>
        public RegisteredUser(RegisteredUserElement element)
            : base(element)
        {
            if (element != null)
            {
                this.NonSecureEncryptionKeyName = element.NonSecureEncryptionKeyName;
                this.NonSecuredCookieName = element.NonSecuredCookieName;
                this.SecureEncryptionKeyName = element.SecureEncryptionKeyName;
                this.SecureCookieName = element.CookieName;
                this.RememberMeCookieName = element.RememberMeCookieName;
                this.SslMode = element.SslMode;
                this.ValidateIdentity = element.ValidateIdentity;
            }
            else
            {
                this.NonSecuredCookieName = RegisteredUserElement.NonSecuredCookieNameDefaultValue;
                this.NonSecureEncryptionKeyName = null;
                this.SecureCookieName = RegisteredUserElement.CookieNameDefaultValue;
                this.SecureEncryptionKeyName = null;
                this.RememberMeCookieName = RegisteredUserElement.RememberMeCookieNameDefaultValue;
                this.SslMode = RegisteredUserElement.SslModeDefaultValue;
                this.ValidateIdentity = RegisteredUserElement.ValidateIdentityDefaultValue;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RegisteredUser"/> class.
        /// </summary>
        public RegisteredUser()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the name of the secure cookie used to hold reistered user information.
        /// </summary>
        public string SecureCookieName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the encryption key used to encrypt the secure cookie.
        /// </summary>
        public string SecureEncryptionKeyName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the remember me cookie.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Justification = "For future development.")]
        public string RememberMeCookieName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the non-secure cookie used to hold registered user information.
        /// </summary>
        public string NonSecuredCookieName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the encryption key used to encrypt the non-secure cookie.
        /// </summary>
        public string NonSecureEncryptionKeyName
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the SSL mode used to determine when the secure registered user cookie is allowed to be sent over a non-secure connection.
        /// </summary>
        public CommerceServerContrib.CrossTier.Helpers.UserCookieSslMode SslMode
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets a value indicating whether the identity stored in the registered user cookie should be validated.
        /// </summary>
        public bool ValidateIdentity
        {
            get;
            private set;
        }
    }
}
