﻿//-----------------------------------------------------------------------
// <copyright file="SecurePage.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the SecurePage class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the anonymousUser configuration element.
    /// </summary>
    public class SecurePage
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePage"/> class.
        /// </summary>
        /// <param name="element">The <see cref="SecurePageElement"/> this class is mapped to.</param>
        public SecurePage(SecurePageElement element)
        {
            if (element != null)
            {
                this.Path = element.Path;
                this.IgnoreProtocolScheme = element.IgnoreProtocolScheme;
            }
            else
            {
                this.Path = string.Empty;
                this.IgnoreProtocolScheme = false;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePage"/> class.
        /// </summary>
        public SecurePage()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the path.
        /// </summary>
        public string Path
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets a value indicating whether [ignore protocol scheme].
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [ignore protocol scheme]; otherwise, <c>false</c>.
        /// </value>
        public bool IgnoreProtocolScheme
        {
            get; 
            private set;
        }
    }
}
