﻿//-----------------------------------------------------------------------
// <copyright file="SecurePageDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the SecurePageDictionary class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the SecurePageElementCollection configuration element
    /// </summary>
    public class SecurePageDictionary : ConfigurationMappedDictionary<SecurePage>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePageDictionary"/> class.
        /// </summary>
        /// <param name="element">The <see cref="SecurePageElementCollection"/> this class is mapped to.</param>
        public SecurePageDictionary(SecurePageElementCollection element)
            : base(element)
        {
            if (element == null)
            {
                return;
            }

            foreach (SecurePageElement childElement in element)
            {
                this[childElement.Path] = new SecurePage(childElement);
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePageDictionary"/> class.
        /// </summary>
        public SecurePageDictionary()
            : this(null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePageDictionary"/> class with serialized data.
        /// </summary>
        /// <param name="info">A SerializationInfo object containing the information required to serialize this class.</param>
        /// <param name="context">A StreamingContext structure containing the source and destination of the serialized stream associated with this class.</param>
        protected SecurePageDictionary(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context)
            : base(info, context)
        {
        }
    }
}
