﻿//-----------------------------------------------------------------------
// <copyright file="SecurePageSettings.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the SecurePageSettings class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the userSecurityManagement configuration element.
    /// </summary>
    public class SecurePageSettings : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePageSettings"/> class.
        /// </summary>
        /// <param name="element">The <see cref="SecurePageSettingsElement"/> this class is mapped to.</param>
        public SecurePageSettings(SecurePageSettingsElement element)
            : base(element)
        {
            if (element != null)
            {
                this.RequireSsl = element.RequireSsl;
                this.SecureHostName = element.SecureHostName;
                this.SecurePort = element.SecurePort;
                this.NonSecureHostName = element.NonSecureHostName;
                this.NonSecurePort = element.NonSecurePort;
                this.SslOffloadPort = element.SslOffloadPort;
                this.Pages = new SecurePageDictionary(element.Pages);
            }
            else
            {
                this.RequireSsl = false;
                this.SecureHostName = string.Empty;
                this.SecurePort = 0;
                this.NonSecureHostName = string.Empty;
                this.NonSecurePort = 0;
                this.Pages = new SecurePageDictionary();
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SecurePageSettings"/> class.
        /// </summary>
        public SecurePageSettings()
            : this(null)
        {
        }

        /// <summary>
        /// Gets a value indicating whether [require SSL].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [require SSL]; otherwise, <c>false</c>.
        /// </value>
        public bool RequireSsl
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the secure host.
        /// </summary>
        /// <value>
        /// The name of the secure host.
        /// </value>
        public string SecureHostName
        {
            get;
            private set;
        }
        
        /// <summary>
        /// Gets the secure port.
        /// </summary>
        public int SecurePort
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the name of the non secure host.
        /// </summary>
        /// <value>
        /// The name of the non secure host.
        /// </value>
        public string NonSecureHostName
        {
            get;
            private set;
        }
        
        /// <summary>
        /// Gets the non secure port.
        /// </summary>
        public int NonSecurePort
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the SSL offload port.
        /// </summary>
        public int SslOffloadPort
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the pages.
        /// </summary>
        public SecurePageDictionary Pages
        {
            get;
            private set;
        }
    }
}
