﻿//-----------------------------------------------------------------------
// <copyright file="UserSecurityManagement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the UserSecurityManagement class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using CommerceServerContrib.CrossTier.Configuration;

    /// <summary>
    /// Class that represents the userSecurityManagement configuration element.
    /// </summary>
    public class UserSecurityManagement : ConfigurationMappedItem
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserSecurityManagement"/> class.
        /// </summary>
        /// <param name="element">The <see cref="UserSecurityManagementElement"/> this class is mapped to.</param>
        public UserSecurityManagement(UserSecurityManagementElement element)
            : base(element)
        {
            if (element != null)
            {
                this.Domain = element.Domain;
                this.Path = element.Path;
                this.AnonymousUser = new AnonymousUser(element.AnonymousUser);
                this.RegisteredUser = new RegisteredUser(element.RegisteredUser);
            }
            else
            {
                this.Domain = null;
                this.Path = null;
                this.AnonymousUser = new AnonymousUser();
                this.RegisteredUser = new RegisteredUser();
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="UserSecurityManagement"/> class.
        /// </summary>
        public UserSecurityManagement()
            : this(null)
        {
        }

        /// <summary>
        /// Gets the domain associated with user cookies.
        /// </summary>
        public string Domain
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the path associated with user cookies.
        /// </summary>
        public string Path
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the registerd user cookie configuation.
        /// </summary>
        public RegisteredUser RegisteredUser
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the anonymous user cookie configuration.
        /// </summary>
        public AnonymousUser AnonymousUser
        {
            get;
            private set;
        }
    }
}
