﻿//---------------------------------------------------------------------
// <copyright file="AnonymousUserElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>AnonymousUserElement class</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.ComponentModel;
    using System.Configuration;
    using System.Globalization;
    using System.Diagnostics;

    /// <summary>
    /// AnonymousUserElement class
    /// </summary>
    [DebuggerNonUserCode]
    public class AnonymousUserElement : BasePresentationElement
    {
        /// <summary>
        /// The timeout default time for cookie life
        /// </summary>
        public static readonly System.TimeSpan TimeoutDefaultValue = System.TimeSpan.FromMinutes(long.Parse(TimeoutDefaultValueString, CultureInfo.InvariantCulture));

        internal const string CookieNameDefaultValue = "__CLAnonymousUser";
        internal const bool SlidingExpirationDefaultValue = true;
        internal const string TimeoutDefaultValueString = "30";
        
        private const string CookieNameAttribute = "cookieName";
        private const string SlidingExpirationAttribute = "slidingExpiration";
        private const string TimeoutAttribute = "timeout";

        /// <summary>
        /// Gets or sets the name of the cookie.
        /// </summary>
        /// <value>
        /// The name of the cookie.
        /// </value>
        [ConfigurationProperty(CookieNameAttribute, IsRequired = false, DefaultValue = CookieNameDefaultValue), StringValidator(MinLength = 1)]
        public string CookieName
        {
            get
            {
                return (string)this[CookieNameAttribute];
            }

            set
            {
                this[CookieNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether [sliding expiration].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [sliding expiration]; otherwise, <c>false</c>.
        /// </value>
        [ConfigurationProperty(SlidingExpirationAttribute, IsRequired = false, DefaultValue = SlidingExpirationDefaultValue)]
        public bool SlidingExpiration
        {
            get
            { 
                return (bool)this[SlidingExpirationAttribute];
            }

            set
            {
                this[SlidingExpirationAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the timeout.
        /// </summary>
        /// <value>
        /// The timeout.
        /// </value>
        [ConfigurationProperty(TimeoutAttribute, IsRequired = false, DefaultValue = "30"), TypeConverter(typeof(TimeSpanMinutesConverter)), TimeSpanValidator(MinValueString = "00:00:00", MaxValueString = "10675199.02:48:05.4775807")]
        public System.TimeSpan Timeout
        {
            get
            {
                return (System.TimeSpan)this[TimeoutAttribute];
            }

            set
            {
                this[TimeoutAttribute] = value;
            }
        }

        /// <summary>
        /// Gets the timeout minutes.
        /// </summary>
        public int TimeoutMinutes
        {
            get
            {
                return this.Timeout.Minutes;
            }
        }
    }
}
