﻿//---------------------------------------------------------------------
// <copyright file="ArgumentElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// Used to represent a route element
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class ArgumentElement : BasePresentationElement
    {
        private const string KeyName = "key";
        private const string ValueName = "value";
        private const string ShortName = "short";

        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        [ConfigurationPropertyAttribute(KeyName, IsRequired = true, IsKey = true, IsDefaultCollection = false)]
        public string Key
        {
            get
            {
                return (string)base[KeyName];
            }

            set
            {
                base[KeyName] = value;
            }
        }

        /// <summary>
        /// Gets or sets the path.
        /// </summary>
        [ConfigurationPropertyAttribute(ValueName, IsRequired = false, IsKey = false, IsDefaultCollection = false)]
        public string Value
        {
            get
            {
                return (string)base[ValueName];
            }

            set
            {
                base[ValueName] = value;
            }
        }

        /// <summary>
        /// Gets or sets the short name.
        /// </summary>
        [ConfigurationPropertyAttribute(ShortName, IsRequired = false, IsKey = false, IsDefaultCollection = false)]
        public string Short
        {
            get
            {
                return (string)base[ShortName];
            }

            set
            {
                base[ShortName] = value;
            }
        }

        /// <summary>
        /// Gets a value indicating whether the element is read-only.
        /// </summary>
        /// <returns>
        /// true if the <see cref="T:System.Configuration.ConfigurationElement"/> object is read-only; otherwise, false.
        /// </returns>
        public override bool IsReadOnly()
        {
            return false;
        }
    }
}
