﻿//---------------------------------------------------------------------
// <copyright file="ArgumentElementCollection.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// Handles the "caches" element of the configuration.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class ArgumentElementCollection : BasePresentationElementCollection
    {
        #region Overrides

        /// <summary>
        /// Gets a value indicating that this is a basic map
        /// </summary>
        public override ConfigurationElementCollectionType CollectionType
        {
            get
            {
                return ConfigurationElementCollectionType.BasicMap;
            }
        }

        /// <summary>
        /// Gets a value indicating the name of the child elements
        /// </summary>
        protected override string ElementName
        {
            get
            {
                return "argument";
            }
        }

        /// <summary>
        /// Gets the CacheElement from the collection based on the element name
        /// </summary>
        /// <param name="prop">The property value to look for</param>
        /// <returns>CacheElement if found null otherwise </returns>
        public new ArgumentElement this[string prop]
        {
            get
            {
                return this.BaseGet(prop) as ArgumentElement;
            }
        }

        /// <summary>
        /// Creates a new CacheElement
        /// </summary>
        /// <returns>A new CacheElement</returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new ArgumentElement();
        }

        /// <summary>
        /// Gets the element key of a element
        /// </summary>
        /// <param name="element">The element who's key is required</param>
        /// <returns>The key of the element</returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((ArgumentElement)element).Key;
        }

        #endregion
    }
}
