﻿//---------------------------------------------------------------------
// <copyright file="BaseBrandElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// Default Brand configuration element from the configuration file.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class BaseBrandElement : BasePresentationElement
    {
        private const string NameAttributeName = "name";
        private const string ExceptionHandlingElementName = "exceptionHandling";
        private const string UserSecurityManagementElementName = "userSecurityManagement";
        private const string EncryptionKeysElementName = "encryptionKeys";
        private const string SecurePageSettingsElementName = "securePageSettings";
        private const string OperationServiceNameAttributeName = "operationServiceName";

        #region Properties (public, non-static)

        /// <summary>
        /// Gets or sets the brand name.
        /// </summary>
        [ConfigurationProperty(NameAttributeName, IsRequired = true)]
        public string Name
        {
            get { return (string)this[NameAttributeName]; }
            set { this[NameAttributeName] = value; }
        }

        /// <summary>
        /// Gets or sets the Operation Service Name.
        /// </summary>
        [ConfigurationProperty(OperationServiceNameAttributeName, IsRequired = true)]
        public string OperationServiceName
        {
            get { return (string)this[OperationServiceNameAttributeName]; }
            set { this[OperationServiceNameAttributeName] = value; }
        }

        /// <summary>
        /// Gets or sets the exception handling information.
        /// </summary>
        [ConfigurationProperty(ExceptionHandlingElementName, IsRequired = false)]
        public ExceptionHandlingElement ExceptionHandling
        {
            get { return (ExceptionHandlingElement)this[ExceptionHandlingElementName]; }
            set { this[ExceptionHandlingElementName] = value; }
        }

        /// <summary>
        /// Gets or sets the user security management.
        /// </summary>
        [ConfigurationProperty(UserSecurityManagementElementName, IsRequired = false)]
        public UserSecurityManagementElement UserSecurityManagement
        {
            get { return (UserSecurityManagementElement)this[UserSecurityManagementElementName]; }
            set { this[UserSecurityManagementElementName] = value; }
        }

        /// <summary>
        /// Gets the encryption keys.
        /// </summary>
        [ConfigurationProperty(EncryptionKeysElementName, IsRequired = false)]
        public EncryptionKeysElementCollection EncryptionKeys
        {
            get { return (EncryptionKeysElementCollection)this[EncryptionKeysElementName]; }
        }
        
        /// <summary>
        /// Gets the secure page settings.
        /// </summary>
        [ConfigurationProperty(SecurePageSettingsElementName, IsRequired = false)]
        public SecurePageSettingsElement SecurePageSettings
        {
            get { return (SecurePageSettingsElement)this[SecurePageSettingsElementName]; }
        }

        #endregion
    }
}
