﻿//---------------------------------------------------------------------
// <copyright file="EncryptionKeyElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>EncryptionKeyElement class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// EncryptionKeyElement class
    /// </summary>
    [DebuggerNonUserCode]
    public class EncryptionKeyElement : BasePresentationElement
    {
        private const string NameAttribute = "name";
        private const string ValueAttribute = "value";

        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>
        /// The element name.
        /// </value>
        [ConfigurationPropertyAttribute(NameAttribute, IsRequired = true, IsKey = true, IsDefaultCollection = false)]
        public string Name
        {
            get
            {
                return (string)base[NameAttribute];
            }

            set
            {
                base[NameAttribute] = value;
            }
        }
        
        /// <summary>
        /// Gets or sets the public key.
        /// </summary>
        /// <value>
        /// The public key.
        /// </value>
        [ConfigurationPropertyAttribute(ValueAttribute, IsRequired = true, IsKey = false, IsDefaultCollection = false)]
        public string Value
        {
            get
            {
                return (string)base[ValueAttribute];
            }

            set
            {
                base[ValueAttribute] = value;
            }
        }
        
        /// <summary>
        /// Gets a value indicating whether the element is read-only.
        /// </summary>
        /// <returns>
        /// true if the <see cref="T:System.Configuration.ConfigurationElement"/> object is read-only; otherwise, false.
        /// </returns>
        public override bool IsReadOnly()
        {
            return false;
        }
    }
}
