﻿//---------------------------------------------------------------------
// <copyright file="EncryptionKeyElementCollection.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>EncryptionKeyElementCollection class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// EncryptionKeysElementCollection class
    /// </summary>
    [DebuggerNonUserCode]
    public class EncryptionKeyElementCollection : BasePresentationElementCollection
    {
        private const string NameAttribute = "name";
        private const string EncryptionProviderTypeAttribute = "encryptionProviderType";

        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>
        /// The name of the element.
        /// </value>
        [ConfigurationPropertyAttribute(NameAttribute, IsRequired = true, IsKey = true, IsDefaultCollection = false)]
        public string Name
        {
            get
            {
                return (string)base[NameAttribute];
            }

            set
            {
                base[NameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the type.
        /// </summary>
        /// <value>
        /// The type of the element.
        /// </value>
        [ConfigurationPropertyAttribute(EncryptionProviderTypeAttribute, IsRequired = true, IsKey = false, IsDefaultCollection = false)]
        public string EncryptionProviderType
        {
            get
            {
                return (string)base[EncryptionProviderTypeAttribute];
            }

            set
            {
                base[EncryptionProviderTypeAttribute] = value;
            }
        }
        
        #region Overrides

        /// <summary>
        /// Gets a value indicating that this is a basic map
        /// </summary>
        public override ConfigurationElementCollectionType CollectionType
        {
            get
            {
                return ConfigurationElementCollectionType.BasicMap;
            }
        }

        /// <summary>
        /// Gets a value indicating the name of the child elements
        /// </summary>
        protected override string ElementName
        {
            get
            {
                return "key";
            }
        }
        
        /// <summary>
        /// Gets or sets a property, attribute, or child element of this configuration element.
        /// </summary>
        /// <param name="prop"> is read-only or locked.</param>
        /// <returns>The specified property, attribute, or child element</returns>
        public new EncryptionKeyElement this[string prop]
        {
            get
            {
                return this.BaseGet(prop) as EncryptionKeyElement;
            }
        }

        /// <summary>
        /// Creates a new CacheElement
        /// </summary>
        /// <returns>A new CacheElement</returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new EncryptionKeyElement();
        }

        /// <summary>
        /// Gets the element key of a element
        /// </summary>
        /// <param name="element">The element who's key is required</param>
        /// <returns>The key of the element</returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((EncryptionKeyElement)element).Name;
        }

        #endregion
    }
}
