﻿namespace CommerceServerContrib.CrossTier.Configuration
{
    using System;
    using System.Collections.Generic;
    using System.Configuration;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// A ConfigurationElementCollection to hold a list of groups in configuration. 
    /// </summary>
    [ConfigurationCollection(typeof(GroupElement), AddItemName = "group")]
    public class GroupElementCollection : BasePresentationElementCollection
    {
        /// <summary>
        /// Gets or sets a property, attribute, or child element of this configuration element.
        /// </summary>
        /// <param name="id">The id.</param>
        /// <returns>Returns a <see cref="GroupElement" /></returns>
        public new GroupElement this[string id]
        {
            get
            {
                return (GroupElement)BaseGet(id);
            }
        }

        /// <summary>
        /// When overridden in a derived class, creates a new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </summary>
        /// <returns>
        /// A new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new GroupElement();
        }

        /// <summary>
        /// Gets the element key for a specified configuration element when overridden in a derived class.
        /// </summary>
        /// <param name="element">The <see cref="T:System.Configuration.ConfigurationElement" /> to return the key for.</param>
        /// <returns>
        /// An <see cref="T:System.Object" /> that acts as the key for the specified <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((GroupElement)element).Id;
        }
    }
}
