﻿namespace CommerceServerContrib.CrossTier.Configuration
{
    using System;
    using System.Collections.Generic;
    using System.Configuration;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// A ConfigurationElementCollection used to hold a list of localized setting display names.  
    /// </summary>
    [ConfigurationCollection(typeof(SettingElement), AddItemName = "localizedSetting")]
    public class LocalizedSettingElementCollection : BasePresentationElementCollection
    {
        /// <summary>
        /// Gets or sets a property, attribute, or child element of this configuration element.
        /// </summary>
        /// <param name="key">The key.</param>
        /// <returns>Returns a LocalizedSettingElement for the given key.</returns>
        public new LocalizedSettingElement this[string key]
        {
            get
            {
                return (LocalizedSettingElement)BaseGet(key);
            }
        }

        /// <summary>
        /// When overridden in a derived class, creates a new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </summary>
        /// <returns>
        /// A new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new LocalizedSettingElement();
        }

        /// <summary>
        /// Gets the element key for a specified configuration element when overridden in a derived class.
        /// </summary>
        /// <param name="element">The <see cref="T:System.Configuration.ConfigurationElement" /> to return the key for.</param>
        /// <returns>
        /// An <see cref="T:System.Object" /> that acts as the key for the specified <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((LocalizedSettingElement)element).Key;
        }
    }
}
