﻿//---------------------------------------------------------------------
// <copyright file="RegisteredUserElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>RegisteredUserElement class</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.ComponentModel;
    using System.Configuration;
    using System.Diagnostics;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServer.Foundation.Configuration;

    /// <summary>
    /// RegisteredUserElement class
    /// </summary>
    [DebuggerNonUserCode]
    public class RegisteredUserElement : BasePresentationElement
    {
        internal const string CookieNameDefaultValue = "__CLRegisteredUser";
        internal const string NonSecuredCookieNameDefaultValue = "__CLRegisteredUserHttp";
        internal const string RememberMeCookieNameDefaultValue = "__CLRememberMe";
        internal const UserCookieSslMode SslModeDefaultValue = UserCookieSslMode.Disabled;
        internal const bool ValidateIdentityDefaultValue = true;
        private const string CookieNameAttribute = "cookieName";
        private const string NonSecuredCookieNameAttribute = "nonSecureCookieName";
        private const string RememberMeCookieNameAttribute = "rememberMeCookieName";
        private const string SecureEncryptionKeyNameAttribute = "secureEncryptionKeyName";
        private const string NonSecureEncryptionKeyNameAttribute = "nonSecureEncryptionKeyName";
        private const string SslModeAttribute = "sslMode";
        private const string ValidateIdentityAttribute = "validateIdentity";

        /// <summary>
        /// Gets or sets the name of the cookie.
        /// </summary>
        /// <value>
        /// The name of the cookie.
        /// </value>
        [ConfigurationProperty(CookieNameAttribute, IsRequired = false, DefaultValue = CookieNameDefaultValue), StringValidator(MinLength = 1)]
        public string CookieName
        {
            get
            {
                return (string)this[CookieNameAttribute];
            }

            set
            {
                this[CookieNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the name of the non secured cookie.
        /// </summary>
        /// <value>
        /// The name of the non secured cookie.
        /// </value>
        [StringValidator(MinLength = 1), ConfigurationProperty(NonSecuredCookieNameAttribute, IsRequired = false, DefaultValue = NonSecuredCookieNameDefaultValue)]
        public string NonSecuredCookieName
        {
            get
            {
                return (string)this[NonSecuredCookieNameAttribute];
            }

            set
            {
                this[NonSecuredCookieNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the name of the remember me cookie.
        /// </summary>
        /// <value>
        /// The name of the remember me cookie.
        /// </value>
        [StringValidator(MinLength = 1), ConfigurationProperty(RememberMeCookieNameAttribute, IsRequired = false, DefaultValue = RememberMeCookieNameDefaultValue)]
        public string RememberMeCookieName
        {
            get
            {
                return (string)this[RememberMeCookieNameAttribute];
            }

            set
            {
                this[RememberMeCookieNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the non secure cookie encryption key.
        /// </summary>
        /// <value>
        /// The non secure cookie encryption key.
        /// </value>
        [ConfigurationProperty(SecureEncryptionKeyNameAttribute, IsRequired = true)]
        public string SecureEncryptionKeyName
        {
            get
            {
                return (string)this[SecureEncryptionKeyNameAttribute];
            }

            set
            {
                this[SecureEncryptionKeyNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the name of the non secure encryption key.
        /// </summary>
        /// <value>
        /// The name of the non secure encryption key.
        /// </value>
        [ConfigurationProperty(NonSecureEncryptionKeyNameAttribute, IsRequired = true)]
        public string NonSecureEncryptionKeyName
        {
            get
            {
                return (string)this[NonSecureEncryptionKeyNameAttribute];
            }

            set
            {
                this[NonSecureEncryptionKeyNameAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the SSL mode.
        /// </summary>
        /// <value>
        /// The SSL mode.
        /// </value>
        [ConfigurationProperty(SslModeAttribute, IsRequired = false, DefaultValue = SslModeDefaultValue), TypeConverter(typeof(CommerceCookieSslModeTypeConverter))]
        public UserCookieSslMode SslMode
        {
            get
            {
                return (UserCookieSslMode)this[SslModeAttribute];
            }

            set
            {
                this[SslModeAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether [validate identity].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [validate identity]; otherwise, <c>false</c>.
        /// </value>
        [ConfigurationProperty(ValidateIdentityAttribute, IsRequired = false, DefaultValue = ValidateIdentityDefaultValue)]
        public bool ValidateIdentity
        {
            get
            {
                return (bool)this[ValidateIdentityAttribute];
            }

            set
            {
                this[ValidateIdentityAttribute] = value;
            }
        }
    }
}
