﻿//-----------------------------------------------------------------------
// <copyright file="SecurePageElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>SecurePageElement</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// Secure Page Element class.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class SecurePageElement : BasePresentationElement
    {
        private const string PathAttribute = "path";
        private const string IgnoreProtocolSchemeAttribute = "ignoreProtocolScheme";
        
        /// <summary>
        /// Gets or sets the path.
        /// </summary>
        /// <value>The path of the secure page.</value>
        [ConfigurationProperty(PathAttribute, IsRequired = true)]
        public string Path
        {
            get
            {
                return (string)this[PathAttribute];
            }

            set
            {
                this[PathAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether [ignore protocol scheme].
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [ignore protocol scheme]; otherwise, <c>false</c>.
        /// </value>
        [ConfigurationProperty(IgnoreProtocolSchemeAttribute, IsRequired = false)]
        public bool IgnoreProtocolScheme
        {
            get
            {
                return (bool)this[IgnoreProtocolSchemeAttribute];
            }

            set
            {
                this[IgnoreProtocolSchemeAttribute] = value;
            } 
        }
    }
}