﻿//-----------------------------------------------------------------------
// <copyright file="SecurePageElementCollection.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>SecurePageElementCollection</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// Secure Page Colection class.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    [ConfigurationCollection(typeof(SecurePageElementCollection), AddItemName = "addPage", ClearItemsName = "clearPages", RemoveItemName = "removePage")]
    public class SecurePageElementCollection : BasePresentationElementCollection
    {
        /// <summary>
        /// Gets the type of the collection.
        /// </summary>
        /// <value>The type of the collection.</value>
        public override ConfigurationElementCollectionType CollectionType
        {
            get
            {
                return ConfigurationElementCollectionType.AddRemoveClearMap;
            }
        }

        /// <summary>
        /// Gets or sets the <see cref="SecurePageElement" /> at the specified index.
        /// </summary>
        /// <value>
        /// The element at the index specified.
        /// </value>
        /// <param name="index">The index of the element.</param>
        /// <returns>a SecurePageElement</returns>
        public SecurePageElement this[int index]
        {
            get 
            { 
                return (SecurePageElement)this.BaseGet(index); 
            }

            set
            {
                if (this.BaseGet(index) != null)
                {
                    this.BaseRemoveAt(index);
                }

                this.BaseAdd(index, value);
            }
        }

        /// <summary>
        /// Adds the specified element.
        /// </summary>
        /// <param name="element">The element.</param>
        public void Add(SecurePageElement element)
        {
            this.BaseAdd(element);
        }

        /// <summary>
        /// Clears this instance.
        /// </summary>
        public void Clear()
        {
            this.BaseClear();
        }
       
        /// <summary>
        /// Removes the specified element.
        /// </summary>
        /// <param name="element">The element.</param>
        public void Remove(SecurePageElement element)
        {
            this.BaseRemove(element.Path);
        }

        /// <summary>
        /// Removes the specified name.
        /// </summary>
        /// <param name="name">The name of the element.</param>
        public void Remove(string name)
        {
            this.BaseRemove(name);
        }

        /// <summary>
        /// Removes at.
        /// </summary>
        /// <param name="index">The index.</param>
        public void RemoveAt(int index)
        {
            this.BaseRemoveAt(index);
        }

        /// <summary>
        /// Creates the new element.
        /// </summary>
        /// <returns>The new element.</returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new SecurePageElement();
        }

        /// <summary>
        /// Gets the element key.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <returns>The element key.</returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((SecurePageElement)element).Path;
        }
    }
}