﻿//---------------------------------------------------------------------
// <copyright file="ServiceEndpointElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;
    using System.Xml;

    /// <summary>
    /// Represents the ServiceEndpointElement in the Request Template Framework configuration.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class ServiceEndpointElement : BasePresentationElement
    {
        private const string NameAttribute = "name";
        private const string WcfEndpointNameAttribute = "wcfEndpointName";

        #region Properties
        /// <summary>
        /// Gets or sets the name of the ServiceEndpointElement.
        /// </summary>
        /// <value>
        /// The name of the ServiceEndpointElement.
        /// </value>
        [ConfigurationProperty(NameAttribute, IsRequired = true, IsKey = true)]
        public string Name
        {
            get { return (string)this[NameAttribute]; }
            set { this[NameAttribute] = value; }
        }

        /// <summary>
        /// Gets or sets the name of the WCF endpoint.
        /// </summary>
        /// <value>
        /// The name of the WCF endpoint.
        /// </value>
        [ConfigurationProperty(WcfEndpointNameAttribute, IsRequired = true)]
        public string WcfEndpointName
        {
            get { return (string)this[WcfEndpointNameAttribute]; }
            set { this[WcfEndpointNameAttribute] = value; }
        }
        #endregion

        /// <summary>
        /// Deserializes the specified reader.
        /// </summary>
        /// <param name="reader">The reader.</param>
        /// <param name="serializeCollectionKey">if set to <c>true</c> [serialize collection key].</param>
        public void Deserialize(XmlReader reader, bool serializeCollectionKey)
        {
            DeserializeElement(reader, serializeCollectionKey);
        }
    }
}
