﻿namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;

    /// <summary>
    /// A ConfigurationElement to hold a single Setting. 
    /// </summary>
    public class SettingElement : BasePresentationElement
    {
        private const string KeyAttributeName = "key";
        private const string ValueAttributeName = "value";
        private const string LocalizedValues = "localizedValues";

        /// <summary>
        /// Gets or sets the key from the Setting.
        /// </summary>
        /// <value>
        /// The key.
        /// </value>
        [ConfigurationProperty(KeyAttributeName, IsRequired = true)]
        public string Key
        {
            get { return (string)this[KeyAttributeName]; }
            set { this[KeyAttributeName] = value; }
        }

        /// <summary>
        /// Gets or sets the value of the Setting.
        /// </summary>
        /// <value>
        /// The value.
        /// </value>
        [ConfigurationProperty(ValueAttributeName, IsRequired = true)]
        public string Value
        {
            get { return (string)this[ValueAttributeName]; }
            set { this[ValueAttributeName] = value; }
        }

        /// <summary>
        /// Gets the localized display names for the setting..
        /// </summary>
        /// <value>
        /// The localized settings.
        /// </value>
        [ConfigurationProperty(LocalizedValues, IsRequired = false)]
        public LocalizedSettingElementCollection LocalizedSettings
        {
            get { return (LocalizedSettingElementCollection)this[LocalizedValues]; }
        }
    }
}
