﻿namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;

    /// <summary>
    /// A ConfigurationElementCollection for holding a collection of settings. 
    /// </summary>
    [ConfigurationCollection(typeof(SettingElement), AddItemName = "setting")]
    public class SettingElementCollection : BasePresentationElementCollection
    {
        /// <summary>
        /// Gets or sets a property, attribute, or child element of this configuration element.
        /// </summary>
        /// <param name="key">The key.</param>
        /// <returns>Returns SettingElement.</returns>
        public new SettingElement this[string key]
        {
            get
            {
                return (SettingElement)BaseGet(key);
            }
        }

        /// <summary>
        /// When overridden in a derived class, creates a new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </summary>
        /// <returns>
        /// A new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new SettingElement();
        }

        /// <summary>
        /// Gets the element key for a specified configuration element when overridden in a derived class.
        /// </summary>
        /// <param name="element">The <see cref="T:System.Configuration.ConfigurationElement" /> to return the key for.</param>
        /// <returns>
        /// An <see cref="T:System.Object" /> that acts as the key for the specified <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((SettingElement)element).Key;
        }
    }
}
