﻿namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;

    /// <summary>
    /// A ConfigurationElementCollection for holding a list of site settings. 
    /// </summary>
    [ConfigurationCollection(typeof(SiteElement), AddItemName = "site")]
    public class SiteSettingsElementCollection : BasePresentationElementCollection
    {
        /// <summary>
        /// Gets or sets a property, attribute, or child element of this configuration element.
        /// </summary>
        /// <param name="id">The id of the SiteElement.</param>
        /// <returns>Returns SiteElement for the given Id. </returns>
        public new SiteElement this[string id]
        {
            get
            {
                return (SiteElement)BaseGet(id);
            }
        }

        /// <summary>
        /// When overridden in a derived class, creates a new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </summary>
        /// <returns>
        /// A new <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new SiteElement();
        }

        /// <summary>
        /// Gets the element key for a specified configuration element when overridden in a derived class.
        /// </summary>
        /// <param name="element">The <see cref="T:System.Configuration.ConfigurationElement" /> to return the key for.</param>
        /// <returns>
        /// An <see cref="T:System.Object" /> that acts as the key for the specified <see cref="T:System.Configuration.ConfigurationElement" />.
        /// </returns>
        protected override object GetElementKey(ConfigurationElement element)
        {
            return ((SiteElement)element).Id;
        }
    }
}
