﻿//---------------------------------------------------------------------
// <copyright file="UserSecurityManagementElement.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>UserSecurityManagementElement class</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Configuration
{
    using System.Configuration;
    using System.Diagnostics;

    /// <summary>
    /// UserSecurityManagementSession class
    /// </summary>
    [DebuggerNonUserCode]
    public class UserSecurityManagementElement : BasePresentationElement
    {
        internal const string DomainDefaultValue = null;
        internal const string PathDefaultValue = "/";
        private const string DomainAttribute = "domain";
        private const string PathAttribute = "path";
        private const string RegisteredUserElement = "registeredUser";
        private const string AnonymousUserElement = "anonymousUser";

        /// <summary>
        /// Gets or sets the domain.
        /// </summary>
        /// <value>
        /// The domain.
        /// </value>
        [ConfigurationProperty(DomainAttribute, IsRequired = false, DefaultValue = DomainDefaultValue)]
        public string Domain
        {
            get
            {
                return (string)this[DomainAttribute];
            }

            set
            {
                this[DomainAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the path.
        /// </summary>
        /// <value>
        /// The cookie path.
        /// </value>
        [ConfigurationProperty(PathAttribute, IsRequired = false, DefaultValue = PathDefaultValue), StringValidator(MinLength = 1)]
        public string Path
        {
            get
            {
                return (string)this[PathAttribute];
            }

            set
            {
                this[PathAttribute] = value;
            }
        }

        /// <summary>
        /// Gets or sets the registered user.
        /// </summary>
        /// <value>
        /// The registered user.
        /// </value>
        [ConfigurationProperty(RegisteredUserElement, IsRequired = false)]
        public RegisteredUserElement RegisteredUser
        {
            get
            {
                return (this[RegisteredUserElement] as RegisteredUserElement);
            }

            set
            {
                this[RegisteredUserElement] = value;
            }
        }

        /// <summary>
        /// Gets or sets the anonymous user.
        /// </summary>
        /// <value>
        /// The anonymous user.
        /// </value>
        [ConfigurationProperty(AnonymousUserElement, IsRequired = false)]
        public AnonymousUserElement AnonymousUser
        {
            get
            {
                return this[AnonymousUserElement] as AnonymousUserElement;
            }

            set
            {
                this[AnonymousUserElement] = value;
            }
        }
    }
}
