﻿//---------------------------------------------------------------------
// <copyright file="User.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>User class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Entities
{
    using System.Collections.Generic;
    using System.Diagnostics;

    /// <summary>
    /// User class
    /// </summary>
    [DebuggerNonUserCode]
    public class User
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="User"/> class.
        /// </summary>
        public User()
        {
            this.Email = string.Empty;
            this.Id = string.Empty;
            this.AnonymousId = string.Empty;
            this.Name = string.Empty;
            this.AuthenticationType = string.Empty;
            this.RememberMe = string.Empty;
            this.Properties = new Dictionary<string, object>();
        }

        /// <summary>
        /// Gets or sets the name of the user.
        /// </summary>
        /// <value>
        /// The name of the user.
        /// </value>
        public string Name { get; set; }

        /// <summary>
        /// Gets or sets the user id.
        /// </summary>
        /// <value>
        /// The user id.
        /// </value>
        public string Id { get; set; }

        /// <summary>
        /// Gets or sets the anonymous id.
        /// </summary>
        /// <value>
        /// The anonymous id.
        /// </value>
        public string AnonymousId { get; set; }

        /// <summary>
        /// Gets or sets the user email.
        /// </summary>
        /// <value>
        /// The user email.
        /// </value>
        public string Email { get; set; }

        /// <summary>
        /// Gets or sets the type of the authentication.
        /// </summary>
        /// <value>
        /// The type of the authentication.
        /// </value>
        public string AuthenticationType { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is windows identity.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows identity; otherwise, <c>false</c>.
        /// </value>
        public bool IsWindowsIdentity { get; set; }

        /// <summary>
        /// Gets or sets the remember me.
        /// </summary>
        /// <value>
        /// The remember me.
        /// </value>
        public string RememberMe { get; set; }

        /// <summary>
        /// Gets or sets the properties.
        /// </summary>
        /// <value>
        /// The properties.
        /// </value>
        public Dictionary<string, object> Properties { get; set; }
    }
}