﻿//---------------------------------------------------------------------
// <copyright file="ControllerInstance.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Entities
{
    using CommerceServer.Foundation.RequestTemplates;
    using System;
    using System.Diagnostics;

    /// <summary>
    /// Used to represent a service instance that a user can chose
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class ControllerInstance
    {
        /// <summary>
        /// Gets or sets the id of the service instance.
        /// </summary>
        public string Id
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the friendly name to show to a user which then 
        /// are chosing a service
        /// </summary>
        public string FriendlyName
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the a reference to the type of the service, this reduces the amount of 
        /// reflection that will needed to be done at runtime
        /// </summary>
        public Type TypeReference
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the group id for the controller.
        /// </summary>
        public string GroupId
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the all of the available request templates in the service.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly", Justification = "Setter is required.")]
        public ClientRequestTemplateCollection Methods
        {
            get;
            set;
        }
    }
}
