﻿//---------------------------------------------------------------------
// <copyright file="SortParameterSelection.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Entities
{
    using CommerceServer.Foundation.RequestTemplates;
    using System;
    using System.Diagnostics;

    /// <summary>
    /// An enum for the sort order type.
    /// </summary>
    public enum SortConfiguration
    {
        /// <summary>
        /// Indicates that there is sort order
        /// </summary>
        None = 0,

        /// <summary>
        /// Indicates that the sort order will be defined staticly
        /// </summary>
        Static = 1,

        /// <summary>
        /// Indicates that the sort order will be defined dynamically via a querystring
        /// </summary>
        Dynamic = 2
    }

    /// <summary>
    /// Represents a selection of a sort parameter.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    [Serializable]
    public class SortParameterSelection
    {
        /// <summary>
        /// Gets or sets the sort order type.
        /// </summary>
        public SortConfiguration ConfigurationType { get; set; }

        /// <summary>
        /// Gets or sets the parameter to sort by.
        /// </summary>
        public string ParameterId { get; set; }

        /// <summary>
        /// Gets or sets the sort order.
        /// </summary>
        public SortOrder? Order { get; set; }

        /// <summary>
        /// Gets or sets the query string used to indicate the sort parameter.
        /// </summary>
        public string ParameterIdQueryString { get; set; }

        /// <summary>
        /// Gets or sets the query string used to indicate the sort order.
        /// </summary>
        public string OrderQueryString { get; set; }
    }
}
