﻿//---------------------------------------------------------------------
// <copyright file="RenderArgumentBuilder.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>RenderArgumentBuilder class.</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Entities
{
    using System;
    using System.Diagnostics;
    using System.Xml.Xsl;

    /// <summary>
    /// This is a serializable class that is responsible for building out and <see cref="XsltArgumentList" /> class.
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    [Serializable]
    public class RenderArgumentBuilder
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RenderArgumentBuilder"/> class.
        /// </summary>
        public RenderArgumentBuilder()
        {
            this.Parameters = new RenderParameters();
            this.RenderExtensionObjects = new RenderExtensionObjects();
        }

        /// <summary>
        /// Gets or sets the parameters.
        /// </summary>
        /// <value>
        /// The parameters.
        /// </value>
        public RenderParameters Parameters { get; set; }

        /// <summary>
        /// Gets or sets the Render extension objects.
        /// </summary>
        /// <value>
        /// The Render extension objects.
        /// </value>
        public RenderExtensionObjects RenderExtensionObjects
        {
            get;
            set;
        }

        /// <summary>
        /// Converts current class into RenderArgumentList object.
        /// </summary>
        /// <returns>A fully formulated RenderArgumentList object, <see cref="System.Xml.Xsl.XsltArgumentList" /></returns>
        public XsltArgumentList ToXsltArgumentList()
        {
            XsltArgumentList xsltArgumentList = new XsltArgumentList();
            foreach (RenderParameter parameter in this.Parameters)
            {
                xsltArgumentList.AddParam(parameter.RenderParameterKey, parameter.RenderNamespace, parameter.RenderParameterValue);
            }

            foreach (RenderExtensionObject extensionObject in this.RenderExtensionObjects)
            {
                xsltArgumentList.AddExtensionObject(extensionObject.RenderExtensionObjectNamespace, extensionObject.RenderExtensionObjectClass);
            }

            return xsltArgumentList;
        }
    }
}
