﻿//---------------------------------------------------------------------
// <copyright file="RenderExtensionObject.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>RenderExtensionObject object.</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Entities
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// RenderExtesnionObject represents the RenderArgumentList's ExtensionObject 
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class RenderExtensionObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RenderExtensionObject"/> class.
        /// </summary>
        /// <param name="renderExtensionObjectNamespace">The Render extension object namespace.</param>
        /// <param name="renderExtensionObjectClass">The Render extension object class.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1720:IdentifiersShouldNotContainTypeNames", MessageId = "object", Justification = "this makes the code more readable.")]
        public RenderExtensionObject(string renderExtensionObjectNamespace, object renderExtensionObjectClass)
        {
            this.RenderExtensionObjectClass = renderExtensionObjectClass;
            this.RenderExtensionObjectNamespace = renderExtensionObjectNamespace;
        }

        /// <summary>
        /// Prevents a default instance of the <see cref="RenderExtensionObject"/> class from being created.
        /// </summary>
        private RenderExtensionObject()
        {
        }

        /// <summary>
        /// Gets or sets the Render extension object namespace.
        /// </summary>
        /// <value>
        /// The Render extension object namespace.
        /// </value>
        public string RenderExtensionObjectNamespace { get; set; }

        /// <summary>
        /// Gets or sets the Render extension object class.
        /// </summary>
        /// <value>
        /// The Render extension object class.
        /// </value>
        public object RenderExtensionObjectClass { get; set; }

        /// <summary>
        /// Determines whether the specified <see cref="System.Object"/> is equal to this instance.
        /// </summary>
        /// <param name="obj">The <see cref="System.Object"/> to compare with this instance.</param>
        /// <returns>
        ///   <c>true</c> if the specified <see cref="System.Object"/> is equal to this instance; otherwise, <c>false</c>.
        /// </returns>
        /// <exception cref="T:System.NullReferenceException">The <paramref name="obj"/> parameter is null.</exception>
        public override bool Equals(object obj)
        {
            return this.RenderExtensionObjectNamespace.Equals(((RenderExtensionObject)obj).RenderExtensionObjectNamespace, StringComparison.OrdinalIgnoreCase);
        }

        /// <summary>
        /// Returns a hash code for this instance.
        /// </summary>
        /// <returns>
        /// A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table. 
        /// </returns>
        public override int GetHashCode()
        {
            return base.GetHashCode();
        }
    }
}
