﻿//---------------------------------------------------------------------
// <copyright file="RenderParameter.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>RenderParameter class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Entities
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// RenderParameter represents the RenderArgumentList's Parameter Collection
    /// </summary>
    /// DebuggerNonUserCode is added as a way to stop this object counting against code coverage,
    /// As this is just an entity class there is no reason or benifit to testing it
    [DebuggerNonUserCode]
    public class RenderParameter
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RenderParameter"/> class.
        /// </summary>
        /// <param name="renderParameterKey">The Render parameter key.</param>
        /// <param name="renderNamespace">The Render namespace.</param>
        /// <param name="renderParameterValue">The Render parameter value.</param>
        public RenderParameter(string renderParameterKey, string renderNamespace, object renderParameterValue)
        {
            this.RenderNamespace = renderNamespace;
            this.RenderParameterKey = renderParameterKey;
            this.RenderParameterValue = renderParameterValue;
        }

        /// <summary>
        /// Prevents a default instance of the <see cref="RenderParameter"/> class from being created.
        /// </summary>
        private RenderParameter()
        {
        }

        /// <summary>
        /// Gets or sets the Render namespace.
        /// </summary>
        /// <value>
        /// The Render namespace.
        /// </value>
        public string RenderNamespace { get; set; }

        /// <summary>
        /// Gets or sets the Render param key.
        /// </summary>
        /// <value>
        /// The Render parameter key.
        /// </value>
        public string RenderParameterKey { get; set; }

        /// <summary>
        /// Gets or sets the Render param value.
        /// </summary>
        /// <value>
        /// The Render param value.
        /// </value>
        public object RenderParameterValue { get; set; }

        /// <summary>
        /// Determines whether the specified <see cref="System.Object"/> is equal to this instance.
        /// </summary>
        /// <param name="obj">The <see cref="System.Object"/> to compare with this instance.</param>
        /// <returns>
        ///   <c>true</c> if the specified <see cref="System.Object"/> is equal to this instance; otherwise, <c>false</c>.
        /// </returns>
        /// <exception cref="T:System.NullReferenceException">The <paramref name="obj"/> parameter is null.</exception>
        public override bool Equals(object obj)
        {
            return this.RenderParameterKey.Equals(((RenderParameter)obj).RenderParameterKey, StringComparison.OrdinalIgnoreCase);
        }

        /// <summary>
        /// Returns a hash code for this instance.
        /// </summary>
        /// <returns>
        /// A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table. 
        /// </returns>
        public override int GetHashCode()
        {
            return base.GetHashCode();
        }
    }
}
