﻿//-----------------------------------------------------------------------
// <copyright file="CommerceServerContribCsrfException.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the CommerceServerContribCsrfException class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;
    using System.Runtime.Serialization;

    /// <summary>
    /// The exception that is thrown when a CSRF attempt is detected. 
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Csrf", Justification = "CSRF is a valid acronym.")]
    [Serializable]
    public class CommerceServerContribCsrfException : Exception
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="CommerceServerContribCsrfException"/> class.
        /// </summary>
        public CommerceServerContribCsrfException()
        {           
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="CommerceServerContribCsrfException"/> class with a specified error message 
        /// and a reference to the inner exception that is the cause of this exception. 
        /// </summary>
        /// <param name="message">The message that describes the error.</param>
        public CommerceServerContribCsrfException(string message) : base(message)
        {            
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="CommerceServerContribCsrfException"/> class with a specified error message.
        /// </summary>
        /// <param name="message">The message that describes the error.</param>
        /// <param name="innerException">The exception that is the cause of the current exception, or a null reference 
        /// (Nothing in Visual Basic) if no inner exception is specified.</param>
        public CommerceServerContribCsrfException(string message, Exception innerException) : base(message, innerException)
        {            
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="CommerceServerContribCsrfException"/> class with serialized data.
        /// </summary>
        /// <param name="info">The <see cref="SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="StreamingContext"/> that contains contextual information about the source or destination.</param>
        protected CommerceServerContribCsrfException(SerializationInfo info, StreamingContext context) : base(info, context)
        {            
        }
    }
}
