﻿//---------------------------------------------------------------------
// <copyright file="InvalidCatalogXmlException.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Exceptions
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Runtime.Serialization;
    using System.Security.Permissions;
    using System.Globalization;

    /// <summary>
    /// Exception thrown when the web parts are unable to parse some expected XML.
    /// </summary>
    [Serializable]
    public class InvalidCatalogXmlException : CommerceServerContribBaseException
    {
        private string _xml;
        private string _xmlType;

        #region Constructors (public)

        /// <summary>
        /// Initializes a new instance of the InvalidCatalogXmlException class.
        /// </summary>
        /// <param name="channel">The name opf the channel.</param>
        /// <param name="xmlType">Type of the XML.</param>
        /// <param name="xml">The XML that is considered invalid.</param>
        public InvalidCatalogXmlException(string channel, string xmlType, string xml)
            : base(channel, String.Format(CultureInfo.InvariantCulture, CrossTierResources.XmlIncorrectFormat, xmlType))
        {
            this._xml = xml;
            this._xmlType = xmlType;
        }

        #endregion

        #region Constructor (protected)

        /// <summary>
        /// Initializes a new instance of the InvalidCatalogXmlException class.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected InvalidCatalogXmlException()
            : base()
        {
        }

        /// <summary>
        /// Initializes a new instance of the InvalidCatalogXmlException class.
        /// </summary>
        /// <param name="message">The message.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected InvalidCatalogXmlException(string message)
            : this(message, null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the InvalidCatalogXmlException class.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="innerException">The inner exception.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected InvalidCatalogXmlException(string message, Exception innerException)
            : base(String.Empty, message, innerException)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="InvalidCatalogXmlException"/> class.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">The <paramref name="info"/> parameter is null. </exception>
        ///   
        /// <exception cref="T:System.Runtime.Serialization.SerializationException">The class name is null or <see cref="P:System.Exception.HResult"/> is zero (0). </exception>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected InvalidCatalogXmlException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }

        #endregion

        #region Properties (public)

        /// <summary>
        /// Gets the type of the XML.
        /// </summary>
        /// <value>
        /// The type of the XML.
        /// </value>
        public string XmlType
        {
            get { return this._xmlType; }
        }

        /// <summary>
        /// Gets the XML.
        /// </summary>
        public string Xml
        {
            get { return this._xml; }
        }

        #endregion

        #region Overrides

        /// <summary>
        /// When overridden in a derived class, sets the <see cref="T:System.Runtime.Serialization.SerializationInfo"/> with information about the exception.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">
        /// The <paramref name="info"/> parameter is a null reference (Nothing in Visual Basic).
        ///   </exception>
        ///   
        /// <PermissionSet>
        ///   <IPermission class="System.Security.Permissions.FileIOPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Read="*AllFiles*" PathDiscovery="*AllFiles*"/>
        ///   <IPermission class="System.Security.Permissions.SecurityPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Flags="SerializationFormatter"/>
        /// </PermissionSet>
        [SecurityPermission(SecurityAction.LinkDemand, Flags = SecurityPermissionFlag.SerializationFormatter)]
        public override void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            base.GetObjectData(info, context);
        }

        #endregion
    }
}
