﻿//---------------------------------------------------------------------
// <copyright file="UnityContainerNotFoundException.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Exceptions
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Globalization;
    using System.Runtime.Serialization;
    using System.Security.Permissions;

    /// <summary>
    /// Exception thrown when the cache container name cannot be found in configuration.
    /// </summary>
    [Serializable]
    public class UnityContainerNotFoundException : CommerceServerContribBaseException
    {
        private string _unityContainerName;

        #region Constructors (public)

        /// <summary>
        /// Initializes a new instance of the UnityContainerNotFoundException class.
        /// </summary>
        /// <param name="channel">The name of the channel.</param>
        /// <param name="unityContainerName">Name of the unity container.</param>
        public UnityContainerNotFoundException(string channel, string unityContainerName)
            : base(channel, String.Format(CultureInfo.InvariantCulture, CrossTierResources.CacheContainerNotFound, unityContainerName))
        {
            this._unityContainerName = unityContainerName;
        }

        #endregion

        #region Constructor (protected)

        /// <summary>
        /// Initializes a new instance of the UnityContainerNotFoundException class.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected UnityContainerNotFoundException()
            : base()
        {
        }

        /// <summary>
        /// Initializes a new instance of the UnityContainerNotFoundException class.
        /// </summary>
        /// <param name="message">The message.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected UnityContainerNotFoundException(string message)
            : this(message, (Exception)null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the UnityContainerNotFoundException class.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="innerException">The inner exception.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected UnityContainerNotFoundException(string message, Exception innerException)
            : base(String.Empty, message, innerException)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="UnityContainerNotFoundException"/> class.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">The <paramref name="info"/> parameter is null. </exception>
        ///   
        /// <exception cref="T:System.Runtime.Serialization.SerializationException">The class name is null or <see cref="P:System.Exception.HResult"/> is zero (0). </exception>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors", Justification = "We do not want devs to use these")]
        protected UnityContainerNotFoundException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }

        #endregion

        #region Properties (public)

        /// <summary>
        /// Gets the unit container name
        /// </summary>
        /// <value>
        /// The unity container name.
        /// </value>
        public string UnityContainerName
        {
            get { return this._unityContainerName; }
        }

        #endregion

        #region Overrides

        /// <summary>
        /// When overridden in a derived class, sets the <see cref="T:System.Runtime.Serialization.SerializationInfo"/> with information about the exception.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">
        /// The <paramref name="info"/> parameter is a null reference (Nothing in Visual Basic).
        ///   </exception>
        ///   
        /// <PermissionSet>
        ///   <IPermission class="System.Security.Permissions.FileIOPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Read="*AllFiles*" PathDiscovery="*AllFiles*"/>
        ///   <IPermission class="System.Security.Permissions.SecurityPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Flags="SerializationFormatter"/>
        /// </PermissionSet>
        [SecurityPermission(SecurityAction.LinkDemand, Flags = SecurityPermissionFlag.SerializationFormatter)]
        public override void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            base.GetObjectData(info, context);
        }

        #endregion
    }
}
