﻿//-----------------------------------------------------------------------
// <copyright file="CommerceServerContribErrorCodes.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the CommerceServerContribErrorCodes class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier
{
    using System;

    /// <summary>
    /// Defines well-known error codes used by Commerce Server Contrib.
    /// </summary>
    public static class CommerceServerContribErrorCodes
    {
        /// <summary>
        /// Generic Warning
        /// </summary>
        public const string Warning = "000";

        /// <summary>
        /// Generica error
        /// </summary>
        public const string GenericError = "111";
        
        /// <summary>
        /// Gets the error code that represents a captcha validation failure.
        /// </summary>
        public const string CaptchaValidationFailed = "201";

        /// <summary>
        /// Gets the error code that represents a backend request failure.
        /// </summary>
        public const string BackEndRequestFailed = "202";

        /// <summary>
        /// Gets the error code for a TypeConversionFailed validation error.
        /// </summary>
        public const string TypeConversionFailed = "203";

        /// <summary>
        /// Gets the error code for a ValueOutOfRange validation error.
        /// </summary>
        public const string ValueOutOfRange = "204";

        /// <summary>
        /// Gets the error code for a InvalidPropertyValueType validation error.
        /// </summary>
        public const string InvalidPropertyValueType = "205";

        /// <summary>
        /// Gets the error code for a method or operation that is not implemented.
        /// </summary>
        public const string NotImplemented = "206";

        /// <summary>
        /// Gets the error code that indicates the checkout flow id (CFId) of the basket a user is
        /// accessing does not match the CFId contained in that user's secure cookie.  This could
        /// indicate that a cookie replay attack is being attempted.
        /// </summary>
        public const string CheckoutFlowIdMismatch = "207";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.ValidationFault"/>.
        /// </summary>
        public const string ValidationFault = "208";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.ItemAlreadyExistsFault"/>.
        /// </summary>
        public const string ItemAlreadyExistsFault = "209";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.AbortOperationFault"/>.
        /// </summary>
        public const string AbortOperationFault = "210";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.AuthorizationFault"/>.
        /// </summary>
        public const string AuthorizationFault = "211";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.CatalogRemoveFault"/>.
        /// </summary>
        public const string CatalogRemoveFault = "212";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.CommerceExpiredSessionFault"/>.
        /// </summary>
        public const string CommerceExpiredSessionFault = "213";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.CommerceNoSessionFault"/>.
        /// </summary>
        public const string CommerceNoSessionFault = "214";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.InvalidSearchQueryFault"/>.
        /// </summary>
        public const string InvalidSearchQueryFault = "215";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.ItemDoesNotExistFault"/>.
        /// </summary>
        public const string ItemDoesNotExistFault = "216";

        /// <summary>
        /// Gets the error code for an error that was generated by a <see cref="CommerceServer.Foundation.OptimisticLockFault"/>.
        /// </summary>
        public const string OptimisticLockFault = "217";

        /// <summary>
        /// Gets the error code for basket is empty.
        /// </summary>
        public const string BasketEmpty = "218";

        /// <summary>
        /// Gets the error code that indicates a review could not be created because of a permission violation.
        /// </summary>
        public const string ReviewPermissionViolation = "219";

        /// <summary>
        /// Redirection JS error code.
        /// </summary>
        public const string Redirect = "302";
    }
}
