﻿//---------------------------------------------------------------------
// <copyright file="RequestTemplateParameterExtensions.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Helpers
{
    using CommerceServer.Foundation;
    using CommerceServer.Foundation.RequestTemplates;
    using System;

    /// <summary>
    /// Extensions class that defines help method on <see cref="RequestTemplateParameter" /> class.
    /// </summary>
    public static class RequestTemplateParameterExtensions
    {
        /// <summary>
        /// Gets the type of the request template parameter by checking against the enum <see cref="RequestTemplateParameterType" />
        /// </summary>
        /// <param name="parameter">The class responsible for calling this function <see cref="RequestTemplateParameter" />.</param>
        /// <param name="parameterKey">The parameter key which should match to the Canonical Name of the argument.</param>
        /// <returns>Returns the Value from the <see cref="RequestTemplateParameterType" /> enumeration.</returns>
        public static RequestTemplateParameterType GetRequestTemplateParameterType(this RequestTemplateParameter parameter, string parameterKey)
        {
            ParameterChecker.CheckForNullOrEmpty(parameterKey, "parameterKey");
            string[] parameterKeyTokens = parameterKey.Split(new string[] { StringConstants.RequestTemplateArgumentSeparator }, StringSplitOptions.RemoveEmptyEntries);
            if (parameterKeyTokens.Length == 0)
            {
                // TODO: Should this class live in Product or here
                // throw new InvalidRequestTemplateParameterException("--", parameterKey);
            }

            return (RequestTemplateParameterType)Enum.Parse(typeof(RequestTemplateParameterType), parameterKeyTokens[0], true);
        }
    }
}
