﻿//---------------------------------------------------------------------
// <copyright file="SerializationHelper.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Helpers
{
    using System;
    using System.Collections.Generic;
    using System.IO;
    using System.Runtime.Serialization;
    using System.Xml;
    using System.Xml.Serialization;
    using CommerceServer.Foundation;

    /// <summary>
    /// Used to help in the serialization and deserialization of objects
    /// </summary>
    public static class SerializationHelper
    {
        /// <summary>
        /// Serializes the specified entity.
        /// </summary>
        /// <param name="entity">The entity to serialize.</param>
        /// <param name="outputType">Type of the output.</param>
        /// <returns>The serialized object</returns>
        public static string Serialize(object entity, string outputType)
        {
            switch (outputType)
            {
                case StringConstants.OutputTypeJson:
                    var jsonSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();

                    return jsonSerializer.Serialize(entity);

                case StringConstants.OutputTypeXmlDataContract:
                    var dataContractSerializer = new DataContractSerializer(entity.GetType(), new Type[] { typeof(CommerceRelationshipList), typeof(string[]), typeof(CommerceRelationship) });
                    var ms = new MemoryStream();
                    dataContractSerializer.WriteObject(ms, entity);

                    var sr = new StreamReader(ms);
                    ms.Seek(0, SeekOrigin.Begin);

                    return sr.ReadToEnd();

                case StringConstants.OutputTypeXml:
                    var xmlSerializer = new XmlSerializer(entity.GetType(), new Type[] { typeof(CommerceRelationshipList), typeof(string[]), typeof(CommerceRelationship) });
                    var memoryStream = new MemoryStream();
                    xmlSerializer.Serialize(memoryStream, entity);

                    var streamReader = new StreamReader(memoryStream);
                    memoryStream.Seek(0, SeekOrigin.Begin);

                    return streamReader.ReadToEnd();
            }

            return null;
        }

        /// <summary>
        /// Deserializes the specified entity.
        /// </summary>
        /// <typeparam name="T">The type to deserialize into</typeparam>
        /// <param name="entity">The entity to deserialize.</param>
        /// <param name="outputType">Type of the output.</param>
        /// <returns>The deserialized entity</returns>
        public static T Deserialize<T>(string entity, string outputType)
        {
            ParameterChecker.CheckForNullOrEmpty(entity, "entity");
            switch (outputType)
            {
                case StringConstants.OutputTypeJson:
                    var jsonSerializer = new System.Web.Script.Serialization.JavaScriptSerializer();

                    return jsonSerializer.Deserialize<T>(entity);

                case StringConstants.OutputTypeXmlDataContract:
                    var dataContractSerializer = new DataContractSerializer(typeof(T), new Type[] { typeof(CommerceRelationshipList), typeof(string[]), typeof(List<CommerceEntity>), typeof(List<object>), typeof(CommerceEntity) });
                    XmlReader reader = XmlReader.Create(new StringReader(entity));
                    return (T)dataContractSerializer.ReadObject(reader);

                case StringConstants.OutputTypeXml:
                    var xmlSerializer = new XmlSerializer(typeof(T), new Type[] { typeof(CommerceRelationshipList), typeof(string[]), typeof(List<CommerceEntity>), typeof(List<object>), typeof(CommerceEntity) });
                    XmlReader xmlReader = XmlReader.Create(new StringReader(entity));
                    return (T)xmlSerializer.Deserialize(xmlReader);
            } 

            return default(T);
        }
    }
}
