﻿//---------------------------------------------------------------------
// <copyright file="Strings.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Helpers
{
    /// <summary>
    /// UserCookieSslMode enum
    /// </summary>
    public enum UserCookieSslMode
    {
        /// <summary>
        /// SSL Mode Enable
        /// </summary>
        Enabled,

        /// <summary>
        /// SSL Mode Disable
        /// </summary>
        Disabled,

        /// <summary>
        /// SSL Mode Mixed
        /// </summary>
        Mixed
    }

    /// <summary>
    /// Some known or common property categories that should be used
    /// </summary>
    public enum CommonPropertyCategories
    {
        /// <summary>
        /// Property category to use for settings that are commerce related.
        /// </summary>
        CommerceServerContrib,

        /// <summary>
        /// Property Category for advanced commerce settings (maps to "Advanced (Commerce)")
        /// </summary>
        AdvancedCS,

        /// <summary>
        /// Property Category for Url parameter overrides (also maps to "Advanced (Commerce)", but used anyway to show difference in code)
        /// </summary>
        RequestParameters,

        /// <summary>
        /// Property Category for appearance related properties (maps "Appearance (Commerce)")
        /// </summary>
        AppearanceCS,

        /// <summary>
        /// Property Category for modifiable strings from resources (also maps to "Appearance (Commerce)", but used anyway to show difference in code)
        /// </summary>
        DisplayText,

        /// <summary>
        /// Property Personalization for properties related to personalization, SEO and benchmarking
        /// </summary>
        Personalization,

        /// <summary>
        /// Property Category for search box autocomplete
        /// </summary>
        AutoComplete,

        /// <summary>
        /// Property category for tab connections configuration
        /// </summary>
        TabConnection
    }

    /// <summary>
    /// A places to store common constants
    /// </summary>
    public static class StringConstants
    {
        /// <summary>
        /// The ID of the root site.
        /// </summary>
        public const string RootSiteId = "Root";
			
        /// <summary>
        /// Character used as a delimiter.
        /// </summary>
        public const char Delimiter = ';';

        /// <summary>
        /// Default unity container name.
        /// </summary>
        public const string DefaultUnityContainerName = "Default";

        /// <summary>
        /// The name of the default channel in Commerce Server
        /// </summary>
        public const string DefaultChannelName = "DefaultChannel";

        /// <summary>
        /// Used to represent Xml with data contract output type
        /// </summary>
        public const string OutputTypeXmlDataContract = "xml-datacontract";

        /// <summary>
        /// Used to represent Xml output type
        /// </summary>
        public const string OutputTypeXml = "xml";

        /// <summary>
        /// Used to represent Json output type
        /// </summary>
        public const string OutputTypeJson = "json";

        /// <summary>
        /// Used to represent Object output type
        /// </summary>
        public const string OutputTypeObject = "poco";

        /// <summary>
        /// The name of the default culture for the localized values of the site settings lists
        /// </summary>
        public const string SiteSettingDefaultCultureName = "*";

        /// <summary>
        /// The name of the key into the RequestContext properties dictionary that contains the domain name
        /// </summary>
        public const string RequestContextDomainNameKey = "DomainName";

        /// <summary>
        /// The name of the key into the RequestContext properties dictionary that contains the site Id
        /// </summary>
        public const string RequestContextSiteIdKey = "SiteId";

        /// <summary>
        /// The name of the key into the RequestContext properties dictionary that contains the site brand name.
        /// </summary>
        public const string RequestContextBrandKey = "Brand";

        /// <summary>
        /// The name of the key into the RequestContext properties dictionary that contains the user context
        /// </summary>
        public const string RequestContextUserContextKey = "UserContext";

        /// <summary>
        /// The seperator used to seperate pieces of a request template argument property e.g. Search_Id
        /// </summary>
        public const string RequestTemplateArgumentSeparator = "_";

        /// <summary>
        /// The name used to identify the Option RequestTemplateParameterType
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Param", Justification = "Don't want to make variable name to long.")]
        public const string RequestTemplateParamTypeOption = "Option";

        /// <summary>
        /// The name used to identify the PropertiesToSet RequestTemplateParameterType
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Param", Justification = "Don't want to make variable name to long.")]
        public const string RequestTemplateParamTypePropertiesToSet = "PropertiesToSet";

        /// <summary>
        /// The name used to identify the Search RequestTemplateParameterType
        /// </summary>
        public const string RequestTemplateParamTypeSearch = "Search";

        /// <summary>
        /// The name used to identify the Sort RequestTemplateParameterType
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Param", Justification = "Don't want to make variable name to long.")]
        public const string RequestTemplateParamTypeSort = "Sort";

        /// <summary>
        /// Xml Root Node Name
        /// </summary>
        public const string XmlRootNodeName = "Root";

        /// <summary>
        /// Xml Element Start Open
        /// </summary>
        public const string XmlElementStartOpen = "<";

        /// <summary>
        /// Xml Element Start Close
        /// </summary>
        public const string XmlElementStartClose = ">";

        /// <summary>
        /// Xml Element End Open
        /// </summary>
        public const string XmlElementEndOpen = "</";

        /// <summary>
        /// Xml Element End Close
        /// </summary>
        public const string XmlElementEndClose = ">";
    }    
}
