﻿//---------------------------------------------------------------------
// <copyright file="IBrandProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System.Collections.Generic;
    using CommerceServerContrib.CrossTier.Providers;

    /// <summary>
    /// Used to provider the name of the current channel
    /// </summary>
    public interface IBrandProvider
    {
        /// <summary>
        /// Gets the name of the current channel.
        /// </summary>
        Brand Current { get; }

        /// <summary>
        /// Gets the default brand defined in the presentation configuration.
        /// </summary>
        /// <returns>The default brand defined in the presentation configuration.</returns>
        Brand GetDefaultBrand();

        /// <summary>
        /// Gets a brand defined in the presentation configuration file by its name.
        /// </summary>
        /// <param name="brandName">The name of the brand to retrieve.</param>
        /// <returns>The brand with the provided <paramref name="brandName"/>.</returns>
        Brand GetBrandByName(string brandName);
        
        /// <summary>
        /// Gets all brands defined in the configuration file.
        /// </summary>
        /// <returns>A list containing all brands defined in the configuration file.</returns>
        List<Brand> GetAllBrands();
    }
}
