﻿//---------------------------------------------------------------------
// <copyright file="ICommerceContext.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>ICommerceContext interface</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces
{
    using CommerceServer.Foundation;
    using CommerceServerContrib.CrossTier.Entities;
    using System;
    using System.Web;

    /// <summary>
    /// Used to provide information about the current site requests
    /// </summary>
    public interface ICommerceContext : ISiteContext
    {
        /// <summary>
        /// Gets or sets the user.
        /// </summary>
        /// <value>
        /// The current user.
        /// </value>
        User User { get; set; }

        /// <summary>
        /// Gets the user ID
        /// </summary>
        string UserId { get; }

        /// <summary>
        /// Gets a value indicating whether or not the user is anonymous.
        /// </summary>
        bool IsUserAuthenticated { get; }

        /// <summary>
        /// Gets a value indicating whether this instance is anonymous.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is anonymous; otherwise, <c>false</c>.
        /// </value>
        bool IsAnonymous { get; }

        /// <summary>
        /// Gets the culture code.
        /// </summary>
        string CultureCode { get; }

        /// <summary>
        /// Gets the culture UI code.
        /// </summary>
        string CultureUICode { get; }

        /// <summary>
        /// Gets the default basket name
        /// </summary>
        string DefaultBasketName { get; }

        /// <summary>
        /// Gets the default basket type
        /// </summary>
        int DefaultBasketType { get; }

        /// <summary>
        /// Gets the default catalog name.
        /// </summary>
        string DefaultCatalogName { get; }

        /// <summary>
        /// Gets the current location path
        /// </summary>
        string FullLocationPath { get; }

        /// <summary>
        /// Gets the current HttpContext
        /// </summary>
        HttpContext CurrentContext { get; }

        /// <summary>
        /// Gets the current date and time.
        /// </summary>
        DateTime CurrentDateTime { get; }

        /// <summary>
        /// Gets the browser.
        /// </summary>
        /// <value>The browser.</value>
        string Browser { get; }

        /// <summary>
        /// Gets the current site id.
        /// </summary>
        string SiteId { get; }

        /// <summary>
        /// Gets a value indicating whether or not the current call is an AJAX call
        /// </summary>
        bool IsAjaxCall { get; }

        /// <summary>
        /// Gets a value indicating whether this instance is secure connection.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is secure connection; otherwise, <c>false</c>.
        /// </value>
        bool IsSecureConnection { get; }

        /// <summary>
        /// Maps the file path.
        /// </summary>
        /// <param name="path">The relative path to the file.</param>
        /// <returns>The path to the mapped file</returns>
        string MapFilePath(string path);

        /// <summary>
        /// Gets the web part property validation exception that will be thrown.
        /// </summary>
        /// <param name="message">The message of the exception.</param>
        /// <returns>Returns the web part property validation exception.</returns>
        Exception GetWebPartPropertyValidationException(string message);

        /// <summary>
        /// Redirects to.
        /// </summary>
        /// <param name="path">The path to redirect to.</param>
        /// <param name="endResponse">if set to <c>true</c> [end response].</param>
        void RedirectTo(string path, bool endResponse);

        /// <summary>
        /// Redirects to the configured page not found web page.  If none are configured then only a standard 404 is returned.
        /// </summary>
        void RedirectTo404();
    }
}
