﻿//-----------------------------------------------------------------------
// <copyright file="ICatalogImageManager.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>ICatalogImageManager Interface.</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System;
    using System.Xml.XPath;
    using System.Collections.Generic;

    /// <summary>
    /// Catalog Image Manager defining blue print for defining where Product Image should live
    /// </summary>
    public interface ICatalogImageManager
    {
        /// <summary>
        /// Gets or sets the base URL.
        /// </summary>
        /// <value>
        /// The base URL.
        /// </value>
        Uri BaseUrl { get; set; }

        /// <summary>
        /// Gets or sets the catalog image delimiter.
        /// </summary>
        /// <value>
        /// The catalog image delimiter.
        /// </value>
        string CatalogImageDelimiter { get; set; }

        /// <summary>
        /// Gets the image with img extension.
        /// </summary>
        /// <param name="imageName">Name of the image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <param name="baseUrl">The base URL.</param>
        /// <returns>Returns the relative image path.</returns>
        string GetCatalogImagePath(string imageName, string imageSize, Uri baseUrl);

        /// <summary>
        /// Gets the catalog image path.
        /// </summary>
        /// <param name="imageName">Name of the image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <returns>Returns the relative image path.</returns>
        string GetCatalogImagePath(string imageName, string imageSize);

        /// <summary>
        /// Gets the first catalog image for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <param name="baseUrl">The base URL.</param>
        /// <returns>
        /// Returns image path for XSLT
        /// </returns>
        string GetFirstCatalogImagePath(string delimitedCatalogImageName, string imageSize, Uri baseUrl);

        /// <summary>
        /// Gets the first catalog image for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <returns>
        /// Returns image path for XSLT
        /// </returns>
        string GetFirstCatalogImagePath(string delimitedCatalogImageName, string imageSize);

        /// <summary>
        /// Gets the catalog images for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <param name="baseUrl">The base URL.</param>
        /// <returns>
        /// Returns image paths for XSLT
        /// </returns>
        XPathNodeIterator GetAlternativeCatalogImagePaths(string delimitedCatalogImageName, string imageSize, Uri baseUrl);

        /// <summary>
        /// Gets the catalog images for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <returns>
        /// Returns image paths for XSLT
        /// </returns>
        XPathNodeIterator GetAlternativeCatalogImagePaths(string delimitedCatalogImageName, string imageSize);

        /// <summary>
        /// Gets the catalog images for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <param name="baseUrl">The base URL.</param>
        /// <returns>
        /// Returns image paths
        /// </returns>
        List<string> GetAlternativeCatalogImagePathsNoXml(string delimitedCatalogImageName, string imageSize, Uri baseUrl);

        /// <summary>
        /// Gets the catalog images for XSL transform.
        /// </summary>
        /// <param name="delimitedCatalogImageName">Name of the delimited catalog image.</param>
        /// <param name="imageSize">Size of the image.</param>
        /// <returns>
        /// Returns image paths
        /// </returns>
        List<string> GetAlternativeCatalogImagePathsNoXml(string delimitedCatalogImageName, string imageSize);
    }
}