﻿//-----------------------------------------------------------------------
// <copyright file="ISiteSettingsProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>ISiteSettingsProvider Interface.</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Interfaces
{
    using CommerceServerContrib.CrossTier.Entities;
    using System.Collections.Generic;

    /// <summary>
    /// ISiteSettingsProvider interface
    /// </summary>
    public interface ISiteSettingsProvider
    {
        /// <summary>
        /// Gets the web setting.
        /// </summary>
        /// <param name="key">The key to search for.</param>
        /// <param name="groupId">The group id.</param>
        /// <returns>
        /// A string value for the setting or string.Empty if the setting doesn't exist.
        /// </returns>
        string GetSiteSetting(string key, string groupId);

        /// <summary>
        /// Gets the web setting.
        /// </summary>
        /// <param name="key">The key to search for.</param>
        /// <param name="siteId">The site id.</param>
        /// <param name="groupId">The group id.</param>
        /// <returns>
        /// A string value for the setting or string.Empty if the setting doesn't exist.
        /// </returns>
        string GetSiteSetting(string key, string siteId, string groupId);

        /// <summary>
        /// Gets the site settings.
        /// </summary>
        /// <param name="groupId">The group id.</param>
        /// <returns>A list of simpleResponse values for the groupId or empty list of simpleResponse if the groupId doesn't exist.</returns>
        List<SiteSettingsResponse> GetSiteSettings(string groupId);

        /// <summary>
        /// Gets the site settings.
        /// </summary>
        /// <param name="siteId">The site id.</param>
        /// <param name="groupId">The group id.</param>
        /// <returns>A list of simpleResponse values for the groupId or empty list of simpleResponse if the groupId doesn't exist.</returns>
        List<SiteSettingsResponse> GetSiteSettings(string siteId, string groupId);

        /// <summary>
        /// Gets the web setting.
        /// </summary>
        /// <param name="key">The key to search for.</param>
        /// <returns>A string value for the setting or string.Empty if the setting doesn't exist.</returns>
        string GetFromWebSetting(string key);

        /// <summary>
        /// Takes a friendly url and converts it to its physical mapping
        /// </summary>
        /// <param name="friendlyUrl">The friendly url to convert.</param>
        /// <returns>
        /// Returns the physical url as a string, if it cannot be found then null is returned
        /// </returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1055:UriReturnValuesShouldNotBeStrings", Justification = "Not returning an actual url")]
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1054:UriParametersShouldNotBeStrings", MessageId = "0#", Justification = "Not returning an actual url")]
        string ConvertFriendlyToPhysicalUrl(string friendlyUrl);
    }
}