﻿//---------------------------------------------------------------------
// <copyright file="IAuthenticationProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>IAuthenticationProvider interface</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System.Web.Security;
    using CommerceServerContrib.CrossTier.Entities;

    /// <summary>
    /// IAuthenticationProvider interface
    /// </summary>
    public interface IAuthenticationProvider
    {
        /// <summary>
        /// Gets a value indicating whether SSL is required for cookies issued by the authentication provider.
        /// </summary>
        bool RequireSsl { get; }

        /// <summary>
        /// Validates the user.
        /// </summary>
        /// <param name="userId">The user id.</param>
        /// <param name="userEmail">Name of the user.</param>
        /// <param name="password">The password.</param>
        /// <returns>True if the user is valid, false otherwise</returns>
        bool ValidateUser(out string userId, string userEmail, string password);

        /// <summary>
        /// Signs in the user into the site.
        /// </summary>
        /// <param name="userId">The user id.</param>
        /// <param name="userEmail">The user email.</param>
        /// <param name="userName">Name of the user.</param>
        /// <param name="password">Password of the user.</param>
        /// <param name="rememberMe">if set to <c>true</c> [remember me].</param>
        /// <returns>
        /// True is the user was sucessfully signed in, false otherwise
        /// </returns>
        bool SignIn(string userId, string userEmail, string userName, string password, bool rememberMe);

        /// <summary>
        /// Determines whether [is user identity valid].
        /// </summary>
        /// <param name="userCookie">The user cookie.</param>
        /// <returns>
        ///   <c>true</c> if [is user identity valid]; otherwise, <c>false</c>.
        /// </returns>
        bool IsUserIdentityValid(UserCookie userCookie);

        /// <summary>
        /// Issues the registered cookie.
        /// </summary>
        /// <param name="userId">The user id.</param>
        /// <param name="userEmail">The user email.</param>
        /// <param name="userName">Name of the user.</param>
        void IssueRegisteredCookie(string userId, string userEmail, string userName);

        /// <summary>
        /// Terminateds the session.
        /// </summary>
        void TerminateSession();

        /// <summary>
        /// Gets a user by email.
        /// </summary>
        /// <param name="userEmail">The user email.</param>
        /// <returns>A MembershipUser.</returns>
        MembershipUser GetUser(string userEmail);
    }
}