﻿//---------------------------------------------------------------------
// <copyright file="IBaseController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces.Controllers
{
    using CommerceServer.Foundation.RequestTemplates;
    using System.Collections.Generic;

    /// <summary>
    /// Used to handle communication with the backend subsystem
    /// </summary>
    public interface IBaseController
    {
        /// <summary>
        /// Gets the template controller responsible for providing available templates for the subsystem.
        /// </summary>
        IRequestTemplateController TemplateController { get; }

        /// <summary>
        /// Gets the group id for the controller.
        /// </summary>
        string GroupId { get; }

        /// <summary>
        /// Gets or sets the display name for the controller.
        /// </summary>
        string DisplayName { get; set; }

        /// <summary>
        /// Queues up the request to the backend.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <param name="parameters">The parameters required by the template.</param>
        void QueueRequest(string templateId, RequestTemplateParameterCollection parameters);

        /// <summary>
        /// Queues up the request to the backend.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <param name="parameters">The parameters required by the template.</param>
        /// <param name="outputType">Type of the output.</param>
        void QueueRequest(string templateId, RequestTemplateParameterCollection parameters, string outputType);

        /// <summary>
        /// Immediately prcesses a request template request.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <param name="parameters">The parameters required by the template.</param>
        /// <param name="outputType">Type of the output.</param>
        /// <returns>The results from the RequestTemplate request</returns>
        ServiceAdapterResponse<object> ProcessRequest(string templateId, RequestTemplateParameterCollection parameters, string outputType);
        
        /// <summary>
        /// Executes the template the request.
        /// </summary>
        /// <returns>The results from the request</returns>
        ServiceAdapterResponse<object> ProcessRequest();
    }
}
