﻿//---------------------------------------------------------------------
// <copyright file="IRequestTemplateController.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces.Controllers
{
    using CommerceServer.Foundation.RequestTemplates;

    /// <summary>
    /// The interface that must be implemented by all template controllers
    /// </summary>
    public interface IRequestTemplateController
    {
        /// <summary>
        /// Gets all of the available templates for the specified group.
        /// </summary>
        /// <param name="groupId">The group to look for.</param>
        /// <returns>A collection of all of the templates in that group</returns>
        ServiceAdapterResponse<ClientRequestTemplateCollection> GetAvailableTemplates(string groupId);

        /// <summary>
        /// Gets all of the available templates arguments for the specified group and template id.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <returns>
        /// A collection of all of the templates arguments
        /// </returns>
        ServiceAdapterResponse<RequestTemplateParameterCollection> GetTemplateArguments(string templateId);

        /// <summary>
        /// Gets all of the validation rules for the template id
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <returns>All of the rules for the template</returns>
        ServiceAdapterResponse<object> GetTemplateValidationRules(string templateId);

        /// <summary>
        /// Gets the request template.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <returns>The request template</returns>
        RequestTemplate GetRequestTemplate(string templateId);
    }
}
