﻿//-----------------------------------------------------------------------
// <copyright file="IBaseControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Defines the IBaseControl class</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System.Collections.Generic;

    /// <summary>
    /// The interface that all controls much implement
    /// </summary>
    public interface IBaseControl
    {
        /// <summary>
        /// Gets or sets the responses that came in from the backend.
        /// </summary>
        /// <value>
        /// The responses from the backend.
        /// </value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly", Justification = "Required for the design.")]
        List<object> ResponseData
        {
            get;
            set;
        }

        /// <summary>
        /// Returns the data model that the backend returned
        /// </summary>
        /// <typeparam name="T">The type the model should be converted to</typeparam>
        /// <returns>The model as Type T</returns>
        T Model<T>();

        /// <summary>
        /// Models this instance.
        /// </summary>
        /// <typeparam name="T">The type to convert the response to</typeparam>
        /// <param name="index">The particular response to get the model from</param>
        /// <returns>The model as type T</returns>
        T Model<T>(int index);

        /// <summary>
        /// Sets the view bag data.
        /// </summary>
        /// <param name="viewBag">The view bag data.</param>
        void SetViewBag(Dictionary<string, object> viewBag);

        /// <summary>
        /// Returns a specific item from the ViewBag
        /// </summary>
        /// <param name="key">The key to look for in the bag.</param>
        /// <returns>If found the object will be returned otherwise null</returns>
        object GetFromViewBag(string key);

        /// <summary>
        /// Returns a specific item from the ViewBag
        /// </summary>
        /// <typeparam name="T">The type to return the object as</typeparam>
        /// <param name="key">The key to look for in the bag.</param>
        /// <returns>If found the object will be returned otherwise null</returns>
        T GetFromViewBag<T>(string key);
    }
}
