﻿//---------------------------------------------------------------------
// <copyright file="ICacheableWebPart.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System;

    /// <summary>
    /// Used to discribe a webpart that can be cached
    /// </summary>
    public interface ICacheableWebPart
    {
        /// <summary>
        /// Gets or sets a value indicating whether to cache the web part content.
        /// </summary>
        /// <value>
        ///   <c>true</c> if the web part content is to be cached; otherwise, <c>false</c>.
        /// </value>
        bool CacheContent
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether to use the current page url in the cache key
        /// </summary>
        /// <value>
        ///   <c>true</c> if the web part content is to be cached; otherwise, <c>false</c>.
        /// </value>
        bool CacheKeyShouldIncludeUrl
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether specific querystrings should be used when caching with a url
        /// </summary>
        /// <value>
        ///   <c>true</c> if specific values should be used; otherwise, <c>false</c>.
        /// </value>
        bool CacheWithSpecificQueryStrings
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the cache expiration time.
        /// </summary>
        /// <value>
        /// The cache expiration time.
        /// </value>
        TimeSpan? CacheExpiration
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the cache querystring settings.
        /// </summary>
        /// <value>
        /// The cache querystring settings.
        /// </value>
        string CacheQueryStringSettings
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether the content of the response is cached.
        /// </summary>
        /// <value>
        /// <c>true</c> if the response content is to be cached; otherwise, <c>false</c>.
        /// </value>
        bool CacheResponseContent
        {
            get;
            set;
        }
    }
}
