﻿//---------------------------------------------------------------------
// <copyright file="IServiceResponse.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.CrossTier.Interfaces
{
    using System.Xml.Linq;
    using System.Collections.Generic;

    /// <summary>
    /// The different types of rendering supported by the webpart
    /// </summary>
    public enum RenderModes
    {
        /// <summary>
        /// Figures out the rendering type based on the file extension
        /// </summary>
        Auto,

        /// <summary>
        /// When the webpart is not rendering anything
        /// </summary>
        None,

        /// <summary>
        /// Xslt rendering mode
        /// </summary>
        Xslt,

        /// <summary>
        /// Ascx rending mode
        /// </summary>
        Ascx
    }

    /// <summary>
    /// An interface that is used to communicate between webparts
    /// </summary>
    public interface IServiceResponse
    {
        /// <summary>
        /// Gets or sets the service response.
        /// </summary>
        /// <returns></returns>
        XDocument XmlMessage { get; set; }

        /// <summary>
        /// Gets or sets the data that should be passed to the rendering engine.
        /// </summary>
        /// <value>
        /// The render data.
        /// </value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly", Justification = "Required for the design.")]
        List<object> RenderData
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the current render mode.
        /// </summary>
        RenderModes RenderMode
        {
            get;
        }
    }
}
