﻿//---------------------------------------------------------------------
// <copyright file="DefaultRequestTemplateCacheKeyProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.CrossTier.Providers
{
    using System;
    using System.Collections.Generic;
    using System.Globalization;
    using System.Text;
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServer.Foundation.RequestTemplates;

    /// <summary>
    /// Implementation used to build the cache key for the result returned by a request template.
    /// </summary>
    public class DefaultRequestTemplateCacheKeyProvider : IRequestTemplateCacheKeyProvider
    {
        #region Interface Methods

        /// <summary>
        /// Returns the cache key to be used when caching Queued requests.
        /// </summary>
        /// <param name="templateId">The template id.</param>
        /// <param name="inputParameters">The input parameters to the request template.</param>
        /// <param name="outputType">The output type such as XML, JSON, etc...</param>
        /// <param name="culture">The culture of the output data.  If null, the current culture will be used.</param>
        /// <returns>
        /// The cache key is returned based on the given context.
        /// </returns>
        public string GetCacheKey(string templateId, RequestTemplateParameterCollection inputParameters, string outputType, string culture)
        {
            return BuildQueueRequestCacheKey(templateId, inputParameters, outputType, culture);
        }

        #endregion

        #region Private (static) Methods

        private static string BuildQueueRequestCacheKey(string templateId, RequestTemplateParameterCollection inputParameters, string outputType, string culture)
        {
            StringBuilder sb = new StringBuilder();

            sb.Append(templateId);

            if (inputParameters != null)
            {
                foreach (var parameter in inputParameters)
                {
                    sb.Append(String.Concat("_" + parameter.Key + "_" + parameter.Value));
                }
            }

            if (!String.IsNullOrEmpty(outputType))
            {
                sb.Append(String.Concat("_" + outputType.ToLower(CultureInfo.InvariantCulture)));
            }

            if (!String.IsNullOrEmpty(culture))
            {
                sb.Append(String.Concat("_" + culture.ToLower(CultureInfo.InvariantCulture)));
            }
            else
            {
                sb.Append(String.Concat("_" + CultureInfo.CurrentCulture));
            }

            return sb.ToString();
        }

        #endregion
    }
}
