﻿//-----------------------------------------------------------------------
// <copyright file="CssRemover.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>CssRemover class</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.Web.SharePoint
{
    using System;
    using System.Web.UI;
    using System.Globalization;
    using System.IO;
    using System.Security.Permissions;
    using System.Web;
    using Microsoft.SharePoint.WebControls;

    /// <summary>
    /// SharePointCssRemover that supresses the load of Core.css in public display mode 
    /// </summary>
    [AspNetHostingPermission(SecurityAction.Demand, Level = AspNetHostingPermissionLevel.Minimal)]
    public class CssRemover : CssLink
    {
        /// <summary>
        /// Renders the specified output.
        /// </summary>
        /// <param name="output">The output.</param>
        protected override void Render(HtmlTextWriter output)
        {
            if (this.Page == null)
            {
                return;
            }

            // Let base render the stylesheets
            var sw = new StringWriter(CultureInfo.CurrentCulture);
            base.Render(new HtmlTextWriter(sw));
            string renderedOutput = sw.ToString();

            // Split the styleSheets into an array
            string[] styleSheets = renderedOutput.Split(new[] { '\n' }, StringSplitOptions.RemoveEmptyEntries);
            if (styleSheets.Length == 0)
            {
                output.Write(renderedOutput);
            }
            else
            {
                var reorderedStyleSheets = new string[styleSheets.Length];
                for (int i = 0; i < styleSheets.Length; i++)
                {
                    var currentOffset = styleSheets.Length - (i + 1);
                    var sheet = styleSheets[currentOffset];

                    if (!SharePointHelper.ShouldRunElevated &&
                        ((sheet.IndexOf("core.css", StringComparison.OrdinalIgnoreCase) > -1) ||
                         (sheet.IndexOf("corev4.css", StringComparison.OrdinalIgnoreCase) > -1) ||
                         (sheet.IndexOf("controls.css", StringComparison.OrdinalIgnoreCase) > -1) ||
                         (sheet.IndexOf("defaultsite.css", StringComparison.OrdinalIgnoreCase) > -1) ||
                         (sheet.IndexOf("pagelayouts.css", StringComparison.OrdinalIgnoreCase) > -1)))
                    {
                        continue;
                    }

                    if (sheet.IndexOf("search.css", StringComparison.OrdinalIgnoreCase) > -1)
                    {
                        continue;
                    }

                    reorderedStyleSheets[i] = sheet + "\n";
                }

                output.Write(string.Concat(reorderedStyleSheets));
            }
        }
    }
}