﻿//---------------------------------------------------------------------
// <copyright file="SharePointShopperName.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>SharePointShopperName class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web.SharePoint
{
    using System.Globalization;
    using System.Security.Permissions;
    using System.Web;
    using System.Web.UI;
    using Microsoft.Security.Application;

    /// <summary>
    /// Displays the welcome message including the shopper's name.
    /// </summary>
    [AspNetHostingPermission(SecurityAction.Demand, Level = AspNetHostingPermissionLevel.Minimal)]
    [ToolboxData("<{0}:SharePointLoginStatus runat=\"server\" />")]
    public class SharePointShopperName : CommerceServerContribShopperName
    {
        /// <summary>
        /// Writes the content of the LiteralControl object to the ASP.NET page.
        /// </summary>
        /// <param name="output">An HtmlTextWriter object that renders the content of the LiteralControl object to the requesting client.</param>
        protected override void Render(HtmlTextWriter output)
        {
            if (this.Context == null || !PresentationServiceLocator.Current.SiteContext.IsUserAuthenticated)
            {
                return;
            }

            var shopperName = PresentationServiceLocator.Current.SiteContext.User.Name;
            if (string.IsNullOrEmpty(shopperName) && HttpContext.Current.User != null)
            {
                var userName = (HttpContext.Current.User.Identity.Name).Split('|');
                shopperName = !string.IsNullOrEmpty(userName[1]) ? userName[1] : string.Empty;
            }

            if (!string.IsNullOrEmpty(shopperName))
            {
                shopperName = Sanitizer.GetSafeHtmlFragment(shopperName);

                output.Write("<span>" + string.Format(CultureInfo.CurrentCulture, this.WelcomeText, shopperName) + "</span>");
            }
        }
    }
}