﻿//---------------------------------------------------------------------
// <copyright file="FeatureHelper.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web.SharePoint
{
    using System;
    using System.Globalization;
    using System.IO;
    using System.Reflection;
    using System.Text.RegularExpressions;
    using Microsoft.SharePoint;
    using Microsoft.SharePoint.Administration;
    using Microsoft.SharePoint.Utilities;
    using System.Collections;

    /// <summary>
    /// Feature helper class
    /// </summary>
    public static class FeatureHelper
    {
        /// <summary>
        /// Replaces any instance of a token with the cooresponding value from the Feature.XML file
        /// </summary>
        /// <param name="input">The string that contains the tokens</param>
        /// <param name="properties">Properties that have the values</param>
        /// <returns>A string with all tokens replaced with proper values.</returns>
        public static string ReplaceTokens(string input, SPFeaturePropertyCollection properties)
        {
            string newString = input;

            foreach (SPFeatureProperty property in properties)
            {
                string findString = "{" + property.Name + "}";

                if (Regex.IsMatch(input, findString, RegexOptions.IgnoreCase))
                {
                    newString = Regex.Replace(newString, findString, property.Value, RegexOptions.IgnoreCase);
                }
            }

            return newString;
        }

        /// <summary>
        /// Replaces any instance of a token with the cooresponding value from the Feature.XML file
        /// </summary>
        /// <param name="input">The string that contains the tokens</param>
        /// <param name="properties">Properties that have the values</param>
        /// <returns>A string with all tokens replaced with proper values.</returns>
        public static string ReplaceTokens(string input, Hashtable properties)
        {
            string newString = input;

            foreach (string key in properties.Keys)
            {
                string findString = "{" + key + "}";

                if (Regex.IsMatch(input, findString, RegexOptions.IgnoreCase))
                {
                    newString = Regex.Replace(newString, findString, properties[key].ToString(), RegexOptions.IgnoreCase);
                }
            }

            return newString;
        }

        /// <summary>
        /// method for replacing certain text in a text file
        /// </summary>
        /// <param name="file">file we're looking in (include full path)</param>
        /// <param name="searchFor">text we're looking for</param>
        /// <param name="replaceWith">text to replace it with</param>
        /// <returns>True if the replace was successful.</returns>
        public static bool ReplaceTokensInFile(string file, string searchFor, string replaceWith)
        {
            try
            {
                StreamReader reader = new StreamReader(file);

                string contents = reader.ReadToEnd();

                reader.Close();
                reader.Dispose();

                contents = Regex.Replace(contents, searchFor, replaceWith);

                StreamWriter writer = new StreamWriter(file);

                writer.Write(contents);
                writer.Close();
                writer.Dispose();

                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }

        /// <summary>
        /// Gets the embedded resource.
        /// </summary>
        /// <param name="fileName">The filename.</param>
        /// <returns>A string representation of the embedded resource.</returns>
        public static string GetEmbeddedResource(string fileName)
        {
            Assembly asm = typeof(FeatureHelper).Assembly;
            Stream xmlStream = asm.GetManifestResourceStream(typeof(FeatureHelper).Namespace + ".FeatureActivation.DefaultConfigs." + fileName);

            if (xmlStream != null)
            {
                var sr = new StreamReader(xmlStream);
                string output = sr.ReadToEnd();
                sr.Close();

                return output;
            }

            return string.Empty;
        }

        /// <summary>
        /// Deletes any instance of SP Job
        /// </summary>
        /// <param name="webApp">The SP Web Application.</param>
        /// <param name="jobName">The Job name</param>
        public static void DeleteJobInstance(SPWebApplication webApp, string jobName)
        {
            if (webApp == null)
            {
                return;
            }

            foreach (SPJobDefinition job in webApp.JobDefinitions)
            {
                if (job.Name == jobName && job.WebApplication.Name == webApp.Name)
                {
                    job.Delete();
                }
            }
        }

        /// <summary>
        /// Deletes any instance of SP Job
        /// </summary>
        /// <param name="service">The SP Web Application.</param>
        /// <param name="jobName">The Job name</param>
        public static void DeleteJobInstance(SPService service, string jobName)
        {
            if (service == null)
            {
                return;
            }

            foreach (SPJobDefinition job in service.JobDefinitions)
            {
                if (job.Name == jobName && job.Service.Name == service.Name)
                {
                    job.Delete();
                }
            }
        }

        /// <summary>
        /// Reads the file content from hive file.
        /// </summary>
        /// <param name="featureName">Name of the feature.</param>
        /// <param name="fileName">Name of the file.</param>
        /// <returns>String output of what is in the file.</returns>
        public static string ReadFileContentFromHiveFile(string featureName, string fileName)
        {
            string sourcePath = string.Empty;

#if SP2013
            sourcePath = string.Format(CultureInfo.InvariantCulture, "{0}\\FEATURES\\{1}\\{2}", SPUtility.GetVersionedGenericSetupPath("Template", 14), featureName, fileName);
#else
            sourcePath = string.Format(CultureInfo.InvariantCulture, "{0}\\FEATURES\\{1}\\{2}", SPUtility.GetGenericSetupPath("Template"), featureName, fileName);
#endif

            var fileInfo = new FileInfo(sourcePath);
            if (fileInfo.Exists)
            {
                StreamReader reader = fileInfo.OpenText();
                return reader.ReadToEnd();
            }

            return string.Empty;
        }
    }
}
