﻿//---------------------------------------------------------------------
// <copyright file="SharePointVirtualPathProvider.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web.SharePoint
{
    using System;
    using System.Web.Hosting;

    /// <summary>
    /// Used to deal with an issue
    /// </summary>
    public class SharePointVirtualPathProvider : VirtualPathProvider
    {
        private const string SharePointDesignerFile = "~/_vti_inf.html";

        /// <summary>
        /// Gets a value that indicates whether a directory exists in the virtual file system.
        /// </summary>
        /// <param name="virtualDir">The path to the virtual directory.</param>
        /// <returns>
        /// true if the directory exists in the virtual file system; otherwise, false.
        /// </returns>
        public override bool DirectoryExists(string virtualDir)
        {
            if (virtualDir.StartsWith("~/services", StringComparison.OrdinalIgnoreCase))
            {
                return false;
            }

            return Previous.DirectoryExists(virtualDir);
        }

        /// <summary>
        /// Gets a value that indicates whether a file exists in the virtual file system.
        /// </summary>
        /// <param name="virtualPath">The path to the virtual file.</param>
        /// <returns>
        /// true if the file exists in the virtual file system; otherwise, false.
        /// </returns>
        public override bool FileExists(string virtualPath)
        {
            if (virtualPath.Equals(SharePointDesignerFile, StringComparison.OrdinalIgnoreCase))
            {
                return true;
            }

            return Previous.FileExists(virtualPath);
        }
    }
}
