﻿//-----------------------------------------------------------------------
// <copyright file="CommonXsltParameter.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>CommonXsltParameter class.</summary>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.CrossTier.Entities;
    using CommerceServerContrib.CrossTier;

    /// <summary>
    /// Used to provide common xslt parameters
    /// </summary>
    public class CommonXsltParameter : IRenderParameterProvider
    {
        private const string CategoryPathKey = "CategoryPathKey";
        private const string ReturnUrlKey = "ReturnUrlKey";
        private RenderParameters _xsltParameters = null;

        /// <summary>
        /// Gets the XSLT parameters, a class implementing this interface can manage the logic of retrieval as long as it conforms
        /// to this method.
        /// </summary>
        /// <returns>
        /// XsltParameters List <see cref="CommerceServerContrib.CrossTier.Entities.RenderParameters"/>
        /// </returns>
        public RenderParameters GetRenderParameters()
        {
            if (this._xsltParameters != null)
            {
                return this._xsltParameters;
            }

            var provider = PresentationServiceLocator.Current.GetImplementation<IQueryStringProvider>();

            string categoryPathQueryParameterKey = provider.GetQueryString(CategoryPathKey).QueryParameterKey;
            string returnUrlQueryParameterKey = provider.GetQueryString(ReturnUrlKey).QueryParameterKey;

            var requestQueryString = UrlBuilder.CurrentUrl.QueryList;

            string catpath = requestQueryString[categoryPathQueryParameterKey];
            string returnUrl = System.Web.HttpUtility.UrlEncode(requestQueryString[returnUrlQueryParameterKey]);

            this._xsltParameters = new RenderParameters();

            var brand = PresentationServiceLocator.Current.BrandContext;
            var siteContext = PresentationServiceLocator.Current.SiteContext;

            this._xsltParameters.Add(new RenderParameter("_siteId", string.Empty, siteContext.SiteId));
            this._xsltParameters.Add(new RenderParameter("_brandName", string.Empty, brand.Name));
            this._xsltParameters.Add(new RenderParameter("_compareCookieName", string.Empty, string.Concat(brand.Name, "_compareCookie")));
            this._xsltParameters.Add(new RenderParameter("_compareCategoryCookieName", string.Empty, string.Concat(brand.Name, "_compareCategoryCookie")));
            this._xsltParameters.Add(new RenderParameter("_browseHistoryCookieName", string.Empty, "__CSDefaultUserBrowseHistory"));
            this._xsltParameters.Add(new RenderParameter("catPath", string.Empty, (catpath ?? string.Empty)));
            this._xsltParameters.Add(new RenderParameter("_isAuthenticated", string.Empty, siteContext.IsUserAuthenticated));
            this._xsltParameters.Add(new RenderParameter("_saveShippingCookieName", string.Empty, string.Concat(brand.Name, "_saveShippingCookie")));
            this._xsltParameters.Add(new RenderParameter("_saveBillingCookieName", string.Empty, string.Concat(brand.Name, "_saveBillingCookie")));
            this._xsltParameters.Add(new RenderParameter("_savePaymentCookieName", string.Empty, string.Concat(brand.Name, "_savePaymentCookie")));
            this._xsltParameters.Add(new RenderParameter("_isGuestCheckoutCookieName", string.Empty, string.Concat(brand.Name, "_isGuestCheckoutCookieName")));
            this._xsltParameters.Add(new RenderParameter("_returnUrl", string.Empty, returnUrl ?? string.Empty));
            this._xsltParameters.Add(new RenderParameter("_isUserAuthenticated", string.Empty, PresentationServiceLocator.Current.SiteContext.IsUserAuthenticated));
            this._xsltParameters.Add(new RenderParameter("_cultureCode", string.Empty, PresentationServiceLocator.Current.SiteContext.CultureCode));
            this._xsltParameters.Add(new RenderParameter("_cultureUICode", string.Empty, PresentationServiceLocator.Current.SiteContext.CultureUICode));

            return this._xsltParameters;            
        }
    }
}
