﻿//---------------------------------------------------------------------
// <copyright file="FriendlyNameAttribute.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System;
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServer.Foundation;

    /// <summary>
    /// Used to allow objects to have a friendly name to display to users
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1019:DefineAccessorsForAttributeArguments", Justification = "There is no need to expose these properties.")]
    [AttributeUsage(AttributeTargets.Class)]
    public sealed class FriendlyNameAttribute : Attribute
    {
        private string _name;
        private string _area;

        /// <summary>
        /// Initializes a new instance of the <see cref="FriendlyNameAttribute"/> class.
        /// </summary>
        /// <param name="resource">The resource file.</param>
        /// <param name="key">The key in the resource file.</param>
        public FriendlyNameAttribute(string resource, string key)
        {
            ParameterChecker.CheckForNullOrEmpty(resource, "resource");
            ParameterChecker.CheckForNullOrEmpty(key, "key");

            var resourceProvider = PresentationServiceLocator.Current.ResourceProvider;

            if (resourceProvider == null)
            {
                return;
            }

            this._name = resourceProvider.GetResource(resource, key);
            this._area = resourceProvider.GetResource(resource, key + "_Area");
        }

        /// <summary>
        /// Gets the name to display to users.
        /// </summary>
        public string Name
        {
            get
            {
                return this._name;
            }
        }

        /// <summary>
        /// Gets the area associated to the controller
        /// </summary>
        public string Area
        {
            get
            {
                return this._area;
            }
        }
    }
}
