﻿//---------------------------------------------------------------------
// <copyright file="LocalizedWebCategoryAttribute.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System;
    using System.Globalization;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServerContrib.CrossTier.Interfaces;

    /// <summary>
    /// Overrides System.ComponentModel.CategoryAttribute to return a localized
    /// category name from web global resources.
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1019:DefineAccessorsForAttributeArguments", Justification = "Unable to set base.Category property after initialization so adding accessor is not possible.")]
    [AttributeUsage(AttributeTargets.Property)]
    public sealed class LocalizedWebCategoryAttribute : System.ComponentModel.CategoryAttribute
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="LocalizedWebCategoryAttribute"/> class
        /// by supplying a selected "common" category.
        /// </summary>
        /// <param name="commonCategory">the category logical name</param>
        public LocalizedWebCategoryAttribute(CommonPropertyCategories commonCategory)
            : base(ConvertToResourceKey(commonCategory))
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="LocalizedWebCategoryAttribute"/> class.
        /// </summary>
        /// <param name="category">the category logical name</param>
        public LocalizedWebCategoryAttribute(string category)
            : base(category)
        {
        }

        #endregion Constructors

        #region Protected Methods

        /// <summary>
        /// Gets Localized String
        /// </summary>
        /// <param name="value">the name of the category</param>
        /// <returns>localized string</returns>
        protected override string GetLocalizedString(string value)
        {
            return ResourceHelper.GetCommerceServerContrib(value);
        }

        #endregion Protected Methods

        #region Private properties

        private static string ConvertToResourceKey(CommonPropertyCategories value)
        {
            return String.Concat("CommonPropertyCategories_", value.ToString());
        }

        #endregion
    }
}
