﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribCssControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Renders a CSS import element in Commerce Server Contrib using the base url from settings and list.</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Web.UI;

    /// <summary>
    /// Renders a CSS control on the page.
    /// </summary>
    public class CommerceServerContribCssControl : Control
    {
        /// <summary>
        /// Gets or sets the relative URL for the CSS link.
        /// </summary>
        /// <value>
        /// The relative URL.
        /// </value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1056:UriPropertiesShouldNotBeStrings", Justification = "Urls are used as strings")]
        public virtual string RelativeUrl
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the media type of the CSS link.
        /// </summary>
        /// <value>
        /// The media type.
        /// </value>
        public virtual string Media
        {
            get;
            set;
        }

        /// <summary>
        /// Sends server control content to a provided <see cref="T:System.Web.UI.HtmlTextWriter"/> object, which writes the content to be rendered on the client.
        /// </summary>
        /// <param name="writer">The <see cref="T:System.Web.UI.HtmlTextWriter"/> object that receives the server control content.</param>
        protected override void Render(HtmlTextWriter writer)
        {
            //// <link rel="stylesheet" type="text/css" href="/Styles/tab.css" />
            writer.Write(this.CreateElement().ToString());
        }

        private GenericHtmlElement CreateElement()
        {
            GenericHtmlElement cssElement = new GenericHtmlElement("link");
            cssElement.AddAttribute("rel", "stylesheet");
            cssElement.AddAttribute("type", "text/css");

            if (!string.IsNullOrEmpty(this.Media))
            {
                cssElement.AddAttribute("media", this.Media);
            }

            cssElement.AddAttribute("href", CdnHelper.CreateCSSUrl(this.RelativeUrl));
            
            return cssElement;
        }
    }
}
