﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribImageControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Image control used in the Commerce Server Contrib solution which is CDN aware.</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Collections;
    using System.Web.UI;
    using System.Web.UI.WebControls;

    /// <summary>
    /// Image control used in the Commerce Server Contrib solution which is CDN aware.  It defaults to the catalog CDN zone.
    /// </summary>
    public class CommerceServerContribImageControl : WebControl
    {
        private string cdnArea = "SiteCDN";

        /// <summary>
        /// Gets or sets the relative URL.
        /// </summary>
        /// <value>
        /// The relative URL.
        /// </value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1056:UriPropertiesShouldNotBeStrings", Justification = "Urls are used as strings throughout the system")]
        public virtual string RelativeUrl
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the CDN area.
        /// </summary>
        /// <value>
        /// The CDN area.
        /// </value>
        public virtual string CdnArea
        {
            get
            {
                return this.cdnArea;
            }

            set
            {
                this.cdnArea = value;
            }
        }

        /// <summary>
        /// Sends server control content to a provided <see cref="T:System.Web.UI.HtmlTextWriter"/> object, which writes the content to be rendered on the client.
        /// </summary>
        /// <param name="writer">The <see cref="T:System.Web.UI.HtmlTextWriter"/> object that receives the server control content.</param>
        protected override void Render(HtmlTextWriter writer)
        {
            var element = this.CreateElement();
            IEnumerator attributes = this.Attributes.Keys.GetEnumerator();
            while (attributes.MoveNext())
            {
                element.AddAttribute((string)attributes.Current, this.Attributes[(string)attributes.Current]);
            }
            
            writer.Write(element.ToString());
        }

        /// <summary>
        /// Builds the GenericHtmlElement used to render the image tag.
        /// </summary>
        /// <returns>A GenericHtmlElement used to render the image tag.</returns>
        private GenericHtmlElement CreateElement()
        {
            GenericHtmlElement imageElement = new GenericHtmlElement("img");
            if (!string.IsNullOrEmpty(this.CssClass))
            {
                imageElement.AddAttribute("class", this.CssClass);
            }

            if (this.CdnArea.Equals(CommerceServerContrib.Web.CdnArea.CatalogCDN))
            {
                imageElement.AddAttribute("src", CdnHelper.CreateCatalogImageUrl(this.RelativeUrl));
            }
            else if (this.CdnArea.Equals(CommerceServerContrib.Web.CdnArea.MarketingCDN))
            {
                imageElement.AddAttribute("src", CdnHelper.CreateMarketingImageUrl(this.RelativeUrl));
            }
            else
            {
                imageElement.AddAttribute("src", CdnHelper.CdnUrl(this.RelativeUrl, this.CdnArea));
            }

            return imageElement;
        }
    }
}
