﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribScriptControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A server control that renders a script tag.</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Web.UI;

    /// <summary>
    /// Renders a script element on the page.
    /// </summary>
    public class CommerceServerContribScriptControl : Control
    {
        /// <summary>
        /// Gets or sets the relative URL for the script.
        /// </summary>
        /// <value>
        /// The relative URL.
        /// </value>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1056:UriPropertiesShouldNotBeStrings", Justification = "Urls are used as string.")]
        public virtual string RelativeUrl
        {
            get;
            set;
        }

        /// <summary>
        /// Sends server control content to a provided <see cref="T:System.Web.UI.HtmlTextWriter"/> object, which writes the content to be rendered on the client.
        /// </summary>
        /// <param name="writer">The <see cref="T:System.Web.UI.HtmlTextWriter"/> object that receives the server control content.</param>
        protected override void Render(HtmlTextWriter writer)
        {
            writer.Write(this.CreateElement().ToString());
            writer.Write(GenericHtmlElement.ClosingElement("script"));
        }

        private GenericHtmlElement CreateElement()
        {
            GenericHtmlElement scriptControl = new GenericHtmlElement("script");
            scriptControl.SelfCloseElement = false;
            scriptControl.AddAttribute("src", CdnHelper.CreateScriptUrl(this.RelativeUrl));
            
            scriptControl.AddAttribute("type", "text/javascript");
            return scriptControl;
        }
    }
}
