﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribScriptManager.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Commerce Server Contrib script manager for CDN support.</summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Globalization;
    using System.Web.UI;

    /// <summary>
    /// A script manager for Commerce Server
    /// </summary>
    public class CommerceServerContribScriptManager : ScriptManager
    {
        private const string ScriptCdnUrl = "var cdnUrlScripts = '{0}';";
        private const string ScriptCdnUrlKey = "ScriptCdnUrl";

        /// <summary>
        /// Called when the class is initialised
        /// </summary>
        /// <param name="e">Any events for the initialization</param>
        protected override void OnInit(System.EventArgs e)
        {
            base.OnInit(e);

            if (!CdnHelper.HideDependentCalls)
            {
                var scriptUrl = CdnHelper.GetBaseUrlForArea(CdnArea.ScriptCDN);
                var scriptBlock = string.Format(CultureInfo.InvariantCulture, ScriptCdnUrl, scriptUrl);

                RegisterClientScriptBlock(this, typeof(CommerceServerContribScriptManager), ScriptCdnUrlKey, scriptBlock, true);
            }
        }

        /// <summary>
        /// Called when the script manager is reading through the script references
        /// </summary>
        /// <param name="e">The argument for the current script.</param>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Portability", "CA1903:UseOnlyApiFromTargetedFramework", MessageId = "System.Web.UI.ScriptReferenceBase", Justification = "We will only be running this on .NET 3.5 SP1")]
        protected override void OnResolveScriptReference(ScriptReferenceEventArgs e)
        {
            if (!string.IsNullOrEmpty(e.Script.Path) && 
                !CdnHelper.IsAbsoluteUrl(e.Script.Path))
            {
                var url = CdnHelper.CdnUrl(e.Script.Path, CdnArea.ScriptCDN);
                e.Script.Path = url;
            }
        }

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.PreRender"/> event, and registers script files and services for partial-page updates.
        /// </summary>
        /// <param name="e">The event data.</param>
        /// <exception cref="T:System.InvalidOperationException">The browser that made the partial-page request does not support at least DOM Level 1.0.</exception>
        protected override void OnPreRender(System.EventArgs e)
        {
            if (CdnHelper.HideDependentCalls)
            {
                this.Scripts.Clear();
            }
            else
            {
                base.OnPreRender(e);
            }
        }
    }
}
