﻿//---------------------------------------------------------------------
// <copyright file="WebPartZoneControlAdapter.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System.Web.UI;
    using System.Web.UI.Adapters;
    using System.Web.UI.WebControls.WebParts;

    /// <summary>
    /// Remove all tables in WebPartZone
    /// </summary>
    public class WebPartZoneControlAdapter : ControlAdapter
    {
        private const string ZoneIgnoreWPZ = "wpz";
        private const string ZoneIgnoreMain = "main";

        /// <summary>
        /// Override Render
        /// </summary>
        /// <param name="writer">The <see cref="System.Web.UI.HtmlTextWriter"/> object</param>
        protected override void Render(HtmlTextWriter writer)
        {
            if (this.Page.Request.IsAuthenticated)
            {
                if (this.Control.ID.Equals(ZoneIgnoreWPZ, System.StringComparison.OrdinalIgnoreCase) || this.Control.ID.Equals(ZoneIgnoreMain, System.StringComparison.OrdinalIgnoreCase))
                {
                    base.Render(writer);
                }
                else
                {
                    var swpm = WebPartManager.GetCurrentWebPartManager(this.Page);
                    var inEditMode = (swpm.DisplayMode != WebPartManager.BrowseDisplayMode);

                    if (inEditMode)
                    {
                        base.Render(writer);
                    }
                    else
                    {
                        this.RenderZoneCleanly(writer);
                    }
                }
            }
            else
            {
                this.RenderZoneCleanly(writer);
            }
        }

        private void RenderZoneCleanly(HtmlTextWriter writer)
        {
            var webPartZone = this.Control as WebPartZone;

            if (webPartZone != null)
            {
                foreach (WebPart wp in webPartZone.WebParts)
                {
                    wp.RenderControl(writer);
                }
            }
        }
    }
}
