﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribShopperName.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>CommerceServerContribShopperName class</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System.ComponentModel;
    using System.Globalization;
    using System.Security.Permissions;
    using System.Web;
    using System.Web.UI;
    using Microsoft.Security.Application;

    /// <summary>
    /// Displays the welcome message including the shopper's name.
    /// </summary>
    [AspNetHostingPermission(SecurityAction.Demand, Level = AspNetHostingPermissionLevel.Minimal)]
    [ToolboxData("<{0}:CommerceServerContribShopperName runat=\"server\" />")]
    public class CommerceServerContribShopperName : LiteralControl
    {
        /// <summary>
        /// Gets or sets the welcome text.
        /// </summary>
        /// <value>
        /// The welcome text.
        /// </value>
        [Category("Appearance"), DefaultValue(""), Bindable(true), Localizable(true)]
        public virtual string WelcomeText
        {
            get;
            set;
        }

        /// <summary>
        /// Writes the content of the LiteralControl object to the ASP.NET page.
        /// </summary>
        /// <param name="output">An HtmlTextWriter object that renders the content of the LiteralControl object to the requesting client.</param>
        protected override void Render(HtmlTextWriter output)
        {
            if (this.Context != null && PresentationServiceLocator.Current.SiteContext.User != null && !string.IsNullOrEmpty(PresentationServiceLocator.Current.SiteContext.User.Name))
            {
                output.Write("<span>" + string.Format(CultureInfo.CurrentCulture, this.WelcomeText, Sanitizer.GetSafeHtmlFragment(PresentationServiceLocator.Current.SiteContext.User.Name)) + "</span>");
            }
        }
    }
}