﻿//---------------------------------------------------------------------
// <copyright file="EditPage.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System;
    using System.ComponentModel;
    using System.Web;
    using System.Web.UI;
    using System.Web.UI.WebControls;
    using System.Web.UI.WebControls.WebParts;

    /// <summary>
    /// A control for switching to the different modes of a page.
    /// </summary>
    [DefaultProperty("Text")]
    [ToolboxData("<{0}:EditPage runat=server></{0}:EditPage>")]
    public class EditPage : CompositeControl
    {
        #region Private Fields

        private Label modeLabel;
        private LinkButton editLinkButton;
        private LinkButton browseLinkButton;
        private LinkButton connectionLinkButton;
        private WebPartManager _currentWebPartManager;

        #endregion

        #region Public Properties

        /// <summary>
        /// Gets or sets the name of the web part manager.
        /// </summary>
        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("")]
        [Localizable(true)]
        public string WebPartManagerName
        {
            get
            {
                string s = (string)ViewState["WebPartManagerName"];
                return ((s == null) ? string.Empty : s);
            }

            set
            {
                ViewState["WebPartManagerName"] = value;
            }
        }

        #endregion

        #region Overrides

        /// <summary>
        /// Called by the ASP.NET page framework to notify server controls that use composition-based
        /// implementation to create any child controls in preparation for posting back or rendering.
        /// </summary>
        protected override void CreateChildControls()
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null && PresentationServiceLocator.Current.SiteContext.IsUserAuthenticated)
            {
                this.Controls.Clear();

                this.modeLabel = new Label();
                this.SetBrowseModeLabel();
                this.Controls.Add(this.modeLabel);

                this.browseLinkButton = new LinkButton { ID = "BrowseLinkButton", Text = "Browse" };
                this.browseLinkButton.Click += new EventHandler(this.BrowseLinkButton_Click);
                this.Controls.Add(this.browseLinkButton);

                if (this.Page.User.Identity.IsAuthenticated)
                {
                    this.editLinkButton = new LinkButton { ID = "EditLinkButton", Text = "Edit" };
                    this.editLinkButton.Click += new EventHandler(this.EditLinkButton_Click);
                    this.Controls.Add(this.editLinkButton);

                    this.connectionLinkButton = new LinkButton { ID = "ConnectionLinkButton", Text = "Connect" };
                    this.connectionLinkButton.Click += new EventHandler(this.ConnectionLinkButton_Click);
                    this.Controls.Add(this.connectionLinkButton);
                }
            }
        }

        /// <summary>
        /// Writes the rendered content of the control and its child controls to the client using the specified HtmlTextWriter. 
        /// </summary>
        /// <param name="writer">An HtmlTextWriter that represents the output stream to render HTML content on the client.</param>
        protected override void Render(HtmlTextWriter writer)
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null && PresentationServiceLocator.Current.SiteContext.IsUserAuthenticated)
            {
                this.modeLabel.RenderControl(writer);

                writer.RenderBeginTag(HtmlTextWriterTag.Ul);

                writer.RenderBeginTag(HtmlTextWriterTag.Li);
                this.browseLinkButton.RenderControl(writer);
                writer.RenderEndTag();

                if (this.Page.User.Identity.IsAuthenticated)
                {
                    writer.RenderBeginTag(HtmlTextWriterTag.Li);
                    this.editLinkButton.RenderControl(writer);
                    writer.RenderEndTag();

                    writer.RenderBeginTag(HtmlTextWriterTag.Li);
                    this.connectionLinkButton.RenderControl(writer);
                    writer.RenderEndTag();
                }

                writer.RenderEndTag(); 
            }
        }

        #endregion

        #region Private Methods

        private void EditLinkButton_Click(object sender, EventArgs e)
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null)
            {
                manager.DisplayMode = WebPartManager.EditDisplayMode;
                this.SetBrowseModeLabel();
            }
        }

        private void BrowseLinkButton_Click(object sender, EventArgs e)
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null)
            {
                manager.DisplayMode = WebPartManager.BrowseDisplayMode;
                this.SetBrowseModeLabel();
            }

            PresentationServiceLocator.Current.SiteContext.RedirectTo(HttpContext.Current.Request.Url.ToString(), true);
        }

        private void ConnectionLinkButton_Click(object sender, EventArgs e)
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null)
            {
                manager.DisplayMode = WebPartManager.ConnectDisplayMode;
                this.SetBrowseModeLabel();
            }
        }

        private WebPartManager GetWebPartManager()
        {
            if (this._currentWebPartManager != null)
            {
                return this._currentWebPartManager;
            }

            this._currentWebPartManager = this.Page.Master.FindControl(this.WebPartManagerName) as WebPartManager;

            return this._currentWebPartManager;
        }

        private void SetBrowseModeLabel()
        {
            WebPartManager manager = this.GetWebPartManager();

            if (manager != null)
            {
                this.modeLabel.Text = "Webpart mode status: " + manager.DisplayMode.Name; 
            }
        }

        #endregion
    }
}
