﻿//---------------------------------------------------------------------
// <copyright file="WebRequestLifetimeManager.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System;
    using System.Web;
    using Microsoft.Practices.Unity;

    /// <summary>
    /// Makes sure that an object will only exist for the extent of a request
    /// </summary>
    public class WebRequestLifetimeManager : LifetimeManager
    {
        private readonly Guid _key = Guid.NewGuid();
        private object _singletonValue = null;

        private HttpContext CurrentContext
        {
            get
            {
                return HttpContext.Current;
            }
        }

        /// <summary>
        /// Gets the value from the store.
        /// </summary>
        /// <returns>The requested object</returns>
        public override object GetValue()
        {
            if (this.CurrentContext != null)
            {
                return this.CurrentContext.Items[this._key];
            }
            else
            {
                return this._singletonValue;
            }
        }

        /// <summary>
        /// Sets the value to the store.
        /// </summary>
        /// <param name="newValue">The new value.</param>
        public override void SetValue(object newValue)
        {
            if (this.CurrentContext != null)
            {
                this.CurrentContext.Items[this._key] = newValue;
            }
            else
            {
                this._singletonValue = newValue;
            }
        }

        /// <summary>
        /// Removes the value from the store.
        /// </summary>
        public override void RemoveValue()
        {
            if (this.CurrentContext != null)
            {
                var obj = this.GetValue();
                this.CurrentContext.Items.Remove(obj);
            }
            else
            {
                this._singletonValue = null;
            }
        }
    }
}
