﻿//---------------------------------------------------------------------
// <copyright file="CachingEditorPart.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Web.UI.WebControls.WebParts;
    using System.Web.UI.HtmlControls;
    using System.Web.UI.WebControls;
    using CommerceServerContrib.CrossTier.Interfaces;
    using System.Web.UI;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using CommerceServerContrib.CrossTier.Entities;
    using Microsoft.Security.Application;
    using CommerceServerContrib.CrossTier.Helpers;
    using System.Linq;

    /// <summary>
    /// Used to control the display of the cache setting
    /// </summary>
    public class CachingEditorPart : EditorPart
    {
        #region Private Fields

        private const string TitleKey = "CachingEditorPartTitle";
        private const string CacheContentDisplayName = "WebPartProperty_CacheContentDisplayName";
        private const string CacheContentDescription = "WebPartProperty_CacheContentDescription";
        private const string UseUrlInCacheKeyDisplayName = "WebPartProperty_UseUrlInCacheKeyDisplayName";
        private const string UseUrlInCacheKeyDescription = "WebPartProperty_UseUrlInCacheKeyDescription";
        private const string CacheExpirationDisplayName = "WebPartProperty_CacheExpirationDisplayName";
        private const string CacheExpirationDescription = "WebPartProperty_CacheExpirationDescription";
        private const string CacheUsingQueryStringsDescription = "WebPartProperty_CacheUsingQueryStringsDescription";
        private const string CacheUsingQueryStringsDisplayName = "WebPartProperty_CacheUsingQueryStringsDisplayName";
        private const string CacheResponseContentDisplayName = "WebPartProperty_CacheResponseContentDisplayName";
        private const string CacheResponseContentDescription = "WebPartProperty_CacheResponseContentDescription";
        private const string AddQueryStringDisplayName = "CachingEditor_AddQueryStringDisplayName";
        private const string AddQueryStringDescription = "CachingEditor_AddQueryStringDescription";
        private const string QueryStringSettingsKey = "QueryStringSettings";

        private HtmlTable _outerTable;
        private HtmlTable _existingParameterTable;

        private Label _lblEnableCaching;
        private Label _lblCacheExpiration;
        private Label _lblUseUrlInCacheKey;
        private Label _lblUseSpecificQueryStrings;
        private Label _lblCacheResponseContent;

        private CheckBox _cbEnableCaching;
        private CheckBox _cbUseUrlInCacheKey;
        private CheckBox _cbUseSpecificQueryStrings;
        private CheckBox _cbCacheResponseContent;

        private TextBox _txtCacheExpiration;

        private DropDownList _ddlQueryStringList;
        private Button _btnQueryStringListAdd;

        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="CachingEditorPart"/> class.
        /// </summary>
        public CachingEditorPart()
        {
            this.Title = ResourceHelper.GetCommerceServerContrib(TitleKey);
        }

        #region Properties

        /// <summary>
        /// Gets the webpart associated with this editor webpart
        /// </summary>
        protected virtual ICacheableWebPart AssociatedWebPart
        {
            get
            {
                return this.WebPartToEdit as ICacheableWebPart;
            }
        }

        /// <summary>
        /// Gets or sets the parameter settings for the querystring
        /// </summary>
        private string QueryStringSettings
        {
            get
            {
                return this.ViewState[QueryStringSettingsKey] == null ? string.Empty : this.ViewState[QueryStringSettingsKey].ToString();
            }

            set
            {
                this.ViewState[QueryStringSettingsKey] = value;
            }
        }

        #endregion

        #region Overridden Methods

        /// <summary>
        /// Saves the values in an <see cref="T:System.Web.UI.WebControls.WebParts.EditorPart"/> control to the corresponding properties in the associated <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control.
        /// </summary>
        /// <returns>
        /// true if the action of saving values from the <see cref="T:System.Web.UI.WebControls.WebParts.EditorPart"/> control to the <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control is successful; otherwise (if an error occurs), false.
        /// </returns>
        public override bool ApplyChanges()
        {
            var wp = this.AssociatedWebPart;

            if (wp == null)
            {
                return false;
            }

            if (!string.IsNullOrEmpty(this._txtCacheExpiration.Text))
            {
                this.AssociatedWebPart.CacheExpiration = System.TimeSpan.Parse(this._txtCacheExpiration.Text);
            }
            else
            {
                this.AssociatedWebPart.CacheExpiration = System.TimeSpan.Zero;
            }

            this.AssociatedWebPart.CacheContent = this._cbEnableCaching.Checked;
            this.AssociatedWebPart.CacheKeyShouldIncludeUrl = this._cbUseUrlInCacheKey.Checked;
            this.AssociatedWebPart.CacheWithSpecificQueryStrings = this._cbUseSpecificQueryStrings.Checked;
            this.AssociatedWebPart.CacheResponseContent = this._cbCacheResponseContent.Checked;

            this.AssociatedWebPart.CacheQueryStringSettings = this.QueryStringSettings;

            return true;
        }

        /// <summary>
        /// Retrieves the property values from a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control for its associated <see cref="T:System.Web.UI.WebControls.WebParts.EditorPart"/> control.
        /// </summary>
        public override void SyncChanges()
        {
            var wp = this.AssociatedWebPart;

            if (wp == null)
            {
                return;
            }

            this.QueryStringSettings = this.AssociatedWebPart.CacheQueryStringSettings;
        }

        /// <summary>
        /// Called by the ASP.NET page framework to notify server controls that use composition-based implementation to create any child controls they contain in preparation for posting back or rendering.
        /// </summary>
        protected override void CreateChildControls()
        {
            // setup all of the tables
            this._outerTable = new HtmlTable();
            this._existingParameterTable = new HtmlTable();
            this._existingParameterTable.Visible = false;

            // setup everything except for the query strings
            this.SetupBasicFields();
            
            // setup the querystring related fields
            this.SetupUrlQueryStrings();

            // set up the current values from the user
            this._txtCacheExpiration.Text = this.AssociatedWebPart.CacheExpiration.ToString();

            this._cbEnableCaching.Checked = this.AssociatedWebPart.CacheContent;
            this._cbUseUrlInCacheKey.Checked = this.AssociatedWebPart.CacheKeyShouldIncludeUrl;
            this._cbUseSpecificQueryStrings.Checked = this.AssociatedWebPart.CacheWithSpecificQueryStrings;
            this._cbCacheResponseContent.Checked = this.AssociatedWebPart.CacheResponseContent;

            this.ToggleDisplays();

            // add everyhing to the control collection
            this.Controls.Add(this._outerTable);
        }

        #endregion

        #region Control Events

        /// <summary>
        /// Called when the user tries to delete a querystring parameter
        /// </summary>
        /// <param name="sender">The sender control.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void DeleteClick(object sender, System.EventArgs e)
        {
            var paramSettings = SerializationHelper.Deserialize<List<ParameterSelection>>(this.QueryStringSettings, StringConstants.OutputTypeXmlDataContract);
            var selectedItem = paramSettings.First(p => p.Id == ((Button)sender).CommandName);

            if (selectedItem != null)
            {
                paramSettings.Remove(selectedItem);
                this.QueryStringSettings = SerializationHelper.Serialize(paramSettings, StringConstants.OutputTypeXmlDataContract);

                // re-render the querystring tab
                this.SetupUrlQueryStringTable(paramSettings);
            }
        }

        /// <summary>
        /// Called when the user tries to add a querystring to the list
        /// </summary>
        /// <param name="sender">The sender control.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void AddClick(object sender, System.EventArgs e)
        {
            List<ParameterSelection> paramSettings = null;

            if (!string.IsNullOrEmpty(this.QueryStringSettings))
            {
                paramSettings = SerializationHelper.Deserialize<List<ParameterSelection>>(this.QueryStringSettings, StringConstants.OutputTypeXmlDataContract);
            }

            if (paramSettings == null)
            {
                paramSettings = new List<ParameterSelection>();
            }

            if (!paramSettings.Any(p => p.Id == this._ddlQueryStringList.SelectedValue))
            {
                paramSettings.Add(new ParameterSelection() { Id = this._ddlQueryStringList.SelectedValue });

                this.QueryStringSettings = SerializationHelper.Serialize(paramSettings, StringConstants.OutputTypeXmlDataContract);

                // re-render the querystring tab
                this.SetupUrlQueryStringTable(paramSettings);
            }
        }

        /// <summary>
        /// Called when [use URL query strings].
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void OnUseUrlQueryStrings(object sender, System.EventArgs e)
        {
            this.ToggleDisplays();
        }

        /// <summary>
        /// Called when [use URL changed].
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void OnUseUrlChanged(object sender, System.EventArgs e)
        {
            this.ToggleDisplays();
        }

        /// <summary>
        /// Called when [enabled changed].
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void OnEnabledChanged(object sender, System.EventArgs e)
        {
            this.ToggleDisplays();
        }

        #endregion

        #region Private Methods

        private void SetupUrlQueryStrings()
        {
            var provider = PresentationServiceLocator.Current.GetImplementation<IQueryStringProvider>();
            var uiCulture = PresentationServiceLocator.Current.SiteContext.CultureUICode;

            // if the site contains no querystring provider then don't do anything
            if (provider != null)
            {
                // get all of the querystrings from the provider
                var queryStrings = provider.GetQueryStrings();

                // we should have atleast one querystring before we do anything
                if (queryStrings != null && queryStrings.Count > 0)
                {
                    this._ddlQueryStringList = new DropDownList();
                    this._ddlQueryStringList.Visible = false;
                    
                    this._btnQueryStringListAdd = new Button() { Text = ResourceHelper.GetCommerceServerContrib(AddQueryStringDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(AddQueryStringDescription) };
                    this._btnQueryStringListAdd.Visible = false;

                    this._btnQueryStringListAdd.Click += new System.EventHandler(this.AddClick);

                    // add all of the site querystrings to the list
                    foreach (var queryString in queryStrings)
                    {
                        this._ddlQueryStringList.Items.Add(new ListItem(queryString.Value.GetLocalizedDescription(uiCulture), queryString.Key));
                    }

                    this._outerTable.Rows.Add(UIHelper.CreateControlRow(new Collection<Control>() { this._ddlQueryStringList, this._btnQueryStringListAdd }, string.Empty));

                    // render out any previously selected items
                    if (!string.IsNullOrEmpty(this.QueryStringSettings))
                    {
                        var paramSettings = SerializationHelper.Deserialize<List<ParameterSelection>>(this.QueryStringSettings, StringConstants.OutputTypeXmlDataContract);
                        this.SetupUrlQueryStringTable(paramSettings);
                    }

                    this._outerTable.Rows.Add(UIHelper.CreateControlRow(this._existingParameterTable, string.Empty));
                }
            }
        }

        /// <summary>
        /// Setups the URL query string table.
        /// </summary>
        /// <param name="paramSettings">The param settings.</param>
        private void SetupUrlQueryStringTable(List<ParameterSelection> paramSettings)
        {
            if (paramSettings != null && paramSettings.Count > 0)
            {
                var headerRow = new HtmlTableRow();

                this._existingParameterTable.Rows.Clear();

                headerRow.Cells.Add(UIHelper.CreateCell(string.Empty));
                headerRow.Cells.Add(UIHelper.CreateCell(string.Concat("<b>", ResourceHelper.GetCommerceServerContrib("ServiceEditorPart_ParameterDescription"), "</b>")));
                this._existingParameterTable.Rows.Add(headerRow);

                foreach (var item in paramSettings)
                {
                    var bodyRow = new HtmlTableRow();

                    var delete = new Button
                    {
                        ID = Encoder.HtmlAttributeEncode(item.Id),
                        CommandName = Encoder.HtmlAttributeEncode(item.Id),
                        Text = ResourceHelper.GetCommerceServerContrib("ServiceEditorPart_Delete")
                    };

                    delete.Click += new System.EventHandler(this.DeleteClick);

                    bodyRow.Cells.Add(UIHelper.CreateControlCell(delete));
                    bodyRow.Cells.Add(UIHelper.CreateCell(Encoder.HtmlEncode(item.Id)));

                    this._existingParameterTable.Rows.Add(bodyRow);
                }

                this._existingParameterTable.Visible = true;
            }
            else
            {
                this._existingParameterTable.Rows.Clear();
                this._existingParameterTable.Visible = false;
            }
        }

        private void SetupBasicFields()
        {
            this._lblEnableCaching = new Label() { Text = ResourceHelper.GetCommerceServerContrib(CacheContentDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(CacheContentDescription), RenderTag = LabelTag.Label };
            this._cbEnableCaching = new CheckBox();
            this._cbEnableCaching.AutoPostBack = true;
            this._cbEnableCaching.CheckedChanged += new System.EventHandler(this.OnEnabledChanged);

            this._lblCacheExpiration = new Label() { Text = ResourceHelper.GetCommerceServerContrib(CacheExpirationDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(CacheExpirationDescription), RenderTag = LabelTag.Label };
            this._txtCacheExpiration = new TextBox();

            this._lblCacheExpiration.Visible = false;
            this._txtCacheExpiration.Visible = false;

            this._lblUseUrlInCacheKey = new Label() { Text = ResourceHelper.GetCommerceServerContrib(UseUrlInCacheKeyDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(UseUrlInCacheKeyDescription), RenderTag = LabelTag.Label };
            this._cbUseUrlInCacheKey = new CheckBox();
            this._cbUseUrlInCacheKey.AutoPostBack = true;
            this._cbUseUrlInCacheKey.CheckedChanged += new System.EventHandler(this.OnUseUrlChanged);

            this._lblUseUrlInCacheKey.Visible = false;
            this._cbUseUrlInCacheKey.Visible = false;

            this._lblUseSpecificQueryStrings = new Label() { Text = ResourceHelper.GetCommerceServerContrib(CacheUsingQueryStringsDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(CacheUsingQueryStringsDescription), RenderTag = LabelTag.Label };
            this._cbUseSpecificQueryStrings = new CheckBox();
            this._cbUseSpecificQueryStrings.AutoPostBack = true;
            this._cbUseSpecificQueryStrings.CheckedChanged += new System.EventHandler(this.OnUseUrlQueryStrings);
            
            this._lblUseSpecificQueryStrings.Visible = false;
            this._cbUseSpecificQueryStrings.Visible = false;

            this._cbEnableCaching.Checked = this.AssociatedWebPart.CacheContent;
            this._txtCacheExpiration.Text = this.AssociatedWebPart.CacheExpiration.ToString();
            this._cbUseUrlInCacheKey.Checked = this.AssociatedWebPart.CacheKeyShouldIncludeUrl;
            this._cbUseSpecificQueryStrings.Checked = this.AssociatedWebPart.CacheWithSpecificQueryStrings;

            this._lblCacheResponseContent = new Label() { Text = ResourceHelper.GetCommerceServerContrib(CacheResponseContentDisplayName), ToolTip = ResourceHelper.GetCommerceServerContrib(CacheResponseContentDescription), RenderTag = LabelTag.Label };
            this._cbCacheResponseContent = new CheckBox();
            this._cbCacheResponseContent.Checked = this.AssociatedWebPart.CacheResponseContent;

            this._outerTable.Rows.Add(UIHelper.CreateControlRow(new Collection<Control>() { this._cbEnableCaching, this._lblEnableCaching }, string.Empty));
            this._outerTable.Rows.Add(UIHelper.CreateControlRow(this._lblCacheExpiration, string.Empty));
            this._outerTable.Rows.Add(UIHelper.CreateControlRow(this._txtCacheExpiration, string.Empty));
            this._outerTable.Rows.Add(UIHelper.CreateControlRow(new Collection<Control>() { this._cbUseUrlInCacheKey, this._lblUseUrlInCacheKey }, string.Empty));
            this._outerTable.Rows.Add(UIHelper.CreateControlRow(new Collection<Control>() { this._cbUseSpecificQueryStrings, this._lblUseSpecificQueryStrings }, string.Empty));
            this._outerTable.Rows.Add(UIHelper.CreateControlRow(new Collection<Control>() { this._cbCacheResponseContent, this._lblCacheResponseContent }, string.Empty));
        }

        private void ToggleDisplays()
        {
            if (this._cbEnableCaching.Checked)
            {
                this._lblCacheExpiration.Visible = true;
                this._txtCacheExpiration.Visible = true;
                this._lblUseUrlInCacheKey.Visible = true;
                this._cbUseUrlInCacheKey.Visible = true;
                this._lblCacheResponseContent.Visible = true;
                this._cbCacheResponseContent.Visible = true;

                if (this._cbUseUrlInCacheKey.Checked)
                {
                    this._lblUseSpecificQueryStrings.Visible = true;
                    this._cbUseSpecificQueryStrings.Visible = true;

                    if (this._cbUseSpecificQueryStrings.Checked)
                    {
                        this._existingParameterTable.Visible = true;
                        if (this._ddlQueryStringList != null)
                        {
                            this._ddlQueryStringList.Visible = true;
                            this._btnQueryStringListAdd.Visible = true;
                        }
                    }
                    else
                    {
                        this._existingParameterTable.Visible = false;
                        if (this._ddlQueryStringList != null)
                        {
                            this._ddlQueryStringList.Visible = false;
                            this._btnQueryStringListAdd.Visible = false;
                        }
                    }
                }
                else
                {
                    this._lblUseSpecificQueryStrings.Visible = false;
                    this._cbUseSpecificQueryStrings.Visible = false;
                    this._existingParameterTable.Visible = false;
                    if (this._ddlQueryStringList != null)
                    {
                        this._ddlQueryStringList.Visible = false;
                        this._btnQueryStringListAdd.Visible = false;
                    }
                }
            }
            else
            {
                this._lblCacheExpiration.Visible = false;
                this._txtCacheExpiration.Visible = false;
                this._lblUseUrlInCacheKey.Visible = false;
                this._cbUseUrlInCacheKey.Visible = false;
                this._lblUseSpecificQueryStrings.Visible = false;
                this._cbUseSpecificQueryStrings.Visible = false;
                this._existingParameterTable.Visible = false;
                this._ddlQueryStringList.Visible = false;
                this._btnQueryStringListAdd.Visible = false;
                this._lblCacheResponseContent.Visible = false;
                this._cbCacheResponseContent.Visible = false;
            }
        }

        #endregion
    }
}
