﻿//---------------------------------------------------------------------
// <copyright file="CommerceServerContribExceptionManager.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System;
    using CommerceServerContrib.CrossTier.Configuration;
    using CommerceServerContrib.CrossTier.Interfaces;
    using System.Collections.Generic;
    using CommerceServer.Foundation.RequestTemplates;
    using CommerceServerContrib.CrossTier.Diagnostics;
    using CommerceServer.Foundation;

    /// <summary>
    /// Entry point into the Commerce Server Contrib exception manager implemented around Enterprise Library.
    /// </summary>
    public static class CommerceServerContribExceptionManager
    {
        /// <summary>
        /// Handles the given exception for the default policy.
        /// </summary>
        /// <param name="exception">The exception to be handled.</param>
        public static void HandleException(Exception exception)
        {
            HandleException(exception, PresentationServiceLocator.Current.BrandContext.ExceptionHandling.DefaultExceptionPolicy);
        }

        /// <summary>
        /// Handles the given exception.
        /// </summary>
        /// <param name="exception">The exception to be handled.</param>
        /// <param name="policy">The exception policy.</param>
        public static void HandleException(Exception exception, string policy)
        {
            CommerceEventLog.PresentationTierSource.WriteException(exception);

            var rethrow = ExceptionManager.HandleException(policy, exception);

            if (rethrow != null)
            {
                throw rethrow;
            }
        }

        /// <summary>
        /// Handles errors in a <see cref="BaseServiceAdapterResponse"/>.
        /// </summary>
        /// <param name="response">The <see cref="BaseServiceAdapterResponse"/> to inspect.</param>
        /// <param name="redirectUser">If true, the current request is treated as a Http page rquest and the user will be redirected to a different page if an error is found.  Otherwise, the user will not be redirected, and client script will be expected to handle any redirection needed.</param>
        public static void HandleServiceAdapterErrors(BaseServiceAdapterResponse response, bool redirectUser)
        {
            if (response != null && !response.Succeeded)
            {
                if (response.Errors.Count == 0)
                {
                    // Ensure that at least one error is included in the resposne.
                    response.Errors.Add(new ServiceAdapterErrorInfo
                    {
                        ErrorCode = CommerceServerContrib.CrossTier.CommerceServerContribErrorCodes.BackEndRequestFailed,
                    });
                }
                else
                {
                    // Check if a CheckoutFlowIdMismatch error occurred
                    ServiceAdapterErrorInfo cfidError = response.Errors.Find(x => string.Equals(x.ErrorCode, CommerceServerContrib.CrossTier.CommerceServerContribErrorCodes.CheckoutFlowIdMismatch, StringComparison.OrdinalIgnoreCase));
                    if (cfidError != null)
                    {
                        // Potential cookie replay attack detected - issue a new ID for this user.
                        var anonymousUserId = Guid.NewGuid().ToString("B");
                        UserCookieHelper.IssueAnonymousCookie(anonymousUserId);
                    }

                    //// No other errors have specific handling at this time.
                }
            }
        }
    }
}
