﻿//-----------------------------------------------------------------------
// <copyright file="ResourceHelper.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>A Helper class to getting resources.</summary>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Globalization;

    /// <summary>
    /// Used to make it easier to request string from resource files
    /// </summary>
    public static class ResourceHelper
    {
        /// <summary>
        /// The name of the Commerce Server Contrib resource location
        /// </summary>
        public const string CommerceServerContribResourceLocation = "CommerceServerContrib";

        /// <summary>
        /// The name of the Catalog resource location
        /// </summary>
        public const string CatalogResourceLocation = "Catalog";

        /// <summary>
        /// The name of the Order resource location
        /// </summary>
        public const string OrderResourceLocation = "Order";

        /// <summary>
        /// The name of the Profile resource location
        /// </summary>
        public const string ProfileResourceLocation = "Profile";

        private const string ErrorCodeTemplate = "ErrorCode_{0}";

        /// <summary>
        /// Gets strings from the catalog resource
        /// </summary>
        /// <param name="key">The key in the file.</param>
        /// <returns>The value from the resource</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1304:SpecifyCultureInfo", MessageId = "CommerceServerContrib.Web.ResourceHelper.Get(System.String,System.String)", Justification = "Culture is handled in another method.")]
        public static string GetError(string key)
        {
            return Get(CommerceServerContribResourceLocation, string.Format(CultureInfo.InvariantCulture, ErrorCodeTemplate, key));
        }

        /// <summary>
        /// Gets strings from the catalog resource
        /// </summary>
        /// <param name="key">The key in the file.</param>
        /// <returns>The value from the resource</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1304:SpecifyCultureInfo", MessageId = "CommerceServerContrib.Web.ResourceHelper.Get(System.String,System.String)", Justification = "Culture is handled in another method.")]
        public static string GetCatalog(string key)
        {
            return Get(CatalogResourceLocation, key);
        }

        /// <summary>
        /// Gets strings from the order resource
        /// </summary>
        /// <param name="key">The key in the file.</param>
        /// <returns>The value from the resource</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1304:SpecifyCultureInfo", MessageId = "CommerceServerContrib.Web.ResourceHelper.Get(System.String,System.String)", Justification = "Culture is handled in another method.")]
        public static string GetOrder(string key)
        {
            return Get(OrderResourceLocation, key);
        }

        /// <summary>
        /// Gets strings from the profile resource
        /// </summary>
        /// <param name="key">The key in the file.</param>
        /// <returns>The value from the resource</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1304:SpecifyCultureInfo", MessageId = "CommerceServerContrib.Web.ResourceHelper.Get(System.String,System.String)", Justification = "Culture is handled in another method.")]
        public static string GetProfile(string key)
        {
            return Get(ProfileResourceLocation, key);
        }

        /// <summary>
        /// Gets strings from the Commerce Server Contrib resource
        /// </summary>
        /// <param name="key">The key in the file.</param>
        /// <returns>The value from the resource</returns>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1304:SpecifyCultureInfo", MessageId = "CommerceServerContrib.Web.ResourceHelper.Get(System.String,System.String)", Justification = "Culture is handled in another method.")]
        public static string GetCommerceServerContrib(string key)
        {
            return Get(CommerceServerContribResourceLocation, key);
        }

        /// <summary>
        /// Gets strings from the custom resource
        /// </summary>
        /// <param name="location">The name of the custom resource.</param>
        /// <param name="key">The key in the file.</param>
        /// <returns>
        /// The value from the resource
        /// </returns>
        public static string Get(string location, string key)
        {
            return Get(location, key, PresentationServiceLocator.Current.SiteContext.UICulture);
        }

        /// <summary>
        /// Gets strings from the custom resource
        /// </summary>
        /// <param name="location">The name of the custom resource.</param>
        /// <param name="key">The key in the file.</param>
        /// <param name="culture">The culture with which to look up the resource.</param>
        /// <returns>
        /// The value from the resource
        /// </returns>
        public static string Get(string location, string key, CultureInfo culture)
        {
            return PresentationServiceLocator.Current.ResourceProvider.GetResource(location, key, culture);
        }
    }
}
