﻿//---------------------------------------------------------------------
// <copyright file="UIHelper.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Collections.ObjectModel;
    using System.Web.UI;
    using System.Web.UI.HtmlControls;
    using System.Reflection;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServer.Foundation;

    /// <summary>
    /// A helper class for building user interfaces.
    /// </summary>
    public static class UIHelper
    {
        /// <summary>
        /// Creates a table row with one control
        /// </summary>
        /// <param name="control">The control to add.</param>
        /// <param name="title">The title.</param>
        /// <returns>
        /// The new table row with the control
        /// </returns>
        public static HtmlTableRow CreateControlRow(Control control, string title)
        {
            var newControls = new Collection<Control> { control };

            return CreateControlRow(newControls, title);
        }

        /// <summary>
        /// Creates a table row with one controls
        /// </summary>
        /// <param name="controls">The controls to add.</param>
        /// <param name="title">The title.</param>
        /// <returns>
        /// The new table row with the controls
        /// </returns>
        public static HtmlTableRow CreateControlRow(Collection<Control> controls, string title)
        {
            var newRow = new HtmlTableRow();
            if (!string.IsNullOrEmpty(title))
            {
                newRow.Attributes["title"] = title;
            }
            
            var newCell = new HtmlTableCell();
            foreach (var control in controls)
            {
                newCell.Controls.Add(control);
            }

            newRow.Cells.Add(newCell);

            return newRow;
        }

        /// <summary>
        /// Creates the control cell.
        /// </summary>
        /// <param name="control">The control.</param>
        /// <returns>A new table cell with the control</returns>
        public static HtmlTableCell CreateControlCell(Control control)
        {
            var newCell = new HtmlTableCell();
            newCell.Controls.Add(control);
            return newCell;
        }

        /// <summary>
        /// Creates a table cell with a value set.
        /// </summary>
        /// <param name="value">The value to set in the table cell.</param>
        /// <returns>A table cell a value set.</returns>
        public static HtmlTableCell CreateCell(string value)
        {
            return new HtmlTableCell { InnerHtml = value };
        }
        
        /// <summary>
        /// Gets the value of an attribute of a type.
        /// </summary>
        /// <param name="registeredInterface">The registered interface.</param>
        /// <param name="property">The attribute of the registered interface.</param>
        /// <returns>The value of an attribute of a type</returns>
        public static string GetAttributeValue(MemberInfo registeredInterface, AttributeProperty property)
        {
            ParameterChecker.CheckForNull(registeredInterface, "registeredInterface");

            var attributes = registeredInterface.GetCustomAttributes(true);

            if (attributes.Length > 0)
            {
                foreach (var attribute in attributes)
                {
                    if (attribute is FriendlyNameAttribute)
                    {
                        switch (property)
                        {
                            case AttributeProperty.FriendlyName:
                                return ((FriendlyNameAttribute)attribute).Name;
                            case AttributeProperty.Group:
                                return ((FriendlyNameAttribute)attribute).Area;
                        }
                    }
                }
            }

            return registeredInterface.Name;
        }
    }
}
