﻿//---------------------------------------------------------------------
// <copyright file="ExternalServices.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System;
    using System.Collections.Generic;
    using CommerceServerContrib.CrossTier.Entities;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.CrossTier.Interfaces.Controllers;

    /// <summary>
    /// Used to indicate which attribute property you are looking for
    /// </summary>
    public enum AttributeProperty
    {
        /// <summary>
        /// The friendly name of the service
        /// </summary>
        FriendlyName,

        /// <summary>
        /// The group associated to the controller
        /// </summary>
        Group
    }

    /// <summary>
    /// Used to setup dependency injection and registration of controllers
    /// </summary>
    public static class ExternalServices
    {
        /// <summary>
        /// Gets all of the services available to the site
        /// </summary>
        /// <returns>The collection of services</returns>
        public static List<ControllerInstance> GetServices()
        {
            var section = UnityHelper.GetUnityConfigurationSection();
            var services = new List<ControllerInstance>();

            // for each container in the section, there could be many
            foreach (var container in section.Containers)
            {
                // for each interface registered in the section
                foreach (var registration in container.Registrations)
                {
                    // get the actual Type object for the interface
                    var registedInterface = Type.GetType(registration.TypeName);

                    if (registedInterface.IsInterface)
                    {
                        // check and see if it inherits from IBaseService, these are the only interfaces we are interested in
                        var foundInterfaces = registedInterface.FindInterfaces(InterfaceFilter, typeof(IBaseController).ToString());

                        if (foundInterfaces.Length > 0)
                        {
                            var serviceImplementation = PresentationServiceLocator.Current.GetImplementation(registedInterface) as IBaseController;

                            if (serviceImplementation != null)
                            {
                                // get the area associated to the actual implementation
                                var serviceArea = serviceImplementation.GroupId;
                                var response = serviceImplementation.TemplateController.GetAvailableTemplates(serviceArea);

                                var viewServiceMethods = response.Value;

                                if (viewServiceMethods != null && viewServiceMethods.Count > 0)
                                {
                                    var service = new ControllerInstance();

                                    service.Id = registedInterface.FullName;
                                    service.GroupId = serviceArea;
                                    service.FriendlyName = serviceImplementation.DisplayName;
                                    service.TypeReference = registedInterface;

                                    service.Methods = viewServiceMethods;

                                    services.Add(service);
                                }
                            }
                        }
                    }
                }
            }

            return services;
        }

        private static bool InterfaceFilter(Type typeObj, object criteriaObj)
        {
            if (typeObj.ToString() == criteriaObj.ToString())
            {
                return true;
            }
            else
            {
                return false;
            }
        }
    }
}
