﻿//---------------------------------------------------------------------
// <copyright file="CookieParameterType.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Web.UI;
    using System.Web.UI.WebControls;
    using CommerceServerContrib.CrossTier.Exceptions;
    using CommerceServerContrib.CrossTier.Interfaces;

    /// <summary>
    /// A parameter type that maps to a cookie value.
    /// </summary>
    [FriendlyName(ResourceHelper.CommerceServerContribResourceLocation, "CookieParameterType")]
    public class CookieParameterType : IParameterType
    {
        #region IParameterType Members

        /// <summary>
        /// Creates the editor control.
        /// </summary>
        /// <returns>A control for editing the parameter type.</returns>
        public System.Web.UI.Control CreateEditorControl()
        {
            var cookieValueTextbox = new TextBox { ID = "cookieValueTextbox" };
            return cookieValueTextbox;
        }

        /// <summary>
        /// Get the value of the parameter.
        /// </summary>
        /// <param name="contextValue">The context value.</param>
        /// <returns>The value of the parameter.</returns>
        public object GetParameterValue(string contextValue)
        {
            if (PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.Cookies[contextValue] == null)
            {
                return null;
            }

            if (string.IsNullOrEmpty(PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.Cookies[contextValue].Value))
            {
                return null;
            }

            return PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.Cookies[contextValue].Value;
        }

        /// <summary>
        /// Gets the context value from the editor control.
        /// </summary>
        /// <param name="editorControl">The editor control.</param>
        /// <returns>The context value.</returns>
        public string GetContextValueFromEditorControl(Control editorControl)
        {            
            var contextValue = string.Empty;
            var textBox = editorControl as TextBox;

            if (textBox != null)
            {
                contextValue = textBox.Text;
            }

            return contextValue;
        }

        /// <summary>
        /// Resets the editor control.
        /// </summary>
        /// <param name="editorControl">The editor control.</param>
        public void ResetEditorControl(Control editorControl)
        {
            var textBox = editorControl as TextBox;

            if (textBox != null)
            {
                textBox.Text = string.Empty;
            }
        }

        #endregion
    }
}
