﻿//---------------------------------------------------------------------
// <copyright file="QueryStringParameterType.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------

namespace CommerceServerContrib.Web
{
    using System.Web;
    using System.Web.UI;
    using System.Web.UI.WebControls;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServerContrib.CrossTier.Interfaces;
    
    /// <summary>
    /// A parameter type that maps to a collection of querystrings.
    /// </summary>
    [FriendlyName(ResourceHelper.CommerceServerContribResourceLocation, "QueryStringParameterType")]
    public class QueryStringParameterType : IParameterType
    {
        #region IParameterType Members

        /// <summary>
        /// Creates the editor control.
        /// </summary>
        /// <returns>A control for editing the parameter type.</returns>
        public System.Web.UI.Control CreateEditorControl()
        {
            var queryStringProvider = PresentationServiceLocator.Current.GetImplementation<IQueryStringProvider>();
            var queryStringDropDown = new DropDownList { ID = "queryStringDropDown" };

            queryStringDropDown.Items.Clear();
            var queryStringsDictionary = queryStringProvider.GetQueryStrings();
            foreach (var key in queryStringsDictionary.Keys)
            {
                string queryParameterKey = queryStringsDictionary[key].QueryParameterKey;
                var queryParameterDescription = queryStringsDictionary[key].LocalizedDescriptions.ContainsKey(PresentationServiceLocator.Current.SiteContext.CultureUICode)
                    ? queryStringsDictionary[key].LocalizedDescriptions[PresentationServiceLocator.Current.SiteContext.CultureUICode]
                    : queryStringsDictionary[key].LocalizedDescriptions[StringConstants.SiteSettingDefaultCultureName];
                
                queryStringDropDown.Items.Add(new ListItem(queryParameterDescription, queryParameterKey));
            }

            queryStringDropDown.Items.Insert(0, new ListItem(string.Empty));

            return queryStringDropDown;
        }

        /// <summary>
        /// Get the value of the parameter.
        /// </summary>
        /// <param name="contextValue">The context value.</param>
        /// <returns>The value of the parameter.</returns>
        public object GetParameterValue(string contextValue)
        {
            if (string.IsNullOrEmpty(PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.QueryString[contextValue]))
            {
                return null;
            }

            return HttpUtility.UrlDecode(PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.QueryString[contextValue]);
        }

        /// <summary>
        /// Gets the context value from the editor control.
        /// </summary>
        /// <param name="editorControl">The editor control.</param>
        /// <returns>The context value.</returns>
        public string GetContextValueFromEditorControl(Control editorControl)
        {
            var contextValue = string.Empty;
            var ddl = editorControl as DropDownList;

            if (ddl != null)
            {
                contextValue = ddl.SelectedValue;
            }

            return contextValue;
        }

        /// <summary>
        /// Resets the editor control.
        /// </summary>
        /// <param name="editorControl">The editor control.</param>
        public void ResetEditorControl(Control editorControl)
        {
            var ddl = editorControl as DropDownList;

            if (ddl != null)
            {
                ddl.SelectedIndex = 0;
            }
        }

        #endregion
    }
}
