﻿//---------------------------------------------------------------------
// <copyright file="GenericServiceWebPart.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary></summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.Web
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using System.Web;
    using System.Web.UI.WebControls.WebParts;
    using System.Xml.Linq;
    using System.Globalization;
    using CommerceServerContrib.CrossTier.Exceptions;
    using CommerceServerContrib.CrossTier.Helpers;
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.CrossTier.Interfaces.Controllers;
    using CommerceServer.Foundation.RequestTemplates;
    using CommerceServerContrib.CrossTier.Entities;
    using CommerceServer.Foundation;

    /// <summary>
    /// Provides a way of selecting any service and performing a query against it
    /// </summary>
    public class GenericServiceWebPart : BaseWebPart, IWebEditable, IGenericServiceWebPart
    {       
        #region Private Fields
        
        private IBaseController _controllerInstance;

        #endregion        

        #region WebPart properties

        /// <summary>
        /// Gets or sets the id of the service to talk to
        /// </summary>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ControllerIdDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ControllerIdDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public string ControllerId
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the id of the method in the service to talk to
        /// </summary>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_RequestTemplateIdDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_RequestTemplateIdDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public string RequestTemplateId
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the validation controller id.
        /// </summary>
        /// <value>
        /// The validation controller id.
        /// </value>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ValidationControllerIdDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ValidationControllerIdDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public string ValidationControllerId
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the id of the method in the service to talk to and gets validation rules
        /// </summary>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ValidationRequestTemplateIdDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ValidationRequestTemplateIdDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public string ValidationRequestTemplateId
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a list of all of the parameters for the service method and indicates how they should be set
        /// </summary>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ParameterSettingsDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_ParameterSettingsDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public string ParameterSettings
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether [ignore design time parameter configuration].
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [ignore design time parameter configuration]; otherwise, <c>false</c>.
        /// </value>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [DefaultValue(true)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_IgnoreDesignTimeParameterConfigurationDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_IgnoreDesignTimeParameterConfigurationDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.CommerceServerContrib)]
        public bool IgnoreDesignTimeParameterConfiguration
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether [render with ajax].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [render with ajax]; otherwise, <c>false</c>.
        /// </value>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(true)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_RenderWithAjaxDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_RenderWithAjaxDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.TabConnection)]
        public bool RenderWithAjax { get; set; }

        /// <summary>
        /// Gets or sets the sort parameter.
        /// </summary>
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(false)]
        [DefaultValue(false)]
        [LocalizedWebDisplayName(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_SortParameterSettingsDisplayName")]
        [LocalizedWebDescription(ResourceHelper.CommerceServerContribResourceLocation, "WebPartProperty_SortParameterSettingsDescription")]
        [LocalizedWebCategory(CommonPropertyCategories.TabConnection)]
        public string SortParameterSettings { get; set; }     

        #endregion

        #region IWebEditable Members

        /// <summary>
        /// Gets a reference to the <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control to enable it to be edited by custom <see cref="T:System.Web.UI.WebControls.WebParts.EditorPart"/> controls.
        /// </summary>
        /// <returns>A <see cref="T:System.Object"/> that consists of the child control of a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control.</returns>
        object IWebEditable.WebBrowsableObject
        {
            get
            {                
                return this;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether or not all parameters for a request template have been retrieved successfully.
        /// </summary>
        protected bool AllParameterValuesRetrieved { get; set; }

        /// <summary>
        /// Setups the editor parts.
        /// </summary>
        /// <returns>The editor part collection.</returns>
        protected override EditorPartCollection SetupEditorParts()
        {
            EditorPartCollection existingPartCollection = base.SetupEditorParts();

            var editors = new List<EditorPart>();

            var serviceTemplateEditorPart = new ServiceEditorPart { ID = "serviceTemplateEditorPart" };
            editors.Add(serviceTemplateEditorPart);

            foreach (EditorPart editorPart in existingPartCollection)
            {
                editors.Add(editorPart);
            }

            return new EditorPartCollection(editors);
        }

        #endregion  
        
        #region Overrides

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Init"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnInit(EventArgs e)
        {
            if (this.CurrentPage != null)
            {
                // Call Queue Service Request in the initialization complete event of the page after personalization has been loaded.
                this.CurrentPage.PreLoad += new EventHandler(this.PagePreload);
            }

            base.OnInit(e);
        }

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            // only set things up if we are actually in display mode
            if (this.RenderWithAjax)
            {
                if (this.InDisplayMode && !string.IsNullOrEmpty(this.ControllerId) && !string.IsNullOrEmpty(this.RequestTemplateId))
                {
                    var selectedService = PresentationServiceLocator.Current.AvailableServices.Where(s => s.Id == this.ControllerId).FirstOrDefault();

                    this.AllParameterValuesRetrieved = true;

                    if (!string.IsNullOrEmpty(this.ParameterSettings))
                    {
                        RequestTemplateParameterCollection parameters = this.PopulateParameters();

                        if (parameters != null)
                        {
                            this.JsonData = SerializationHelper.Serialize(parameters.Items, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeJson);
                        }
                        else
                        {
                            this.AllParameterValuesRetrieved = false;
                        }
                    }
                    else
                    {
                        RequestTemplateParameterCollection parameters = this.PopulateParameters();
                        this.JsonData = SerializationHelper.Serialize(parameters.Items, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeJson);
                    }

                    if (this.AllParameterValuesRetrieved)
                    {
                        this.PostBackLocation = string.Concat("/services/", selectedService.GroupId, "/", this.RequestTemplateId);

                        if (!string.IsNullOrEmpty(this.XsltUri))
                        {
                            var lastSlash = this.XsltUri.LastIndexOf(@"\", StringComparison.OrdinalIgnoreCase) + 1;
                            var lastDot = this.XsltUri.LastIndexOf(@".", StringComparison.OrdinalIgnoreCase);

                            string absolutePath = this.XsltUri.Substring(lastSlash, lastDot - lastSlash);

                            if (!string.IsNullOrEmpty(absolutePath))
                            {
                                this.PostBackLocation = string.Concat(this.PostBackLocation, "/", absolutePath);
                            }
                        }
                    }
                }
            }
            else
            {
                base.OnLoad(e);
            }
        }

        /// <summary>
        /// Renders the control to the specified HTML writer.
        /// </summary>
        /// <param name="writer">The <see cref="T:System.Web.UI.HtmlTextWriter"/> object that receives the control content.</param>
        protected override void Render(System.Web.UI.HtmlTextWriter writer)
        {
            if (this.InDisplayMode && !this.RenderWithAjax)
            {
                base.Render(writer);
            }
        }

        /// <summary>
        /// Gets the data to pass to the rendering engine.
        /// </summary>
        /// <returns>The data retrieved from the service</returns>
        protected override object GetData()
        {
            if (!this.RenderWithAjax && this.IsValid())
            {
                return this.GetServiceResponse(this.RenderMode);
            }

            return null;
        }

        /// <summary>
        /// Returns a value indicating whether or not the web part is valid and has all the required parameters.
        /// </summary>
        /// <returns>A value indicating whether or not the web part is valid and has all the required parameters</returns>
        protected override bool IsValid()
        {
            return base.IsValid() && this.AllParameterValuesRetrieved;
        }

        /// <summary>
        /// Occurs when before the page load event.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected virtual void PagePreload(object sender, EventArgs e)
        {
            if (this.InDisplayMode && !this.RenderWithAjax && !this.IsDataInCache())
            {
                this.QueueUpServiceRequest();
            }
        }

        /// <summary>
        /// Gets the validation rules.
        /// </summary>
        /// <returns>
        /// The request template validation rules
        /// </returns>
        protected override object GetValidationRules()
        {
            var validationRules = new object();
            if (this._controllerInstance != null)
            {
                validationRules = this._controllerInstance.TemplateController.GetTemplateValidationRules(this.ValidationRequestTemplateId).Value;
            }
           
            return SerializationHelper.Serialize(validationRules, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeJson);
        }

        #endregion

        #region Main Methods

        /// <summary>
        /// Queues up service request. This is part of a framework to make sure all requests are
        /// bundled and sent as one to the backend, need to reduce the amount of calls that happen 
        /// over multiple tiers
        /// </summary>
        protected virtual void QueueUpServiceRequest()
        {
            if (!string.IsNullOrEmpty(this.ControllerId) && !string.IsNullOrEmpty(this.RequestTemplateId))
            {
                var selectedService = PresentationServiceLocator.Current.AvailableServices.Where(s => s.Id == this.ControllerId).FirstOrDefault();

                if (selectedService != null)
                {
                    var selectedMethod = selectedService.Methods.Where(mi => mi.Id == this.RequestTemplateId).FirstOrDefault();
                    var parameters = new RequestTemplateParameterCollection();

                    // Defect 6211 - Ensure that the selected method isn't null in case the template no longer exists
                    if (selectedMethod != null && !string.IsNullOrEmpty(selectedMethod.Id))
                    {
                        // get the service represented by the selected service interface
                        this._controllerInstance = PresentationServiceLocator.Current.GetImplementation(selectedService.TypeReference) as IBaseController;
                        if (!this.IgnoreDesignTimeParameterConfiguration)
                        {
                            parameters = this.PopulateParameters();

                            this.AllParameterValuesRetrieved = (parameters != null && parameters.Count > 0) || string.IsNullOrEmpty(this.ParameterSettings);

                            if (this.AllParameterValuesRetrieved)
                            {
                                this.DecideRequestType(parameters, this.RenderMode);
                            }
                        }
                        else
                        {
                            this.AllParameterValuesRetrieved = true;
                            this.DecideRequestType(parameters, this.RenderMode);
                        }
                    }
                }
            }
        }

        /// <summary>
        /// Decides the type of the request.
        /// </summary>
        /// <param name="parameters">The parameters.</param>
        /// <param name="mode">The render mode the webpart is in.</param>
        protected virtual void DecideRequestType(RequestTemplateParameterCollection parameters, RenderModes mode)
        {
            if (mode == RenderModes.Xslt)
            {
                this._controllerInstance.QueueRequest(this.RequestTemplateId, parameters);
            }
            else
            {
                this._controllerInstance.QueueRequest(this.RequestTemplateId, parameters, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeObject);
            }
        }

        /// <summary>
        /// Talks to the service requested by the user and gets its response
        /// </summary> 
        /// <returns>Gets the response from the service</returns>
        [Obsolete("Please use GetRenderExtensionObjects(RenderModes mode) instead, GetServiceResponse() will be removed in the next version.")]
        protected virtual List<XDocument> GetServiceResponse()
        {
            return this.GetServiceResponse(RenderModes.Xslt) as List<XDocument>;
        }

        /// <summary>
        /// Talks to the service requested by the user and gets its response
        /// </summary>
        /// <param name="mode">The mode the webpart is running in.</param>
        /// <returns>
        /// Gets the response from the service
        /// </returns>
        protected virtual object GetServiceResponse(RenderModes mode)
        {
            if (this._controllerInstance != null)
            {
                var response = this._controllerInstance.ProcessRequest();
                var xmlMessages = new List<XDocument>();
                var responseValue = response.Value as string;
                var responseErrors = response.Errors;

                if (!response.Succeeded)
                {
                    CommerceServerContribExceptionManager.HandleServiceAdapterErrors(response, true);
                }

                if (mode != RenderModes.Xslt)
                {
                    return response;
                }

                if (!string.IsNullOrEmpty(responseValue))
                {
                    xmlMessages.Add(XDocument.Parse(responseValue));
                }

                if (responseErrors != null && responseErrors.Count > 0)
                {
                    var errorsXml = SerializationHelper.Serialize(response.Errors, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeXml);
                    xmlMessages.Add(XDocument.Parse(errorsXml));
                }

                return xmlMessages;
            }

            return null;
        }
        
        /// <summary>
        /// Populates the parameters.
        /// </summary>
        /// <returns>A dictionary containing populated parameters.</returns>
        protected virtual RequestTemplateParameterCollection PopulateParameters()
        {
            var parameters = new RequestTemplateParameterCollection();

            if (string.IsNullOrEmpty(this.ParameterSettings))
            {
                return parameters;
            }

            var workingParameterCollection = SerializationHelper.Deserialize<List<ParameterSelection>>(this.ParameterSettings, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeXmlDataContract);

            // get all of the parameter values and add them to the list
            foreach (var item in workingParameterCollection)
            {
                var workingParameter = PresentationServiceLocator.Current.GetImplementation(Type.GetType(item.SetType)) as IParameterType;
                if (workingParameter != null)
                {
                    try
                    {
                        var parameter = Convert.ToString(workingParameter.GetParameterValue(item.ContextValue), CultureInfo.InvariantCulture);
                        if (string.IsNullOrEmpty(parameter))
                        {
                            parameter = item.DefaultValue;
                        }

                        if (!string.IsNullOrEmpty(parameter))
                        {
                            parameters.Add(new RequestTemplateParameter(item.Id, parameter));
                        }
                    }
                    catch (ParameterValueNotFoundException exception)
                    {
                        var parameter = item.DefaultValue;
                        
                        if (string.IsNullOrEmpty(parameter))
                        {
                            CommerceServerContribExceptionManager.HandleException(exception);
                        }
                        else
                        {
                            parameters.Add(new RequestTemplateParameter(item.Id, parameter));
                        }
                    }
                }
            }
           
            if (parameters.Count == 0)
            {
                return null;
            }

            // Add the sortable parameter to the list
            if (!string.IsNullOrEmpty(this.SortParameterSettings))
            {
                var sortParameter = SerializationHelper.Deserialize<SortParameterSelection>(this.SortParameterSettings, CommerceServerContrib.CrossTier.Helpers.StringConstants.OutputTypeXmlDataContract);

                if (sortParameter != null)
                {
                    if (sortParameter.ConfigurationType == SortConfiguration.Static)
                    {
                        parameters.Add(new RequestTemplateParameter
                        {
                            Key = sortParameter.ParameterId,
                            Value = sortParameter.Order,
                        });
                    }
                    else if (sortParameter.ConfigurationType == SortConfiguration.Dynamic)
                    {
                        var sortParameterId = this.GetQueryStringValue(sortParameter.ParameterIdQueryString);
                        var sortOrder = this.GetQueryStringValue(sortParameter.OrderQueryString);

                        if (!string.IsNullOrEmpty(sortParameterId) && !string.IsNullOrEmpty(sortOrder))
                        {
                            try
                            {
                                parameters.Add(new RequestTemplateParameter
                                {
                                    Key = sortParameterId,
                                    Value = Enum.Parse(typeof(SortOrder), sortOrder),
                                });    
                            }
                            catch (ArgumentException ex)
                            {
                                CommerceTrace.Error(CommerceClientTraceSource.PresentationTier, ClientFrameworkResources.InvalidSortOrder);
                                CommerceServerContribExceptionManager.HandleException(ex);
                            }
                        }
                    }
                }
            }

            return parameters;
        }

        #endregion

        #region Private Methods

        private string GetQueryStringValue(string key)
        {
            var queryStringValue = PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.QueryString[key];
            return !string.IsNullOrEmpty(key) ? HttpUtility.UrlDecode(PresentationServiceLocator.Current.SiteContext.CurrentContext.Request.QueryString[key]) : string.Empty;
        }

        #endregion
    }
}
