﻿//-----------------------------------------------------------------------
// <copyright file="BaseControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.WebFormsSiteTemplate.ControlBase
{
    using CommerceServerContrib.CrossTier.Interfaces;
    using CommerceServerContrib.WebFormsSiteTemplate.Interfaces;
    using System.Configuration;
    using System.Globalization;
    using System.Web.UI;

    /// <summary>
    /// Base class for all controls on the site
    /// </summary>
    /// <typeparam name="T">Must be of type ICommerceEntity</typeparam>
    public class BaseControl<T> : UserControl, IBaseControl<T>
        where T : class 
    {
        /// <summary>
        /// The value to tell the app tier to recalculate the basket
        /// </summary>
        public const string DoRefreshBasket = "true";

        private ICommerceContext _context;
        private string _userId = string.Empty;

        /// <summary>
        /// Initializes a new instance of the <see cref="BaseControl{T}" /> class.
        /// </summary>
        public BaseControl()
        {
            this._context = CommerceServerContrib.Web.PresentationServiceLocator.Current.SiteContext;
            this._userId = string.IsNullOrWhiteSpace(this._context.User.Id) ? this._context.User.AnonymousId : this._context.User.Id;
        }

        /// <summary>
        /// Gets the current view bag
        /// </summary>
        public dynamic ViewBag
        {
            get
            {
                return ((IBasePage)this.Page).ViewBag;
            }
        }

        /// <summary>
        /// Gets or sets the model for the view
        /// </summary>
        public T Model
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the default catalog for the site
        /// </summary>
        public string DefaultCatalog
        {
            get
            {
                return ConfigurationManager.AppSettings["DefaultCommerceCatalog"];
            }
        }

        /// <summary>
        /// Gets the current context for the site
        /// </summary>
        public ICommerceContext CommerceContext
        {
            get
            {
                return this._context;
            }
        }

        /// <summary>
        /// Gets the current user id
        /// </summary>
        public string UserId
        {
            get
            {
                return this._userId;
            }
        }

        /// <summary>
        /// Gets the id of a cart basket type
        /// </summary>
        public string CartBasketType
        {
            get
            {
                return this.CommerceContext.DefaultBasketType.ToString(CultureInfo.InvariantCulture);
            }
        }

        /// <summary>
        /// Gets a key from the General resource
        /// </summary>
        /// <param name="key">The key to return</param>
        /// <returns>The value associated to the key</returns>
        public string Resource(string key)
        {
            return Resource("General", key);
        }

        /// <summary>
        /// Gets a key from the General resource
        /// </summary>
        /// <param name="source">The file to pull the key from</param>
        /// <param name="key">The key to return</param>        
        /// <returns>The value associated to the key</returns>
        public string Resource(string source, string key)
        {
            return (string)GetGlobalResourceObject(source, key);
        }
    }
}