﻿//-----------------------------------------------------------------------
// <copyright file="CartControl.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

namespace CommerceServerContrib.WebFormsSiteTemplate.ControlBase
{
    using System.Globalization;
    using CommerceServerContrib.WebFormsSiteTemplate.Models;
    using CommerceServerContrib.WebFormsSiteTemplate.Models.Generated;
    using CommerceServerContrib.WebFormsSiteTemplate.RequestTemplates;
    using Generated = CommerceServerContrib.WebFormsSiteTemplate.Models.Generated;

    /// <summary>
    /// Base class for all controls on the site
    /// </summary>
    public class CartControl : BaseControl<BasketViewModel>
    {
        /// <summary>
        /// Called when the page inits
        /// </summary>
        /// <param name="e">Any args from the calling party</param>
        protected override void OnInit(System.EventArgs e)
        {
            if (this.Model == null)
            {
                var page = Request.QueryString["page"];
                var skip = Helpers.ItemsToSkip(page, 10);
                Basket basket = null;
                if (skip > 0)
                {
                    var baskets = Orders.GetBasketPagedLineItems(null, Helpers.UserId(), "0", "true", skip.ToString(CultureInfo.InvariantCulture), "10", "true");
                    basket = Helpers.GetDefaultBasketFromCollectionOfBaskets(baskets);
                }
                else
                {
                    basket = BasketCachingHelper.GetMiniCartBasket(Helpers.LargeBasketMode);
                }

                ViewBag.CurrentPage = Helpers.CalculateCurrentPage(basket.LineItemsFirstItemIndex);
                ViewBag.TotalPages = Helpers.CalculateTotalPages(basket.LineItemsTotalItemCount);

                var cart = ViewModelBuilder.CreateBasketViewModel(basket);

                this.Model = cart;
            }

            this.DataBind();
        }
    }
}