﻿//-----------------------------------------------------------------------
// <copyright file="Category.aspx.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.WebFormsSiteTemplate.Pages
{
    using System;
    using System.Globalization;
    using System.Web.UI;
    using CommerceServerContrib.WebFormsSiteTemplate.PageBase;
    using Generated = CommerceServerContrib.WebFormsSiteTemplate.Models.Generated;
    using RT = CommerceServerContrib.WebFormsSiteTemplate.RequestTemplates;

    /// <summary>
    /// Handles all actions on the category page
    /// </summary>
    public partial class Category : BasePage<Generated.Category>
    {
        /// <summary>
        /// Called just before the preload event
        /// </summary>
        /// <param name="e">Any args for the event</param>
        protected override void OnPreLoad(EventArgs e)
        {
            var page = Page.Request.QueryString["page"];
            var categoryId = Page.RouteData.Values["categoryId"].ToString();

            if (!string.IsNullOrWhiteSpace(categoryId))
            {
                var skip = Helpers.ItemsToSkip(page, 10);
                this.Controller = RT.Catalog.GetCategoryWithChildProductsQueued(
                    categoryId,
                    this.DefaultCatalog,
                    string.IsNullOrWhiteSpace(page) ? "0" : skip.ToString(CultureInfo.InvariantCulture),
                    "10",
                    "true",
                    null,
                    null,
                    null,
                    null,
                    null);
            }
        }

        /// <summary>
        /// Called when the page loads
        /// </summary>
        /// <param name="sender">The caller of the event</param>
        /// <param name="e">Any args around the event</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            var categories = this.GetQueuedResponse();

            if (categories != null)
            {
                var category = (Generated.Category)categories[0];
                ViewBag.CurrentPage = Helpers.CalculateCurrentPage(category.ChildProductsFirstItemIndex);
                ViewBag.TotalPages = Helpers.CalculateTotalPages(category.ChildProductsTotalItemCount);
                this.Model = category;
                this.DataBind();
            }
        }
    }
}