﻿//-----------------------------------------------------------------------
// <copyright file="Checkout.aspx.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.WebFormsSiteTemplate.Pages
{
    using CommerceServer.Foundation;
    using CommerceServerContrib.WebFormsSiteTemplate.Models;
    using CommerceServerContrib.WebFormsSiteTemplate.Models.Generated;
    using CommerceServerContrib.WebFormsSiteTemplate.PageBase;
    using CommerceServerContrib.WebFormsSiteTemplate.RequestTemplates;
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using RT = CommerceServerContrib.WebFormsSiteTemplate.RequestTemplates;

    /// <summary>
    /// Handles all actions on the checkout page
    /// </summary>
    public partial class Checkout : BasePage<BasketViewModel>
    {
        private const string ReadyForCheckout = "ReadyForCheckout";
        
        /// <summary>
        /// Gets the type of the order basket.
        /// </summary>
        /// <value>
        /// The type of the order basket.
        /// </value>
        public string OrderBasketType
        {
            get
            {
                return "1";
            }
        }

        /// <summary>
        /// Called just before the preload event
        /// </summary>
        /// <param name="e">Any args for the event</param>
        protected override void OnPreLoad(EventArgs e)
        {
            if (!IsSubmit())
            {
                this.Controller = RT.Orders.GetBasketQueued(this.CommerceContext.DefaultBasketName, this.UserId, this.CartBasketType, DoRefreshBasket, "true");
            }
        }

        /// <summary>
        /// Called when the page loads
        /// </summary>
        /// <param name="sender">The caller of the event</param>
        /// <param name="e">Any args around the event</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (IsSubmit())
            {
                this.HandleSubmit();
            }
            else
            {
                this.AddSupportingDataToViewBag();

                var baskets = this.GetQueuedResponse();

                BasketViewModel basketViewModel;

                if (baskets != null && baskets.Count > 0)
                {
                    var basket = (Basket)baskets[0];
                    basketViewModel = new BasketViewModel(basket);
                }
                else
                {
                    basketViewModel = new BasketViewModel();
                }

                this.ViewBag.Basket = basketViewModel;
                this.Model = basketViewModel;
                this.DataBind();
            }
        }

        private bool IsCheckout()
        {
            if (Request.Form.AllKeys.Contains("Checkout"))
            {
                return true;
            }

            return false;
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA1806:DoNotIgnoreMethodResults", MessageId = "System.Boolean.TryParse(System.String,System.Boolean@)", Justification = "The default output is fine.")]
        private bool ShouldCleanBasket()
        {
            var cleanBasketFormValue = Request.Form["cleanBasket"];
            bool cleanBasket = false;
            bool.TryParse(cleanBasketFormValue, out cleanBasket);
            return cleanBasket;
        }

        private void HandleSubmit()
        {
            bool cleanBasket = ShouldCleanBasket();
            var basketViewModel = BuildViewModel();

            // Need to determine if it is a checkout of a recalc
            if (this.IsCheckout())
            {
                if (cleanBasket)
                {
                    RT.Orders.CleanBasket(this.CommerceContext.DefaultBasketName, this.UserId, this.CartBasketType);
                }

                var result = this.UpdateBasket(basketViewModel, this.OrderBasketType, ReadyForCheckout);

                if (result != null && result.Count > 0)
                {
                    BasketCachingHelper.InvalidateBasketCache();
                    var basket = (Basket)result[0];
                    Response.Redirect("submitted/" + basket.OrderNumber);
                }
            }
            else
            {
                this.AddSupportingDataToViewBag();

                if (cleanBasket)
                {
                    RT.Orders.CleanBasket(this.CommerceContext.DefaultBasketName, this.UserId, this.CartBasketType);
                }

                var result = UpdateBasket(basketViewModel, this.CartBasketType, ReadyForCheckout);
                if (result != null && result.Count > 0)
                {
                    var resultBasket = (Basket)result[0];
                    //// Special handling for some state issues
                    bool userBilling = basketViewModel.UseBillingAddressForShippingAddress;
                    var creditCardViewModel = basketViewModel.CreditCardPayment;

                    basketViewModel = new BasketViewModel(resultBasket);
                    basketViewModel.UseBillingAddressForShippingAddress = userBilling;
                    basketViewModel.CreditCardPayment = creditCardViewModel;
                    BasketCachingHelper.AddBasketToCache(resultBasket);
                }
            }

            this.ViewBag.Basket = basketViewModel;
            this.Model = basketViewModel;
            this.DataBind();
        }

        private List<CommerceEntity> UpdateBasket(BasketViewModel basketViewModel, string basketType, string basketStatus)
        {
            var shippingAddressId = Guid.NewGuid().ToString();
            var billingAddressId = Guid.NewGuid().ToString();

            if (basketViewModel.UseBillingAddressForShippingAddress)
            {
                this.CopyBillingAddressIntoShippingAddress(basketViewModel);
            }

            #region Update Basket
            var result = RT.Orders.UpdateBasket(
                this.CommerceContext.DefaultBasketName,
                this.UserId,
                this.CartBasketType,
                basketType,
                basketStatus,
                DoRefreshBasket,
                shippingAddressId,
                basketViewModel.ShippingAddress.AddressName,
                basketViewModel.ShippingAddress.FirstName,
                basketViewModel.ShippingAddress.LastName,
                basketViewModel.ShippingAddress.Line1,
                basketViewModel.ShippingAddress.Line2,
                basketViewModel.ShippingAddress.City,
                basketViewModel.ShippingAddress.StateProvinceCode,
                basketViewModel.ShippingAddress.StateProvinceName,
                basketViewModel.ShippingAddress.ZipPostalCode,
                basketViewModel.ShippingAddress.CountryRegionCode,
                basketViewModel.ShippingAddress.CountryRegionName,
                basketViewModel.ShippingAddress.Telephone,
                billingAddressId,
                basketViewModel.BillingAddress.AddressName,
                basketViewModel.BillingAddress.FirstName,
                basketViewModel.BillingAddress.LastName,
                basketViewModel.BillingAddress.Line1,
                basketViewModel.BillingAddress.Line2,
                basketViewModel.BillingAddress.City,
                basketViewModel.BillingAddress.StateProvinceCode,
                basketViewModel.BillingAddress.StateProvinceName,
                basketViewModel.BillingAddress.ZipPostalCode,
                basketViewModel.BillingAddress.CountryRegionCode,
                basketViewModel.BillingAddress.CountryRegionName,
                basketViewModel.BillingAddress.Telephone,
                basketViewModel.ShippingMethodId,
                basketViewModel.CreditCardPayment.Month,
                basketViewModel.CreditCardPayment.Year,
                basketViewModel.CreditCardPayment.FirstName + " " + basketViewModel.CreditCardPayment.LastName,
                basketViewModel.CreditCardPayment.CreditCardNumber,
                basketViewModel.CreditCardPayment.CreditCardVerification,
                billingAddressId,
                basketViewModel.PaymentId);
            #endregion

            return result;
        }

        private BasketViewModel BuildViewModel()
        {
            var basketViewModel = new BasketViewModel();
            basketViewModel.BillingAddress = this.BuildAddress("Billing");
            basketViewModel.ShippingAddress = this.BuildAddress("Shipping");
            basketViewModel.ShippingMethodId = Request.Form["shippingMethod"];
            basketViewModel.PaymentId = Request.Form["paymentMethod"];
            basketViewModel.UseBillingAddressForShippingAddress = false;
            if (Request.Form.AllKeys.Contains("shipToBillingAddress") &&
                Request.Form["shipToBillingAddress"] != null)
            {
                basketViewModel.UseBillingAddressForShippingAddress = true;
            }

            this.BuildCreditCardPayment(basketViewModel.CreditCardPayment);
            return basketViewModel;
        }

        private void CopyBillingAddressIntoShippingAddress(BasketViewModel basket)
        {
            var newShippingAddress = new AddressOrders();
            foreach (var property in basket.BillingAddress.Properties)
            {
                newShippingAddress.Properties[property.Key] = property.Value;
            }

            basket.ShippingAddress = newShippingAddress;
        }

        private void BuildCreditCardPayment(PaymentMethodViewModel paymentMethodViewModel)
        {
            paymentMethodViewModel.FirstName = Request.Form["cc.firstName"];
            paymentMethodViewModel.LastName = Request.Form["cc.lastName"];
            paymentMethodViewModel.CreditCardNumber = Request.Form["cc.creditCardNumber"];
            paymentMethodViewModel.Month = Request.Form["cc.month"];
            paymentMethodViewModel.Year = Request.Form["cc.year"];
            paymentMethodViewModel.CreditCardVerification = Request.Form["cc.creditCardVerification"];
        }

        private AddressOrders BuildAddress(string fieldPrefix)
        {
            var address = new AddressOrders();
            address.FirstName = Request.Form[fieldPrefix + "_firstName"];
            address.LastName = Request.Form[fieldPrefix + "_lastName"];
            address.Line1 = Request.Form[fieldPrefix + "_line1"];
            address.Line2 = Request.Form[fieldPrefix + "_line2"];
            address.City = Request.Form[fieldPrefix + "_city"];
            address.CountryRegionName = Request.Form[fieldPrefix + "_countryRegionName"];
            address.StateProvinceName = Request.Form[fieldPrefix + "_stateProvinceName"];
            address.Telephone = Request.Form[fieldPrefix + "_telephone"];
            return address;
        }

        private bool IsSubmit()
        {
            return Request.Form != null && Request.Form.AllKeys.Length > 0;
        }

        private void AddSupportingDataToViewBag()
        {
            ViewBag.PaymentMethods = RT.Profile.GetPaymentMethods();
            ViewBag.ShippingMethods = RT.Profile.GetShippingMethods();
        }
    }
}