﻿//-----------------------------------------------------------------------
// <copyright file="DynamicViewDataDictionary.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
namespace CommerceServerContrib.WebFormsSiteTemplate.Utils
{
    using System;
    using System.Collections.Generic;
    using System.Dynamic;
    using System.Web.Mvc;

    /// <summary>
    /// A dynamic collection object
    /// </summary>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1711:IdentifiersShouldNotHaveIncorrectSuffix", Justification = "By design, leave as is.")]
    public class DynamicViewDataDictionary : DynamicObject
    {
        private readonly Func<ViewDataDictionary> _viewDataThunk;

        /// <summary>
        /// Initializes a new instance of the <see cref="DynamicViewDataDictionary" /> class
        /// </summary>
        /// <param name="viewDataThunk">A function that can handle setting the value</param>
        public DynamicViewDataDictionary(Func<ViewDataDictionary> viewDataThunk)
        {
            this._viewDataThunk = viewDataThunk;
        }

        private ViewDataDictionary ViewData
        {
            get
            {
                return this._viewDataThunk();
            }
        }

        /// <summary>
        /// Returns a list of all of the kets in the collection
        /// </summary>
        /// <returns>All of the keys in the form of IEnumerable string</returns>
        public override IEnumerable<string> GetDynamicMemberNames()
        {
            return this.ViewData.Keys;
        }

        /// <summary>
        /// Gets a value form the dictionary
        /// </summary>
        /// <param name="binder">The key being searched for</param>
        /// <param name="result">The result of the dictionary search</param>
        /// <returns>True if found</returns>
        public override bool TryGetMember(GetMemberBinder binder, out object result)
        {
            result = this.ViewData[binder.Name];

            return true;
        }

        /// <summary>
        /// Sets a value in the dictionary
        /// </summary>
        /// <param name="binder">The key to set</param>
        /// <param name="value">The value to set for the key</param>
        /// <returns>True if set</returns>
        public override bool TrySetMember(SetMemberBinder binder, object value)
        {
            this.ViewData[binder.Name] = value;

            return true;
        }
    }
}