﻿//---------------------------------------------------------------------
// <copyright file="ViewModelBuilder.cs" company="commerceserver.net">
//     Copyright © commerceserver.net.  All rights reserved.
// </copyright>
// <summary>Holds helper methods for building view models.</summary>
//---------------------------------------------------------------------
namespace CommerceServerContrib.WebFormsSiteTemplate
{
    using CommerceServerContrib.WebFormsSiteTemplate.Models;
    using Generated = CommerceServerContrib.WebFormsSiteTemplate.Models.Generated;
    using System.Linq;

    /// <summary>
    /// Holds helper methods for building view models.
    /// </summary>
    public static class ViewModelBuilder
    {
        /// <summary>
        /// Used to create a BasketViewModel from a Generated.Basket
        /// </summary>
        /// <param name="basket">The basket to convert</param>
        /// <returns>The new BasketViewModel</returns>
        public static BasketViewModel CreateBasketViewModel(Generated.Basket basket)
        {
            if (basket == null)
            {
                return new BasketViewModel();
            }

            var basketViewModel = new BasketViewModel(basket) { BasketId = basket.Id };

            if (basket.BasketErrors != null)
            {
                basketViewModel.BasketErrors.AddRange(basket.BasketErrors.OfType<string>());
            }

            if (basket.LineItems != null && basket.LineItems.Any())
            {
                basketViewModel.LineItems.AddRange(
                    from li in basket.LineItems
                    select new LineItemViewModel
                        {
                            BasketId = basket.Id,
                            Id = li.Id,
                            ProductImagePath = li.ProductImageFilename,
                            ImageFilename = li.ProductImageFilename,
                            ProductId = li.ProductId,
                            DisplayName = li.DisplayName,
                            VariantId = li.VariantId,
                            Description = li.Description,
                            Quantity = li.Quantity.HasValue ? li.Quantity.Value : 0.0m,
                            ListPrice = li.ListPrice,
                            Total = li.Total.Value,
                            ProductViewModel = new ProductViewModel() { ImageFilename = li.ProductImageFilename }
                        });
            }

            return basketViewModel;
        }
    }
}